<?

/**
 * migriert Daten einer Variable in eine bisher nicht geloggte Variable
 * 
 * <p>Diese Funktion migriert die Daten der Variable mit der ID <b>OldVariableID</b> in die Variable mit der ID <b>NewVariableID</b>.</p><p>Die Variable mit der ID <b>NewVariableID</b> darf nicht geloggt sein. Das heit auch, dass keine alten Datenstze durch Logging vorhanden sein drfen.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/archive-control/ac-changevariableid/
 * @returns boolean <p><b>True</b> wenn erfolgreich, sonst <b>False</b></p>
 * @param integer $InstanceID ID zum Archiv
 * @param integer $OldVariableID ID der zu migrierenden Variable
 * @param integer $NewVariableID ID der neuen Variable
 */
function AC_ChangeVariableID(integer $InstanceID, integer $OldVariableID, integer $NewVariableID)
{
    
}

/**
 * lscht in einem bestimmten Zeitraum alle Datenstze einer geloggten Variable
 * 
 * <p>Diese Funktion lscht alle geloggten Datenstze der Variable mit der ID <b>VariablenID</b> im Zeitraum von <b>Startzeit</b> bis inklusive <b>Endzeit</b></p><p>Falls Datensstze zu einem einzelnen Zeitpunkt gelscht werden sollen, muss die Endzeit gleich der Startzeit gesetzt werden</p><p>Es ist zu Bedenken, dass der Unix Zeitstempel in UTC angegeben wird. Viele europische Lnder haben aber Sommerzeit (CEST/UTC+2) und Winterzeit (CET/UTC+1).</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/archive-control/ac-deletevariabledata/
 * @returns boolean <p><b>True</b> wenn erfolgreich, sonst <b>False</b></p>
 * @param integer $InstanceID ID zum Archiv
 * @param integer $VariableID ID der Variable in der die Datenstze gelscht werden sollen
 * @param integer $StartTime Datum/Zeit als Unix Zeitstempel
 * @param integer $EndTime Datum/Zeit als Unix Zeitstempel
 */
function AC_DeleteVariableData(integer $InstanceID, integer $VariableID, integer $StartTime, integer $EndTime)
{
    
}

/**
 * holt aggregierte Daten aus dem Archiv
 * 
 * <p>Dieser Befehlt gibt die aggregierten Daten zurck, die ber das Archiv fr eine Variable mit der <b>VariablenID</b> mitprotokolliert und berechnet wurden. Dabei knnen die <b>Start-</b> und <b>Endzeit</b> als Parameter angegeben werden. Der Parameter <b>Limit</b> limitiert die maximale Anzahl der zurckgegebenen Datenstze, wobei das Limit von 10000 Datenstzen pro Abfrage nie berschritten werden kann.</p><p>Diese Funktion garantiert, dass alle Datenstze zwischen Startzeit und Endzeit auch vorhanden sind und ausgegeben werden. Das bedeutet, dass es es keine zeitlichen Lcken zwischen den Datenstzen gibt. Datenstze werden maximal bis zum jetzigen Zeitpunkt ausgegeben.</p><p>Es werden immer ganze aggregierte Zeitrume abgefragt. Dafr muss der Startzeitpunkt (abhngig von der <b>Aggregationsstufe</b>) der/des Stunde/Tages/Woche/Monats/Jahr im Zeitraum von <b>Startzeit</b> und <b>Endzeit</b> umfasst sein.</p><p>Die Aggregationsstufen 5-Mintige/1-Mintige Aggregation werden aus den Rohdaten berechnet, sodass diese bei vielen Rohdaten ggf. mehr Systemleisung erfordern, als die anderen Aggregationsstufen</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/archive-control/ac-getaggregatedvalues/
 * @returns array <p>Ein Array mit folgenden <b>key =&gt; value</b> Paaren.</p><p>Die Ausgabe startet mit dem neusten Datensatz und dann absteigend mit den lteren Datenstzen.</p><p>Bedeutung der Felder beim Aggregationstyp <b>Standard</b></p><li><b>TimeStamp</b>  integer  Datum/Zeit vom Begin des Aggregationszeitraums als Unix Timestamp</li><li><b>Avg</b>  variant  Durchschnittswert innerhalb dieses Aggregationszeitraums</li><li><b>MinTime</b>  variant  Datum/Zeit von <b>Min</b> als Unix Timestamp</li><li><b>Min</b>  variant  Kleinster Wert innerhalb dieses Aggregationszeitraums</li><li><b>MaxTime</b>  variant  Datum/Zeit von <b>Max</b> als Unix Timestamp</li><li><b>Max</b>  variant  Grter Wert innerhalb dieses Aggregationszeitraums</li><p>Bedeutung der Felder beim Aggregationstyp <b>Zhler</b></p><li><b>TimeStamp</b>  integer  Datum/Zeit vom Begin des Aggregationszeitraums als Unix Timestamp</li><li><b>Avg</b>  variant  Summe der positiven Delta innerhalb dieses Aggregationszeitraums</li><li><b>MinTime</b>  variant  Datum/Zeit von <b>Min</b> als Unix Timestamp</li><li><b>Min</b>  variant  Kleinstes positives Delta innerhalb dieses Aggregationszeitraums</li><li><b>MaxTime</b>  variant  Datum/Zeit von <b>Max</b> als Unix Timestamp</li><li><b>Max</b>  variant  Grter positives Delta innerhalb dieses Aggregationszeitraums</li>
 * @param integer $InstanceID ID zum Archiv
 * @param integer $VariableID ID der abzufragenden Variablen
 * @param integer $AggregationSpan 
 *   enum[0=agHour, 1=agDay, 2=agWeek, 3=agMonth, 4=agYear, 5=ag5Minutes, 6=ag1Minute, 7=agChanges]
 * @param integer $StartTime Datum/Zeit als Unix Zeitstempel
 * @param integer $EndTime Datum/Zeit als Unix Zeitstempel
 * @param integer $Limit Maximale Anzahl an Datenstzen. (0 = Kein Limit, 10000 ist das harte Limit, welches immer greift)
 */
function AC_GetAggregatedValues(integer $InstanceID, integer $VariableID, integer $AggregationSpan, integer $StartTime, integer $EndTime, integer $Limit)
{
    
}

/**
 * gibt den Aggregationstyp einer Variable wieder
 * 
 * <p>Diese Funktion fragt den Aggregationstyp der Variable mit der ID <b>VariablenID</b> ab und gibt diesen als Integer zurck.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/archive-control/ac-getaggregationtype/
 * @returns integer <p>Ein Integer der den Typ der Aggregation wiedergibt.</p><li>0  Standard</li><li>1  Zhler</li>
 * @param integer $InstanceID ID zum Archiv
 * @param integer $VariableID ID der abzufragenden Variablen
 */
function AC_GetAggregationType(integer $InstanceID, integer $VariableID)
{
    
}

/**
 * gibt ein Array aller geloggten Variablen zurck
 * 
 * <p>Diese Funktion gibt ein Array aller geloggten Variablen des Archiv Handlers mit der ID <b>InstanzID</b> wieder. Zustzliche Informationen zu jeder Variable knnen mit <b>Datenbankabfrage</b> aktiviert werden.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/archive-control/ac-getaggregationvariables/
 * @returns array <p>Ein Array mit folgenden <b>key =&gt; value</b> Paaren.</p><li>FirstTime  integer  Datum/Zeit vom Beginn des Aggregationszeitraums als Unix Zeitstempel</li><li>LastTime  integer  Datum/Zeit vom letzten Eintrag des Aggregationszeitraums als Unix Zeitstempel</li><li>RecordCount  integer  Anzahl der Datenstze</li><li>RecordSize  integer  Gre aller Datenstze in Bytes</li><li>VariableID  integer  ID der Variable</li><li>AggregationType  integer  Aggregationstyp als Integer. Siehe auch AC_GetAggregationType</li><li>AggregationVisible  boolean  Gibt an ob die Variable in der Visualisierung angezeigt wird. Siehe auch AC_GetGraphStatus</li><li>AggregationActive  boolean  Gibt an ob das Logging fr diese Variable Aktiv ist. Siehe auch AC_GetLoggingStatus</li>
 * @param integer $InstanceID ID zum Archiv
 * @param boolean $CalculateStatistics True, wenn zustzliche Informationen angezeigt werden sollen, sonst False
 */
function AC_GetAggregationVariables(integer $InstanceID, boolean $CalculateStatistics)
{
    
}

/**
 * fragt ab ob eine Variable visualisiert wird
 * 
 * <p>Diese Funktion fragt ab, ob die Variable mit der ID <b>VariablenID</b> in der Visualisierung angezeigt wird.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/archive-control/ac-getgraphstatus/
 * @returns boolean <p><b>True</b> wenn die Visualisierung der Variable aktiv ist, sonst <b>False</b></p>
 * @param integer $InstanceID ID zum Archiv
 * @param integer $VariableID ID der abzufragenden Variablen
 */
function AC_GetGraphStatus(integer $InstanceID, integer $VariableID)
{
    
}

/**
 * holt Rohdaten aus dem Archiv Control
 * 
 * <p>Dieser Befehlt gibt die Rohdaten zurck, die ber das Archiv Control fr eine Variable mit der <b>VariablenID</b> mitprotokolliert wurden. Dabei knnen die <b>Start-</b> und <b>Endzeit</b> als Parameter angegeben werden. Der Parameter <b>Limit</b> limitiert die maximale Anzahl der zurckgegebenen Datenstze, wobei das Limit von 10000 Datenstzen pro Abfrage nie berschritten werden kann.</p><p>Das Archiv Control erstellt nur neue Datenstze fr genderte Werte! Aktualisierungen werden nicht bercksichtigt.</p><p>Diese Funktion verursacht eine erhebliche Belastung fr das System, da in den meisten Fllen sehr viele Datenstze verarbeitet werden mssen. Bitte weichen Sie in jedem mglichen Falle auf bereits voraggregierte Werte ber die AC_GetAggregatedValues Funktion aus. Diese Funktion bietet Ihnen direkten Zugriff auf Mittelwerte oder Summen fr verschiedene Zeitrume wie z.B. Jahre, Monate, Wochen und Tage.</p><p>In IP-Symcon 2.x war diese Funktion fehlerbehaftet. Es wurde immer ein Wert mehr ausgegeben, welcher vor der Startzeit lag. Das war insofern ntzlich, dass die fr z.B. die Graphengenerierung der vorherige Wert bekannt war, und fr die vollstndige Zeitspanne ein Graph erstellt werden konnte. Anderfalls wre eine Lcke am Anfang des Graphen sichtbar. Fr eine Funktion mit dem Parameter Startzeit ist diese Funktionsweise jedoch nicht korrekt. Wer fr seine Skripte genau diese besondere Funktionsweise bentigt, kann die Hilfsfunktion nutzen, die den vorherigen Datensatz, der vor der Startzeit liegt, entsprechend abfragt und zum Array hinzufgt.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/archive-control/ac-getloggedvalues/
 * @returns array <p>Ein Array mit folgenden <b>key =&gt; value</b> Paaren.</p><p>Die Ausgabe startet mit dem neusten Datensatz und dann absteigend mit den lteren Datenstzen.</p><li><b>TimeStamp</b>  integer  Datum/Zeit beim Erstellen des Datensatzes als Unix Timestamp</li><li><b>Value</b>  variant  Wert</li>
 * @param integer $InstanceID ID zum Archiv Control
 * @param integer $VariableID ID der abzufragenden Variablen
 * @param integer $StartTime Datum/Zeit als Unix Zeitstempel
 * @param integer $EndTime Datum/Zeit als Unix Zeitstempel
 * @param integer $Limit Maximale Anzahl an Datenstzen. (0 = Kein Limit, 10000 ist das harte Limit, welches immer greift)
 */
function AC_GetLoggedValues(integer $InstanceID, integer $VariableID, integer $StartTime, integer $EndTime, integer $Limit)
{
    
}

/**
 * fragt ab ob eine Variable geloggt wird
 * 
 * <p>Diese Funktion fragt ab, ob die Variable mit der ID <b>VariablenID</b> geloggt wird.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/archive-control/ac-getloggingstatus/
 * @returns boolean <p><b>True</b> wenn Logging fr die Variable aktiv ist, sonst <b>False</b></p>
 * @param integer $InstanceID ID zum Archiv
 * @param integer $VariableID ID der abzufragenden Variablen
 */
function AC_GetLoggingStatus(integer $InstanceID, integer $VariableID)
{
    
}

/**
 * startet die Reaggregation einer Variable
 * 
 * <p>Diese Funktion startet die Reaggregation der Variable mit der ID <b>VariablenID</b>.</p><p>Das Reaggregieren kann sehr lange dauern. Der momentane Fortschritt der Reaggregation kann ber regelmssige Eintrge im Meldungsfenster kontrolliert werden.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/archive-control/ac-reaggregatevariable/
 * @returns boolean <p><b>True</b> wenn erfolgreich, sonst <b>False</b></p>
 * @param integer $InstanceID ID zum Archiv
 * @param integer $VariableID ID der zu reaggregierenden Variable
 */
function AC_ReAggregateVariable(integer $InstanceID, integer $VariableID)
{
    
}

/**
 * setzt den Aggregationstyp einer Variable
 * 
 * <p>Diese Funktion setzt den Aggregationstyp <b>Aggregationstyp</b> bei der Variable mit der ID <b>VariablenID</b></p><p>Die nderung wird erst gesetzt nachdem IPS_ApplyChanges aufgerufen wurde. Im Anschluss ist eine Reaggregation der Variable ntig.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/archive-control/ac-setaggregationtype/
 * @returns boolean <p><b>True</b> wenn erfolgreich, sonst <b>False</b></p>
 * @param integer $InstanceID ID zum Archiv
 * @param integer $VariableID ID der Variable bei der der Aggregationstyp gesetzt werden soll
 * @param integer $AggregationType 
 *   enum[0=asGauge, 1=asCounter]
 */
function AC_SetAggregationType(integer $InstanceID, integer $VariableID, integer $AggregationType)
{
    
}

/**
 * setzt die Eigenschaft zur Visualisierung einer Variable
 * 
 * <p>Diese Funktion ndert die Eigenschaft zur Visualisierung der Variable mit der ID <b>VariablenID</b> auf <b>Aktiv</b>.</p><p>Die nderung wird erst wirksam nachdem IPS_ApplyChanges aufgerufen wurde.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/archive-control/ac-setgraphstatus/
 * @returns boolean <p><b>True</b> wenn erfolgreich, sonst <b>False</b></p>
 * @param integer $InstanceID ID zum Archiv
 * @param integer $VariableID ID der abzufragenden Variablen
 * @param boolean $Active True, wenn das Anzeigen der Variable in der Visualisierung aktiviert werden soll, sonst False.
 */
function AC_SetGraphStatus(integer $InstanceID, integer $VariableID, boolean $Active)
{
    
}

/**
 * setzt die Eigenschaft zum Loggen einer Variable
 * 
 * <p>Diese Funktion ndert die Eigenschaft zum Loggen der Variable mit der ID <b>VariablenID</b> auf <b>Aktiv</b>.</p><p>Die nderung wird erst wirksam nachdem IPS_ApplyChanges aufgerufen wurde.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/archive-control/ac-setloggingstatus/
 * @returns boolean <p><b>True</b> wenn erfolgreich, sonst <b>False</b></p>
 * @param integer $InstanceID ID zum Archiv
 * @param integer $VariableID ID der abzufragenden Variablen
 * @param boolean $Active True, wenn das Logging der Variable aktiviert werden soll, sonst False.
 */
function AC_SetLoggingStatus(integer $InstanceID, integer $VariableID, boolean $Active)
{
    
}

/**
 * AESGI_RequestCurrentLimit
 * 
 * @returns boolean
 * @param integer $InstanceID
 */
function AESGI_RequestCurrentLimit(integer $InstanceID)
{
    
}

/**
 * AESGI_RequestErrors
 * 
 * @returns boolean
 * @param integer $InstanceID
 */
function AESGI_RequestErrors(integer $InstanceID)
{
    
}

/**
 * AESGI_RequestPowerReduction
 * 
 * @returns boolean
 * @param integer $InstanceID
 */
function AESGI_RequestPowerReduction(integer $InstanceID)
{
    
}

/**
 * AESGI_RequestRunMode
 * 
 * @returns boolean
 * @param integer $InstanceID
 */
function AESGI_RequestRunMode(integer $InstanceID)
{
    
}

/**
 * AESGI_RequestStatus
 * 
 * @returns boolean
 * @param integer $InstanceID
 */
function AESGI_RequestStatus(integer $InstanceID)
{
    
}

/**
 * AESGI_RequestType
 * 
 * @returns boolean
 * @param integer $InstanceID
 */
function AESGI_RequestType(integer $InstanceID)
{
    
}

/**
 * AESGI_SetCurrentLimit
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param float $Limit
 */
function AESGI_SetCurrentLimit(integer $InstanceID, float $Limit)
{
    
}

/**
 * AESGI_SetPowerReduction
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param integer $Percent
 */
function AESGI_SetPowerReduction(integer $InstanceID, integer $Percent)
{
    
}

/**
 * AESGI_SetRunMode
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param integer $Mode
 * @param float $PowerLimit
 */
function AESGI_SetRunMode(integer $InstanceID, integer $Mode, float $PowerLimit)
{
    
}

/**
 * ALL_ReadConfiguration
 * 
 * @returns boolean
 * @param integer $InstanceID
 */
function ALL_ReadConfiguration(integer $InstanceID)
{
    
}

/**
 * schaltet ein ALLNET Aktor ein/aus
 * 
 * <p>Schaltet den Aktor mit der Gerte ID <b>InstanzID</b> auf dem Kanal <b>KanalID</b> auf den Wert <b>Status</b></p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/allnet/all-switchactor/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param integer $ChannelID ID des zu schaltenden Kanals
 * @param boolean $DeviceOn 
 */
function ALL_SwitchActor(integer $InstanceID, integer $ChannelID, boolean $DeviceOn)
{
    
}

/**
 * schaltet ein ALLNET Gert ein/aus
 * 
 * <p>Schaltet das Gert mit der ID <b>InstanzID</b> auf Wert <b>Status</b></p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/allnet/all-switchmode/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param boolean $DeviceOn 
 */
function ALL_SwitchMode(integer $InstanceID, boolean $DeviceOn)
{
    
}

/**
 * ALL_UpdateValues
 * 
 * @returns boolean
 * @param integer $InstanceID
 */
function ALL_UpdateValues(integer $InstanceID)
{
    
}

/**
 * CC_GetURL
 * 
 * @returns string
 * @param integer $InstanceID
 */
function CC_GetURL(integer $InstanceID)
{
    
}

/**
 * sendet einen String auf den I/O
 * 
 * <p>Sendet den String <b>Text</b> auf dem Client Socket mit der ID <b>InstanzID</b>.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/io/clientsocket/csck-sendtext/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu aktualisierenden Client Sockets
 * @param string $Text der zusendene String
 */
function CSCK_SendText(integer $InstanceID, string $Text)
{
    
}

/**
 * lscht den Buffer der Cutter Instanz
 * 
 * <p>Diese Funktion lscht den Zwischenspeicher (Buffer) der Cutter Instanz mit der ID <b>InstanzID</b>.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/cutter/cutter-clearbuffer/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID zum Cutter
 */
function Cutter_ClearBuffer(integer $InstanceID)
{
    
}

/**
 * dimmt einen Kanal auf einen bestimmten Wert in einer bestimmten Zeit
 * 
 * <p>Dimmt den <b>Kanal</b> des Gerts mit der ID <b>InstanzID</b> auf <b>Wert</b> mit einer bestimmten <b>berblendzeit</b></p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/dmx-lichttechnik/dmx-fadechannel/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param integer $Channel 0 = alle Instanz-Kanle, 1  512 je nach Konfiguration
 * @param integer $Value 0-255
 * @param float $FadingSeconds Zeit in Sekunden
 */
function DMX_FadeChannel(integer $InstanceID, integer $Channel, integer $Value, float $FadingSeconds)
{
    
}

/**
 * dimmt einen Kanal nach einer Verzgerung auf einen bestimmten Wert
 * 
 * <p>Dimmt den Kanal des Gerts mit der ID InstanzID auf Wert mit einer bestimmten berblendzeit. Es kann eine Verzgerungszeit angegeben werden, nach der der Dimmvorgang gestartet wird.</p><p>Wenn keine Verzgerungszeit angegeben wird, bricht dieser Befehl alle fr die betroffenen Kanle verzgertern ber DMX_FadeChannelDelayed gesetzten Fadings ab. Damit kann eine neue Kette an verzgerten Fadings sauber gesetzt werden. Wenn keine verzgerten Fadings genutzt werden, so ist dieser Hinweis nicht relevant</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/dmx-lichttechnik/dmx-fadechanneldelayed/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param integer $Channel 0 = alle Instanz-Kanle, 1  512 je nach Konfiguration
 * @param integer $Value 0-255
 * @param float $FadingSeconds Zeit in Sekunden
 * @param float $DelayedSeconds Zeit in Sekunden
 */
function DMX_FadeChannelDelayed(integer $InstanceID, integer $Channel, integer $Value, float $FadingSeconds, float $DelayedSeconds)
{
    
}

/**
 * dimmt den RGB-Kanal mit einer berblendzeit
 * 
 * <p>Dimmt den Rot-, Grn- und Blaukanal der ID <b>InstanzID</b>  mit einer bestimmten <b>berblendzeit</b>.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/dmx-lichttechnik/dmx-fadergb/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param integer $R Helligkeitswert 0 (aus) bis 255 (an, maximale Helligkeit)
 * @param integer $G Helligkeitswert 0 (aus) bis 255 (an, maximale Helligkeit)
 * @param integer $B Helligkeitswert 0 (aus) bis 255 (an, maximale Helligkeit)
 * @param float $FadingSeconds Zeit in Sekunden
 */
function DMX_FadeRGB(integer $InstanceID, integer $R, integer $G, integer $B, float $FadingSeconds)
{
    
}

/**
 * dimmt verzgert den RGB-Kanal mit einer berblendzeit
 * 
 * <p>Dimmt den Rot-, Grn- und Blaukanal der ID <b>InstanzID</b>  mit einer bestimmten <b>berblendzeit</b>. Es kann eine Verzgerungszeit angegeben werden, nach der der Dimmvorgang gestartet wird.</p><p>Wenn keine Verzgerungszeit angegeben wird, bricht dieser Befehl alle fr die betroffenen Kanle verzgertern ber DMX_FadeRGBDelayed gesetzten Fadings ab. Damit kann eine neue Kette an verzgerten Fadings sauber gesetzt werden. Wenn keine verzgerten Fadings genutzt werden, so ist dieser Hinweis nicht relevant</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/dmx-lichttechnik/dmx-fadergbdelayed/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param integer $R Helligkeitswert 0 (aus) bis 255 (an, maximale Helligkeit)
 * @param integer $G Helligkeitswert 0 (aus) bis 255 (an, maximale Helligkeit)
 * @param integer $B Helligkeitswert 0 (aus) bis 255 (an, maximale Helligkeit)
 * @param float $FadingSeconds Zeit in Sekunden
 * @param float $DelayedSeconds Zeit in Sekunden
 */
function DMX_FadeRGBDelayed(integer $InstanceID, integer $R, integer $G, integer $B, float $FadingSeconds, float $DelayedSeconds)
{
    
}

/**
 * Fragt die Informationen einer DMX Instanz ab
 * 
 * <p>Fragt die Informationen der DMX Instanz mit der ID <b>InstanzID</b> ab.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/dmx-lichttechnik/dmx-requestinfo/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID der DMX Splitter Instanz
 */
function DMX_RequestInfo(integer $InstanceID)
{
    
}

/**
 * setzt ein DMX Interface zurck
 * 
 * <p>Setzt das DMX Splitter Interface mit der ID <b>InstanzID</b> zurck. Es empfiehlt sich, bei Problemen, ein Skript mit diesem Befehl zu erstellen und als Start-Skript zu deklarieren.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/dmx-lichttechnik/dmx-resetinterface/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID der DMX Splitter Instanz
 */
function DMX_ResetInterface(integer $InstanceID)
{
    
}

/**
 * setzt alle 512 Kanle auf 0 oder den alten Wert
 * 
 * <p>Setzt alle Kanle des DMX Interfaces auf Wert <b>Status</b>. Die ID <b>InstanzID</b> ist dabei die InstanzID der Splitter-Instanz.</p><p>Dieser Befehl ist fr ArtNet Gerte nicht verfgbar.</p><p>Dieser Befehl beeinflusst keine Status Variablen der Module.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/dmx-lichttechnik/dmx-setblackout/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param boolean $BlackoutOn 
 */
function DMX_SetBlackOut(integer $InstanceID, boolean $BlackoutOn)
{
    
}

/**
 * setzt einen Kanal auf einen bestimmten Wert
 * 
 * <p>Schaltet den Kanal vom Gert mit der ID <b>InstanzID</b> auf Wert <b>Wert</b></p><p>Dieser Befehl bricht alle fr die betroffenen Kanle ber DMX_FadeChannelDelayed gesetzten Fadings ab.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/dmx-lichttechnik/dmx-setchannel/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param integer $Channel 0 = alle Instanz-Kanle, 1  512 je nach Konfiguration
 * @param integer $Value 0-255
 */
function DMX_SetChannel(integer $InstanceID, integer $Channel, integer $Value)
{
    
}

/**
 * setzt den RGB Kanal auf einen bestimmten Wert
 * 
 * <p>Sendet den Rot-, Grn- und Blaukanal der ID <b>InstanzID</b>.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/dmx-lichttechnik/dmx-setrgb/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param integer $R Helligkeitswert 0 (aus) bis 255 (an, maximale Helligkeit)
 * @param integer $G Helligkeitswert 0 (aus) bis 255 (an, maximale Helligkeit)
 * @param integer $B Helligkeitswert 0 (aus) bis 255 (an, maximale Helligkeit)
 */
function DMX_SetRGB(integer $InstanceID, integer $R, integer $G, integer $B)
{
    
}

/**
 * ruft eine Szene auf
 * 
 * <p>Schaltet das Gert mit der ID <b>InstanzID</b> auf Wert <b>Szene</b>.<br>Weitere Informationen zu den Serverszenen</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/digitalstrom/ds-callscene/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param integer $SceneID Szenen von 0 bis 127
 */
function DS_CallScene(integer $InstanceID, integer $SceneID)
{
    
}

/**
 * dimmt eine digitalSTROM Klemme auf einen bestimmten Wert
 * 
 * <p>Dimmt das Gert mit der ID <b>InstanzID</b> auf Wert <b>Intensitt</b></p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/digitalstrom/ds-dimset/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param integer $Intensity Wert von 0-255
 */
function DS_DimSet(integer $InstanceID, integer $Intensity)
{
    
}

/**
 * DS_GetKnownDevices
 * 
 * @returns array
 * @param integer $InstanceID
 */
function DS_GetKnownDevices(integer $InstanceID)
{
    
}

/**
 * ruft den Status ab
 * 
 * <p>Fragt den Status fr das Gert mit der ID <b>InstanzID</b> ab.</p><p>Dieser Befehl fragt die Klemme ber den dS-Bus ab, was einiges an Zeit in Anspruch nehmen kann. In dieser Zeit ist der dS-Bus belegt und kann keine weiteren Aktionen durchfhren. Sollte der Befehl fr viele Klemmen und oft aufgerufen werden, so kann dies zu sprbaren Verzgerungen im gesamten digitalStrom System fhren.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/digitalstrom/ds-requeststatus/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des Gerts
 */
function DS_RequestStatus(integer $InstanceID)
{
    
}

/**
 * DS_RequestToken
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param string $Username
 * @param string $Password
 */
function DS_RequestToken(integer $InstanceID, string $Username, string $Password)
{
    
}

/**
 * DS_SaveScene
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param integer $SceneID
 */
function DS_SaveScene(integer $InstanceID, integer $SceneID)
{
    
}

/**
 * bewegt den Rolladen bis zu einer gewnschten Position/Stop
 * 
 * <p>Bewegt den Rolladen/Markise/Jalousie mit der ID <b>InstanzID</b> auf die Position <b>Position</b>, bis DS_ShutterStop ausgefhrt wird oder die Zielposition erreicht wird.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/digitalstrom/ds-shuttermove/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param integer $Position Position von 0-255
 */
function DS_ShutterMove(integer $InstanceID, integer $Position)
{
    
}

/**
 * bewegt den Rolladen nach unten bis zur Endposition/Stop
 * 
 * <p>Bewegt den Rolladen/Markise/Jalousie mit der ID <b>InstanzID</b> nach unten, bis DS_ShutterStop ausgefhrt wird oder die Endposition erreicht wird.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/digitalstrom/ds-shuttermovedown/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 */
function DS_ShutterMoveDown(integer $InstanceID)
{
    
}

/**
 * bewegt den Rolladen nach oben bis zur Endposition/Stop
 * 
 * <p>Bewegt den Rolladen/Markise/Jalousie mit der ID <b>InstanzID</b> nach oben, bis DS_ShutterStop ausgefhrt wird oder die Endposition erreicht wird.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/digitalstrom/ds-shuttermoveup/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 */
function DS_ShutterMoveUp(integer $InstanceID)
{
    
}

/**
 * stoppt einen Bewegungsvorgang
 * 
 * <p>Stoppt eine aktuelle Bewegung des/der Rolladens/Markise/Jalousie.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/digitalstrom/ds-shutterstop/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 */
function DS_ShutterStop(integer $InstanceID)
{
    
}

/**
 * schaltet eine digitalSTROM Klemme an/aus
 * 
 * <p>Schaltet das Gert mit der ID <b>InstanzID</b> auf Wert <b>Status</b>.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/digitalstrom/ds-switchmode/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param boolean $DeviceOn 
 */
function DS_SwitchMode(integer $InstanceID, boolean $DeviceOn)
{
    
}

/**
 * DS_UndoScene
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param integer $SceneID
 */
function DS_UndoScene(integer $InstanceID, integer $SceneID)
{
    
}

/**
 * Sendet einen einzelnen Buchstaben
 * 
 * <p>Sendet einen einzelnen Buchstaben <b>Buchstabe</b> an das Gert mit der ID <b>InstanzID</b>.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/eib-knx/eib-char/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param string $Value Einzelner Buchstabe
 */
function EIB_Char(integer $InstanceID, string $Value)
{
    
}

/**
 * EIB_Counter16bit
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param integer $Value
 */
function EIB_Counter16bit(integer $InstanceID, integer $Value)
{
    
}

/**
 * EIB_Counter32bit
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param integer $Value
 */
function EIB_Counter32bit(integer $InstanceID, integer $Value)
{
    
}

/**
 * EIB_Counter8bit
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param integer $Value
 */
function EIB_Counter8bit(integer $InstanceID, integer $Value)
{
    
}

/**
 * sendet den Datumswert
 * 
 * <p>Sendet den Datumswert <b>Datum</b> an das Gert mit der ID <b>InstanzID</b>.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/eib-knx/eib-date/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param string $Value Standard = yyyymmdd
 */
function EIB_Date(integer $InstanceID, string $Value)
{
    
}

/**
 * sendet eine Dimmwertverstellung
 * 
 * <p>Sendet eine Dimmwertverstellung um <b>Wert</b> an das Gert mit der ID <b>InstanzID</b>. Je nach Konfiguration kann 0..15 (Standard) oder -7..7 (Enhanced) gesendet werden.</p><p>Da diese Funktion nur eine relative Vernderungen des Dimmers vornimmt, kann die Helligkeit nicht absolut angegeben werden. Es wird empfohlen eine 8-Bit Adresse anzulegen, um direkte Dimmwerte setzen zu knnen.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/eib-knx/eib-dimcontrol/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param integer $Value Dimmwertverstellung zwischen 0..15 oder -7..7
 */
function EIB_DimControl(integer $InstanceID, integer $Value)
{
    
}

/**
 * sendet einen Dimmwert als Zahl oder Prozent
 * 
 * <p>Sendet den Dimmwert <b>Wert</b> an das Gert mit der ID <b>InstanzID</b>. Je nach Konfiguration kann 0..255 (Standard) oder 0..100 (Percent) als Wert Parameter bergeben werden.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/eib-knx/eib-dimvalue/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param integer $Value Wert 0..255, 0..100%
 */
function EIB_DimValue(integer $InstanceID, integer $Value)
{
    
}

/**
 * sendet einen Positionswert als Zahl oder Prozent
 * 
 * <p>Sendet den Positionswert <b>Wert</b> an das Gert mit der ID <b>InstanzID</b>. Je nach Konfiguration kann 0..255 (Standard) oder 0..100 (Percent) als Wert Parameter bergeben werden.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/eib-knx/eib-drivebladevalue/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param integer $Value Wert 0..255, 0..100%
 */
function EIB_DriveBladeValue(integer $InstanceID, integer $Value)
{
    
}

/**
 * bewegt ein Gert Hoch oder Runter
 * 
 * <p>Bewegt das Gert mit ID <b>InstanzID</b> in eine bestimmt <b>Richtung</b>. Je nach Konfiguration kann die Bewegungsrichtung invertiert werden.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/eib-knx/eib-drivemove/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param boolean $Value Standart: False = Hoch, True = Runter; Invert: True = Hoch, False = Runter
 */
function EIB_DriveMove(integer $InstanceID, boolean $Value)
{
    
}

/**
 * sendet einen Positionswert als Zahl oder Prozent
 * 
 * <p>Sendet den Positionswert <b>Wert</b> an das Gert mit der ID <b>InstanzID</b>. Je nach Konfiguration kann 0..255 (Standard) oder 0..100 (Percent) als Wert Parameter bergeben werden.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/eib-knx/eib-driveshuttervalue/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param integer $Value Wert 0..255, 0..100%
 */
function EIB_DriveShutterValue(integer $InstanceID, integer $Value)
{
    
}

/**
 * bewegt ein Gert schrittweise
 * 
 * <p>Bewegt das Gert <em>schrittweise</em> mit ID <b>InstanzID</b> in eine bestimmt <b>Richtung</b> in Bewegung. Je nach Konfiguration kann die Bewegungsrichtung invertiert werden.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/eib-knx/eib-drivestep/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param boolean $Value Standard: False = Hoch, True = Runter; Invert: True = Hoch, False = Runter
 */
function EIB_DriveStep(integer $InstanceID, boolean $Value)
{
    
}

/**
 * sendet einen Floatwert
 * 
 * <p>Sendet den Wert <b>Wert</b> an das Gert mit der ID <b>InstanzID</b>.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/eib-knx/eib-floatvalue/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param float $Value Fliekommawert
 */
function EIB_FloatValue(integer $InstanceID, float $Value)
{
    
}

/**
 * EIB_GetKnownDevices
 * 
 * @returns array
 * @param integer $InstanceID
 */
function EIB_GetKnownDevices(integer $InstanceID)
{
    
}

/**
 * bewegt einen Rolladen
 * 
 * <p>Bewegt den Rolladen mit der <b>InstanzID</b> in die gewnschte <b>Richtung</b>.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/eib-knx/eib-move/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID der KNX Shutter Instanz
 * @param integer $Command 0 = Hoch, 1 = Schritt (Hoch), 2 = Stop, 3 = Schritt (Runter), 4 = Runter
 *   enum[0=emcOpen, 1=emcStepOpen, 2=emcStop, 3=emcStepClose, 4=emcClose]
 */
function EIB_Move(integer $InstanceID, integer $Command)
{
    
}

/**
 * bewegt einen Rolladen auf eine Position
 * 
 * <p>Bewegt den Rolladen mit der <b>InstanzID</b> auf die gewnschte <b>Position</b>.</p><p>Dieser Befehl funktioniert nur, wenn Ihr KNX-Gert eine absolute Positionierung untersttzt</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/eib-knx/eib-position/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID der KNX Shutter Instanz
 * @param integer $Position 0-100%
 */
function EIB_Position(integer $InstanceID, integer $Position)
{
    
}

/**
 * setzt einen Gertezustand
 * 
 * <p>Setzt das Gert mit ID <b>InstanzID</b> auf einen bestimmten <b>Zustand</b>.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/eib-knx/eib-prioritycontrol/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param integer $Value Standard: 0..3; Enhanced: -1 = Aus, 0 = N/A, 1 = An
 */
function EIB_PriorityControl(integer $InstanceID, integer $Value)
{
    
}

/**
 * setzt ein Gert in eine bestimmte Richtung
 * 
 * <p>Setzt das Gert mit ID <b>InstanzID</b> auf eine bestimmte <b>Richtung</b>. Je nach Konfiguration kann die Richtung invertiert werden.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/eib-knx/eib-priorityposition/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param boolean $Value Standard: False = Hoch, True = Runter; Invert: True = Hoch, False = Runter
 */
function EIB_PriorityPosition(integer $InstanceID, boolean $Value)
{
    
}

/**
 * EIB_RequestInfo
 * 
 * @returns boolean
 * @param integer $InstanceID
 */
function EIB_RequestInfo(integer $InstanceID)
{
    
}

/**
 * schickt eine Leseanfrage auf den Bus
 * 
 * <p>Schickt eine Lesenanfrage fr Gert mit der ID <b>InstanzID</b> auf den Bus.</p><p>Die Leseanfrage wird nur fr die Hauptadresse versendet.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/eib-knx/eib-requeststatus/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des Gerts
 */
function EIB_RequestStatus(integer $InstanceID)
{
    
}

/**
 * sendet einen Zahl-, Prozent- oder Gradwert.
 * 
 * <p>Sendet den Wert <b>Wert</b> an das Gert mit der ID <b>InstanzID</b>. Je nach Konfiguration kann 0..255 (Standard), 0..100 (Percent) oder 0..360 (Degree) als Wert Parameter bergeben werden.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/eib-knx/eib-scale/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param integer $Value Wert 0..255, 0..100, 0..360
 */
function EIB_Scale(integer $InstanceID, integer $Value)
{
    
}

/**
 * EIB_SearchDevices
 * 
 * @returns boolean
 * @param integer $InstanceID
 */
function EIB_SearchDevices(integer $InstanceID)
{
    
}

/**
 * setzt einen RGB Stripe auf einen bestimmten Farbton
 * 
 * <p>Setzt den RGB Stripe des Gerts mit der ID <b>InstanzID</b> auf den Rotwert <b>Rot</b>, den Grnwert <b>Grn</b> und den Blauwert <b>Blau</b>.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/eib-knx/eib-setrgb/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param integer $R 0 .. 255 (0 = aus, 255 = hell)
 * @param integer $G 0 .. 255 (0 = aus, 255 = hell)
 * @param integer $B 0 .. 255 (0 = aus, 255 = hell)
 */
function EIB_SetRGB(integer $InstanceID, integer $R, integer $G, integer $B)
{
    
}

/**
 * setzt einen RGBW Stripe auf einen bestimmten Farbton
 * 
 * <p>Setzt den RGBW Stripe des Gerts mit der ID <b>InstanzID</b> auf den Rotwert <b>Rot</b>, den Grnwert <b>Grn</b>, den Blauwert <b>Blau</b> und den Weianteil auf <b>Weiss</b>.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/eib-knx/eib-setrgbw/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param integer $R 0 .. 255 (0 = aus, 255 = hell)
 * @param integer $G 0 .. 255 (0 = aus, 255 = hell)
 * @param integer $B 0 .. 255 (0 = aus, 255 = hell)
 * @param integer $W 0 .. 255 (0 = aus, 255 = hell)
 */
function EIB_SetRGBW(integer $InstanceID, integer $R, integer $G, integer $B, integer $W)
{
    
}

/**
 * sendet einen Text
 * 
 * <p>Sendet einen Text <b>Zeichenkette</b> an das Gert mit der ID <b>InstanzID</b>.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/eib-knx/eib-str/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param string $Value Zu sendender Text (maximal 14 Zeichen)
 */
function EIB_Str(integer $InstanceID, string $Value)
{
    
}

/**
 * schaltet ein Gert Ein/Aus
 * 
 * <p>Schaltet das Gert mit der ID <b>InstanzID</b> auf Wert <b>Status</b></p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/eib-knx/eib-switch/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param boolean $Value 
 */
function EIB_Switch(integer $InstanceID, boolean $Value)
{
    
}

/**
 * sendet einen Zeitwert
 * 
 * <p>Sendet den Zeitwert <b>Zeit</b> an das Gert mit der ID <b>InstanzID</b>. Der d Wert ist dabei zwischen 1 (Montag) und 7 (Sonntag).</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/eib-knx/eib-time/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param string $Value Standard = dhhmmss; TimeOnly = hhmmss
 */
function EIB_Time(integer $InstanceID, string $Value)
{
    
}

/**
 * EIB_UploadDataPointFile
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param string $Content
 */
function EIB_UploadDataPointFile(integer $InstanceID, string $Content)
{
    
}

/**
 * sendet einen Floatwert
 * 
 * <p>Sendet den Wert <b>Wert</b> an das Gert mit der ID <b>InstanzID</b>.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/eib-knx/eib-value/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param float $Value -671088,63 .. 670760,96
 */
function EIB_Value(integer $InstanceID, float $Value)
{
    
}

/**
 * dimmt ein EnOcean Gert auf eine bestimmte Helligkeit
 * 
 * <p>Dimmt das Gert mit der ID <b>InstanzID</b> auf den Wert <b>Intensitt</b>.</p><p>Diese Funktion kann nur mit Eltako Dimmer Instanzen verwendet werden.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/enocean/eno-dimset/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID der Instanz des zu schaltenden Gertes
 * @param integer $Intensity 1..100
 */
function ENO_DimSet(integer $InstanceID, integer $Intensity)
{
    
}

/**
 * ENO_SendCST
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param boolean $value
 */
function ENO_SendCST(integer $InstanceID, boolean $value)
{
    
}

/**
 * ENO_SendCTM
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param integer $value
 */
function ENO_SendCTM(integer $InstanceID, integer $value)
{
    
}

/**
 * ENO_SendCV
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param float $value
 */
function ENO_SendCV(integer $InstanceID, float $value)
{
    
}

/**
 * ENO_SendERH
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param boolean $value
 */
function ENO_SendERH(integer $InstanceID, boolean $value)
{
    
}

/**
 * ENO_SendFANOR
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param integer $value
 */
function ENO_SendFANOR(integer $InstanceID, integer $value)
{
    
}

/**
 * ENO_SendFANOR_2
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param boolean $value
 */
function ENO_SendFANOR_2(integer $InstanceID, boolean $value)
{
    
}

/**
 * ENO_SendLearn
 * 
 * @returns boolean
 * @param integer $InstanceID
 */
function ENO_SendLearn(integer $InstanceID)
{
    
}

/**
 * ENO_SendRO
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param integer $value
 */
function ENO_SendRO(integer $InstanceID, integer $value)
{
    
}

/**
 * ENO_SendSPS
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param float $value
 */
function ENO_SendSPS(integer $InstanceID, float $value)
{
    
}

/**
 * setzt eine bestimmte Message aktiv
 * 
 * <p>Setzt eine Message mit dem Wert <b>Message</b> auf der Instanz mit der ID <b>InstanzID</b> aktiv.</p><p>Diese Funktion kann nur mit EnOcean Thanos Instanzen verwendet werden.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/enocean/eno-setactivemessage/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID der Instanz des zu schaltenden Gertes
 * @param integer $Message 0..8
 */
function ENO_SetActiveMessage(integer $InstanceID, integer $Message)
{
    
}

/**
 * ENO_SetButtonLock
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param boolean $Active
 */
function ENO_SetButtonLock(integer $InstanceID, boolean $Active)
{
    
}

/**
 * setzt die FanStage auf einen bestimmten Wert
 * 
 * <p>Setzt die FanStage des Gerts mit der ID <b>InstanzID</b> auf den Wert <b>Fanstage</b>.</p><li>0  off</li><li>1  low</li><li>2  medium</li><li>3  high</li><li>4  automatic</li><p>Diese Funktion kann nur mit EnOcean Thanos Instanzen verwendet werden.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/enocean/eno-setfanstage/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID der Instanz des zu schaltenden Gertes
 * @param integer $FanStage 0..4
 */
function ENO_SetFanStage(integer $InstanceID, integer $FanStage)
{
    
}

/**
 * dimmt den Opus-Dimmer auf eine bestimmte Helligkeit
 * 
 * <p>Dimmt das Gert mit der ID <b>InstanzID</b> auf den Wert <b>Intensitt</b>. Der Wert <b>Status</b> gibt an, ob das Gert an/aus geschaltet werden soll.</p><p>Da das EnOcean System unidirektional ist, kann nicht festgestellt werden, ob der Befehl erfolgreich war. Fehlermeldungen werden nur gesendet, wenn ein systeminterner Fehler aufgetreten ist (z.B. wenn das Interface nicht angeschlossen ist).</p><p>Das EnOcean Protokoll sieht keine Dimmfunktion vor. Der Opus-Dimmer wird durch einen Trick ber eine Zeitfunktion angesteuert, sodass das Resultat der Helligkeit je nach Vorgang ein wenig abweichen kann. Die Prozentwerte sind nur ungefhr und es kann keine lineare Helligkeitssteigerung angenommen werden.</p><p>Diese Funktion kann nur mit der Opus Dimmer Instanz verwendet werden.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/enocean/eno-setintensity/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID der Instanz des zu schaltenden Gertes
 * @param boolean $DeviceOn 
 * @param integer $Intensity 1..20, 1 = 5%, 20 = 100%
 */
function ENO_SetIntensity(integer $InstanceID, boolean $DeviceOn, integer $Intensity)
{
    
}

/**
 * locked die FanStage
 * 
 * <p>Locked die FanStage des Gertes mit der ID <b>InstanzID</b>.</p><p>Diese Funktion kann nur mit EnOcean Thanos Instanzen verwendet werden.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/enocean/eno-setlockfanstage/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID der Instanz des zu schaltenden Gertes
 * @param boolean $Locked 
 */
function ENO_SetLockFanStage(integer $InstanceID, boolean $Locked)
{
    
}

/**
 * locked die Occupancy
 * 
 * <p>Locked die Occupancy des Gertes mit der ID <b>InstanzID</b>.</p><p>Diese Funktion kann nur mit EnOcean Thanos Instanzen verwendet werden.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/enocean/eno-setlockroomoccupancy/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID der Instanz des zu schaltenden Gertes
 * @param boolean $Locked 
 */
function ENO_SetLockRoomOccupancy(integer $InstanceID, boolean $Locked)
{
    
}

/**
 * ENO_SetMeasureTemperature
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param boolean $Active
 */
function ENO_SetMeasureTemperature(integer $InstanceID, boolean $Active)
{
    
}

/**
 * setzt den Stellantrieb in einen bestimmten Modus
 * 
 * <p>Setzt den Modus vom Stellantrieb mit der ID <b>InstanzID</b> auf den Wert <b>Value</b>.</p><li>0  Default</li><li>1  Summer Mode</li><li>2  TestClose</li><li>3  TestOpen</li><li>4  Liftset</li><li>5  Init</li>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/enocean/eno-setmode/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID der Instanz des zu schaltenden Gertes
 * @param integer $Mode 0..5
 */
function ENO_SetMode(integer $InstanceID, integer $Mode)
{
    
}

/**
 * setzt die Position des Stellantriebes
 * 
 * <p>Setzt die Position des Stellantriebes mit der ID <b>InstanzID</b> auf den Wert <b>Value</b></p><p>Der Modus des Stellantriebes muss auf "Valve position" stehen, damit diese Funktion aufgerufen werden kann.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/enocean/eno-setposition/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID der Instanz des zu schaltenden Gertes
 * @param integer $Position 1..100
 */
function ENO_SetPosition(integer $InstanceID, integer $Position)
{
    
}

/**
 * setzt die Occupancy auf True/False
 * 
 * <p>Setzt die Occupancy ("Raumbelegung") des Gertes mit der ID <b>InstanzID</b> auf den Wert <b>Occupied</b>.</p><p>Diese Funktion kann nur mit EnOcean Thanos Instanzen verwendet werden.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/enocean/eno-setroomoccupancy/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID der Instanz des zu schaltenden Gertes
 * @param boolean $Occupied 
 */
function ENO_SetRoomOccupancy(integer $InstanceID, boolean $Occupied)
{
    
}

/**
 * setzt den Stellantrieb auf eine bestimmte Soll-Temperatur
 * 
 * <p>Setzt den Soll-Temperaturwert des Stellantriebes mit der ID <b>InstanzID</b> auf den Wert <b>Value</b>.</p><p>Der Modus des Stellantriebes muss auf "Temperature Setpoint" stehen, damit diese Funktion aufgerufen werden.</p><p>Soll ein EnOcean Thanos Gert auf eine Soll-Temperatur eingestellt werden ist der Befehl [<b>ENO_SetTemperature1</b>][tempthanos] zu nutzen.</p><p></p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/enocean/eno-settemperature/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID der Instanz des zu schaltenden Gertes
 * @param float $Temperature 1...100
 */
function ENO_SetTemperature(integer $InstanceID, float $Temperature)
{
    
}

/**
 * setzt das Gert auf eine bestimmte Temperatur
 * 
 * <p>Setzt den Temperaturwert des Gertes mit der ID <b>InstanzID</b> auf den Wert <b>Temperature</b>.</p><p>Diese Funktion kann nur mit EnOcean Thanos Instanzen verwendet werden. Soll ein Stellantrieb auf eine Soll-Temperatur eingestellt werden ist der Befehl [<b>ENO_SetTemperature</b>][tempstellantrieb] zu nutzen.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/enocean/eno-settemperature1/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID der Instanz des zu schaltenden Gertes
 * @param float $Temperature 1..100
 */
function ENO_SetTemperature1(integer $InstanceID, float $Temperature)
{
    
}

/**
 * bewegt den Rolladen nach unten bis zur Endposition/Stop
 * 
 * <p>Bewegt den Rolladen mit der ID InstanzID nach unten, bis ENO_ShutterStop ausgefhrt oder die Endposition erreicht wird.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/enocean/eno-shuttermovedown/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID der Instanz des zu schaltenden Gertes
 */
function ENO_ShutterMoveDown(integer $InstanceID)
{
    
}

/**
 * bewegt den Rolladen nach oben bis zur Endposition/Stop
 * 
 * <p>Bewegt den Rolladen mit der ID InstanzID nach oben, bis ENO_ShutterStop ausgefhrt oder die Endposition erreicht wird.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/enocean/eno-shuttermoveup/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID der Instanz des zu schaltenden Gertes
 */
function ENO_ShutterMoveUp(integer $InstanceID)
{
    
}

/**
 * stoppt einen Bewegungsvorgang
 * 
 * <p>Stoppt eine aktuelle Bewegung des Rolladens.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/enocean/eno-shutterstop/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID der Instanz des zu schaltenden Gertes
 */
function ENO_ShutterStop(integer $InstanceID)
{
    
}

/**
 * schaltet ein EnOcean Gert ein/aus
 * 
 * <p>Schaltet das Gert mit der ID <b>InstanzID</b> auf den Wert <b>Status</b></p><p>Da das EnOcean System unidirektonal ist, kann nicht festgestellt werden, ob der Befehl erfolgreich war. Fehlermeldungen werden nur gesendet, wenn ein systeminterner Fehler aufgetreten ist, z.B. wenn das Interface nicht angeschlossen ist.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/enocean/eno-switchmode/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID der Instanz des zu schaltenden Gertes
 * @param boolean $DeviceOn 
 */
function ENO_SwitchMode(integer $InstanceID, boolean $DeviceOn)
{
    
}

/**
 * sendet einen erweiterten Schaltbefehl
 * 
 * <p>Schaltet das Gert mit der ID <b>InstanzID</b> auf den Wert <b>Status</b></p><p>Da das EnOcean System unidirektonal ist, kann nicht festgestellt werden, ob der Befehl erfolgreich war. Fehlermeldungen werden nur gesendet, wenn ein systeminterner Fehler aufgetreten ist, z.B. wenn das Interface nicht angeschlossen ist.</p><p>Fr die Erklrung der NMessage und UMessage wenden Sie sich bitte an die EnOcean Dokumentation.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/enocean/eno-switchmodeex/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID der Instanz des zu schaltenden Gertes
 * @param boolean $DeviceOn 
 * @param integer $SendMode 0 = NMessage, 1 = UMessage, 2 = Beide (Wie
 *   enum[0=smNMessage, 1=smUMessage, 2=smBoth]
 */
function ENO_SwitchModeEx(integer $InstanceID, boolean $DeviceOn, integer $SendMode)
{
    
}

/**
 * FHT_RequestData
 * 
 * @returns boolean
 * @param integer $InstanceID
 */
function FHT_RequestData(integer $InstanceID)
{
    
}

/**
 * FHT_SetDay
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param integer $Value
 */
function FHT_SetDay(integer $InstanceID, integer $Value)
{
    
}

/**
 * FHT_SetHour
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param integer $Value
 */
function FHT_SetHour(integer $InstanceID, integer $Value)
{
    
}

/**
 * FHT_SetMinute
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param integer $Value
 */
function FHT_SetMinute(integer $InstanceID, integer $Value)
{
    
}

/**
 * sendet einen neuen Soll-Modus an den FHT
 * 
 * <p>Setzt den neuen Soll-Modus fr den FHT mit der ID <b>InstanzID</b> auf Wert <b>Modus</b>.</p><p>Da das FS20 System unidirektonal ist, kann nicht festgestellt werden, ob der Befehl erfolgreich war. Fehlermeldungen werden nur gesendet, wenn ein systeminterner Fehler aufgetreten ist, z.B., wenn die FHZ nicht angeschlossen ist.</p><p>Die FHT Befehle werden von der FHZ zwischengepuffert und nur alle paar Minuten an den FHT gesendet. Bitte beachten Sie, dass der Sendepuffer beschrnkt ist und mehrmaliges Senden von Werten die bertragungszeit erhht und ggf. den FHT berlastet.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/fhz1x00pc/fht/fht-setmode/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param integer $Mode 
 */
function FHT_SetMode(integer $InstanceID, integer $Mode)
{
    
}

/**
 * FHT_SetMonth
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param integer $Value
 */
function FHT_SetMonth(integer $InstanceID, integer $Value)
{
    
}

/**
 * sendet eine neue Soll-Temperatur an den FHT
 * 
 * <p>Setzt die neue Soll-Temperatur fr den FHT mit der ID <b>InstanzID</b> auf Wert <b>Temperatur</b>.</p><p>Da das FS20 System unidirektonal ist, kann nicht festgestellt werden, ob der Befehl erfolgreich war. Fehlermeldungen werden nur gesendet, wenn ein systeminterner Fehler aufgetreten ist, z.B., wenn die FHZ nicht angeschlossen ist.</p><p>Die FHT Befehle werden von der FHZ zwischengepuffert und nur alle paar Minuten an den FHT gesendet. Bitte beachten Sie, dass der Sendepuffer beschrnkt ist und mehrmaliges Senden von Werten die bertragungszeit erhht und ggf. den FHT berlastet.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/fhz1x00pc/fht/fht-settemperature/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param float $Temperature Temperaturwert in 0,5C Schritten
 */
function FHT_SetTemperature(integer $InstanceID, float $Temperature)
{
    
}

/**
 * FHT_SetYear
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param integer $Value
 */
function FHT_SetYear(integer $InstanceID, integer $Value)
{
    
}

/**
 * FHZ_GetFHTQueue
 * 
 * @returns array
 * @param integer $InstanceID
 */
function FHZ_GetFHTQueue(integer $InstanceID)
{
    
}

/**
 * FHZ_GetFreeBuffer
 * 
 * @returns integer
 * @param integer $InstanceID
 */
function FHZ_GetFreeBuffer(integer $InstanceID)
{
    
}

/**
 * dimmt ein FS20 Gert eine Stufe runter
 * 
 * <p>Dimmt das Gert mit der ID <b>InstanzID</b> eine Stufe runter.</p><p>Da das FS20 System unidirektonal ist, kann nicht festgestellt werden, ob der Befehl erfolgreich war. Fehlermeldungen werden nur gesendet, wenn ein systeminterner Fehler aufgetreten ist, z.B., wenn die FHZ nicht angeschlossen ist.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/fhz1x00pc/fs20/fs20-dimdown/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 */
function FS20_DimDown(integer $InstanceID)
{
    
}

/**
 * dimmt ein FS20 Gert ein Stufe hher
 * 
 * <p>Dimmt das Gert mit der ID <b>InstanzID</b> eine Stufe hher.</p><p>Da das FS20 System unidirektonal ist, kann nicht festgestellt werden, ob der Befehl erfolgreich war. Fehlermeldungen werden nur gesendet, wenn ein systeminterner Fehler aufgetreten ist, z.B., wenn die FHZ nicht angeschlossen ist.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/fhz1x00pc/fs20/fs20-dimup/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 */
function FS20_DimUp(integer $InstanceID)
{
    
}

/**
 * dimmt ein FS20 Gert in einer bestimmten Zeitspanne
 * 
 * <p>Dimmt das Gert mit der ID <b>InstanzID</b> auf Wert <b>Intensitt</b> in <b>Dauer</b> Sekunden.</p><p>Da das FS20 System unidirektonal ist, kann nicht festgestellt werden, ob der Befehl erfolgreich war. Fehlermeldungen werden nur gesendet, wenn ein systeminterner Fehler aufgetreten ist, z.B., wenn die FHZ nicht angeschlossen ist.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/fhz1x00pc/fs20/fs20-setintensity/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param integer $Intensity 0-16 (0=0%, 16=100%)
 * @param integer $Duration Dauer des Dimmvorgangs
 */
function FS20_SetIntensity(integer $InstanceID, integer $Intensity, integer $Duration)
{
    
}

/**
 * schaltet ein FS20 Gert fr eine bestimmte Zeit ein/aus
 * 
 * <p>Schaltet das Gert mit der ID <b>InstanzID</b> auf Wert <b>Status</b> fr <b>Dauer</b> Sekunden.</p><p>Die Anzahl der Sekunden wird auf den nchstmglichen Wert gerundet, den die Timer-Funktion im FS0 Gert erlaubt. Mgliche Werte entnehmen Sie z.B. der Wertetabelle Ihres FS20 PIR Handbuchs auf Seite 28.</p><p>Da das FS20 System unidirektonal ist, kann nicht festgestellt werden, ob der Befehl erfolgreich war. Fehlermeldungen werden nur gesendet, wenn ein systeminterner Fehler aufgetreten ist, z.B., wenn die FHZ nicht angeschlossen ist.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/fhz1x00pc/fs20/fs20-switchduration/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param boolean $DeviceOn 
 * @param integer $Duration Ein-/Ausschaltdauer in Sekunden
 */
function FS20_SwitchDuration(integer $InstanceID, boolean $DeviceOn, integer $Duration)
{
    
}

/**
 * schaltet ein FS20 Gert ein/aus
 * 
 * <p>Schaltet das Gert mit der ID <b>InstanzID</b> auf Wert <b>Status</b>.</p><p>Da das FS20 System unidirektonal ist, kann nicht festgestellt werden, ob der Befehl erfolgreich war. Fehlermeldungen werden nur gesendet, wenn ein systeminterner Fehler aufgetreten ist, z.B., wenn die FHZ nicht angeschlossen ist.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/fhz1x00pc/fs20/fs20-switchmode/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param boolean $DeviceOn 
 */
function FS20_SwitchMode(integer $InstanceID, boolean $DeviceOn)
{
    
}

function GetValue(integer $VariableID)
{
    
}

/**
 * holt den Wert einer IP-Symcon Variable vom Typ Boolean
 * 
 * <p>Der Befehl liefert als Ergebnis den Inhalt der externen Variablen mit der ID <b>VariablenID</b>. Die gewhlte Variable muss vom Typ Boolean sein. Wenn nicht, bricht die Funktion mit einem Fehler ab. Eine Konvertierung wird nicht vorgenommen. Fr eine typunsichere Abfrage knnen Sie die GetValue Funktion nutzen.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/variablenzugriff/getvalueboolean/
 * @returns boolean <p>Wert der angegebenen Variable: <b>TRUE/FALSE</b></p>
 * @param integer $VariableID ID der Variable
 */
function GetValueBoolean(integer $VariableID)
{
    
}

/**
 * holt den Wert einer IP-Symcon Variable vom Typ Float
 * 
 * <p>Der Befehl liefert als Ergebnis den Inhalt der externen Variablen mit der ID <b>VariablenID</b>. Die gewhlte Variable muss vom Typ Float sein. Wenn nicht, bricht die Funktion mit einem Fehler ab. Eine Konvertierung wird nicht vorgenommen. Fr eine typunsichere Abfrage knnen Sie die GetValue Funktion nutzen.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/variablenzugriff/getvaluefloat/
 * @returns float <p>Wert der angegebenen Variable: <b>64Bit Gleitkommazahl</b></p>
 * @param integer $VariableID ID der Variable
 */
function GetValueFloat(integer $VariableID)
{
    
}

/**
 * holt den Wert einer IP-Symcon Variable und formatiert ihn anhand des Profils
 * 
 * <p>Der Befehl liefert als Ergebnis den Inhalt der externen Variablen mit der ID <b>VariablenID</b>, nachdem er passend zum Variablenprofil formatiert wurde. Der zurckgelieferte Variablentyp ist dabei durch die Formatierung immer String.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/variablenzugriff/getvalueformatted/
 * @returns string <p>Wert der angegebenen Variable passend zum Profil formatiert</p>
 * @param integer $VariableID ID der Variable
 */
function GetValueFormatted(integer $VariableID)
{
    
}

/**
 * holt den Wert einer IP-Symcon Variable vom Typ Integer
 * 
 * <p>Der Befehl liefert als Ergebnis den Inhalt der externen Variablen mit der ID <b>VariablenID</b>. Die gewhlte Variable muss vom Typ Integer sein. Wenn nicht, bricht die Funktion mit einem Fehler ab. Eine Konvertierung wird nicht vorgenommen. Fr eine typunsichere Abfrage knnen Sie die GetValue Funktion nutzen.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/variablenzugriff/getvalueinteger/
 * @returns integer <p>Wert der angegebenen Variable: <b>-2,147,483,648 .. 2,147,483,647</b></p>
 * @param integer $VariableID ID der Variable
 */
function GetValueInteger(integer $VariableID)
{
    
}

/**
 * holt den Wert einer IP-Symcon Variable vom Typ String
 * 
 * <p>Der Befehl liefert als Ergebnis den Inhalt der externen Variablen mit der ID <b>VariablenID</b>. Die gewhlte Variable muss vom Typ String sein. Wenn nicht, bricht die Funktion mit einem Fehler ab. Eine Konvertierung wird nicht vorgenommen. Fr eine typunsichere Abfrage knnen Sie die GetValue Funktion nutzen.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/variablenzugriff/getvaluestring/
 * @returns string <p>Wert der angegebenen Variable: Text</p>
 * @param integer $VariableID ID der Variable
 */
function GetValueString(integer $VariableID)
{
    
}

/**
 * sendet einen Soll Wert an das Heating-Modul
 * 
 * <p>Sendet ber die Instanz mit der ID <b>InstanzID</b> einen Soll-Wert an das Heating-Modul.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/heating-control/hc-targetvalue/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param float $Value Neuer Soll-Wert
 */
function HC_TargetValue(integer $InstanceID, float $Value)
{
    
}

/**
 * sendet einen String auf den I/O
 * 
 * <p>Sendet den String <b>Text</b> und dem Datensatztyp <b>ReportID</b> auf dem HID mit der ID <b>InstanzID</b>.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/io/hid/hid-sendevent/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu aktualisierenden HIDs
 * @param integer $ReportID ID der zu sendenen ReportID
 * @param string $Text der zusendene String
 */
function HID_SendEvent(integer $InstanceID, integer $ReportID, string $Text)
{
    
}

/**
 * lst den FI Schalter aus
 * 
 * <p>Lst den FI Trenner ber das HMS Gert mit der ID <b>InstanzID</b> aus. Der  <b>Auslseverzgerung</b> Parameter wird in Sekunden angegeben.</p><p>Da das FS20 System unidirektonal ist, kann nicht festgestellt werden, ob der Befehl erfolgreich war. Fehlermeldungen werden nur gesendet, wenn ein systeminterner Fehler aufgetreten ist, z.B., wenn die FHZ nicht angeschlossen ist.</p><p>Wenn der FI Trenner keinen FI auslsen kann, wird seine Status Variable auf <b>FALSE</b> gesetzt.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/fhz1x00pc/hms/hms-releasefi/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param integer $Delay Verzgerung in Sekunden
 */
function HMS_ReleaseFI(integer $InstanceID, integer $Delay)
{
    
}

/**
 * HM_GetKnownDevices
 * 
 * @returns array
 * @param integer $InstanceID
 */
function HM_GetKnownDevices(integer $InstanceID)
{
    
}

/**
 * HM_LoadDevices
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param integer $Protocol
 *   enum[0=hmpRadio, 1=hmpWired]
 */
function HM_LoadDevices(integer $InstanceID, integer $Protocol)
{
    
}

/**
 * liest die Service-Meldungen aus
 * 
 * <p>Liest die Service-Meldungen des CCU/LAN-Adapters mit der ID <b>InstanzID</b> aus.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/homematic/hm-readservicemessages/
 * @returns array <p>Folgende Informationen stehen als <b>key =&gt; value</b> Paare zur Verfgung:</p><li><b>Address</b>  string  Adresse des betreffenden Gerts</li><li><b>Message</b>  string  Kryptische Beschreibung der Fehlermeldung. Text kann teilweise der stringtable_de.txt aus dem HomeMatic Konfigurationstool entnommen werden.</li><li><b>Value</b>  variant  Wert der Fehlermeldung</li>
 * @param integer $InstanceID ID der HomeMatic Socket Instanz
 */
function HM_ReadServiceMessages(integer $InstanceID)
{
    
}

/**
 * fragt den Ist-Wert vom Gert ab
 * 
 * <p>Fragt den <b>Parameter</b> des Gertes mit der ID <b>InstanzID</b> ab.</p><p>Den einzutragenen <b>$Parameter</b> knnen Sie anhand des Idents der Statusvariablen der Instanz ableiten. In der Parameterliste werden einige Beispiele gegeben.</p><p><b>Diese Funktion belastet den Funkverkehr erheblich.</b>Sie sollte ausschliesslich verwendet werden, um kritische Gerte zum IP-Symcon-Start zu aktualisieren. Ein erneutes Abfragen zur Laufzeit wird nicht bentigt, da die HomeMatic alle Statusnderungen direkt an IP-Symcon weiterleitet.</p><p>Bei batteriebetriebenen Gerten wird nur der gespeicherte Status des CCU/LAN-Adapters abgefragt. Netzbetriebene Gerte werden per Funk direkt abgefragt.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/homematic/hm-requeststatus/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID der Instanz des zu schaltenden Gertes
 * @param string $Parameter 
 */
function HM_RequestStatus(integer $InstanceID, string $Parameter)
{
    
}

/**
 * sendet einen neuen Soll-Wert vom Typ Boolean an die CCU
 * 
 * <p>Setzt den <b>Parameter</b> des Gertes mit der ID <b>InstanzID</b> auf den Wert <b>Wert</b>.</p><p>Den einzutragenen <b>$Parameter</b> knnen Sie anhand des Idents der Statusvariablen der Instanz ableiten. In der Parameterliste werden einige Beispiele gegeben. Anhand des Typs der Variable knnen Sie auch die notwendige <b>HM_WriteValue</b> Funktion erkennen.</p><p>Weitere Datenpunkte knnen der HomeMatic Datenpunktliste entnommen werden.</p><p>Sollte die Fehlermeldung <b>Failure</b> auftreten, so ist dies im Normalfall auf eine mangelhafte Funkverbindung zurckzufhren.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/homematic/hm-writevalueboolean/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID 
 * @param string $Parameter 
 * @param boolean $Value 
 */
function HM_WriteValueBoolean(integer $InstanceID, string $Parameter, boolean $Value)
{
    
}

/**
 * sendet einen neuen Soll-Wert vom Typ Float an die CCU
 * 
 * <p>Setzt den <b>Parameter</b> des Gertes mit der ID <b>InstanzID</b> auf Wert <b>Wert</b>.</p><p>Den einzutragenen <b>$Parameter</b> knnen Sie anhand des Idents der Statusvariablen der Instanz ableiten. In der Parameterliste werden einige Beispiele gegeben. Anhand des Typs der Variable knnen Sie auch die notwendige <b>HM_WriteValue</b> Funktion erkennen.</p><p>Weitere Datenpunkte knnen der HomeMatic Datenpunktliste entnommen werden.</p><p>Sollte die Fehlermeldung <b>Failure</b> auftreten, so ist dies im Normalfall auf eine mangelhafte Funkverbindung zurckzufhren.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/homematic/hm-writevaluefloat/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID 
 * @param string $Parameter 
 * @param float $Value 
 */
function HM_WriteValueFloat(integer $InstanceID, string $Parameter, float $Value)
{
    
}

/**
 * sendet einen neuen Soll-Wert vom Typ Integer an die CCU
 * 
 * <p>Setzt den <b>Parameter</b> des Gertes mit der ID <b>InstanzID</b> auf Wert <b>Wert</b>.</p><p>Den einzutragenen <b>$Parameter</b> knnen Sie anhand des Idents der Statusvariablen der Instanz ableiten. In der Parameterliste werden einige Beispiele gegeben. Anhand des Typs der Variable knnen Sie auch die notwendige <b>HM_WriteValue</b> Funktion erkennen.</p><p>Weitere Datenpunkte knnen der HomeMatic Datenpunktliste entnommen werden.</p><p>Sollte die Fehlermeldung <b>Failure</b> auftreten, so ist dies im Normalfall auf eine mangelhafte Funkverbindung zurckzufhren.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/homematic/hm-writevalueinteger/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID 
 * @param string $Parameter 
 * @param integer $Value 
 */
function HM_WriteValueInteger(integer $InstanceID, string $Parameter, integer $Value)
{
    
}

/**
 * sendet einen neuen Soll-Wert vom Typ String an die CCU
 * 
 * <p>Setzt den <b>Parameter</b> des Gertes mit der ID <b>InstanzID</b> auf Wert <b>Wert</b>.</p><p>Den einzutragenen <b>$Parameter</b> knnen Sie anhand des Idents der Statusvariablen der Instanz ableiten. In der Parameterliste werden einige Beispiele gegeben. Anhand des Typs der Variable knnen Sie auch die notwendige <b>HM_WriteValue</b> Funktion erkennen.</p><p>Weitere Datenpunkte knnen der HomeMatic Datenpunktliste entnommen werden.</p><p>Sollte die Fehlermeldung <b>Failure</b> auftreten, so ist dies im Normalfall auf eine mangelhafte Funkverbindung zurckzufhren.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/homematic/hm-writevaluestring/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID 
 * @param string $Parameter 
 * @param string $Value 
 */
function HM_WriteValueString(integer $InstanceID, string $Parameter, string $Value)
{
    
}

/**
 * aktualisiert das Bild der Instanz
 * 
 * <p>Aktualisiert das Bild des Gertes mit der ID <b>InstanzID</b>.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/image-grabber/ig-updateimage/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID der Instanz des zu schaltenden Gertes
 */
function IG_UpdateImage(integer $InstanceID)
{
    
}

/**
 * gibt ein Array zu den gecachten E-Mails zurck
 * 
 * <p>Der Befehl gibt ein Array mit Informationen ber die gecacheten E-Mails einer IMAP-Instanz mit der ID <b>InstanzID</b> zurck. Sollte die Instanz nicht existieren, wird eine Warnung generiert.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/imap/imap-getcachedmails/
 * @returns array <p>Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis ein Array mit Daten zu den gecacheten E-Mails, andernfalls ein Boolean mit dem Wert <b>FALSE</b>.</p>
 * @param integer $InstanceID ID der IMAP-Instanz
 */
function IMAP_GetCachedMails(integer $InstanceID)
{
    
}

/**
 * liefert ein Array mit Informationen zu einer bestimmten E-Mail(UID) wieder
 * 
 * <p>Der Befehl ldt eine E-Mail mit der UID <b>UID</b> ber die IMAP-Instanz mit der ID <b>InstanzID</b> und gibt ein Array mit den Daten der E-Mail zurck. Sollte die Instanz oder eine E-Mail mit der bergebenen UID nicht existieren, wird eine Warnung generiert.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/imap/imap-getmailex/
 * @returns array <p>Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis ein Array mit Daten zu den gecacheten E-Mails, andernfalls ein Boolean mit dem Wert <b>FALSE</b>.</p>
 * @param integer $InstanceID ID der IMAP-Instanz
 * @param string $UID UID der zu ladenden E-Mail
 */
function IMAP_GetMailEx(integer $InstanceID, string $UID)
{
    
}

/**
 * IMAP_UpdateCache
 * 
 * @returns boolean
 * @param integer $InstanceID
 */
function IMAP_UpdateCache(integer $InstanceID)
{
    
}

/**
 * bernimmt eine vernderte Konfiguration
 * 
 * <p>Der Befehl bernimmt die neue Soll-Konfiguration als aktuelle Ist-Konfiguration und initialisiert bei Bedarf entsprechende Modulkomponenten neu. (Z.B. wird bei einem Socket Modul die Netzwerkverbindung getrennt und neu aufgebaut.)</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/instanzenverwaltung/konfiguration/ips-applychanges/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID der Instanz
 */
function IPS_ApplyChanges(integer $InstanceID)
{
    
}

/**
 * prft, ob eine Kategorie bereits existiert
 * 
 * <p>Der Befehl prft, ob die Kategorie mit der ID <b>KategorienID</b> existiert.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/kategorieverwaltung/ips-categoryexists/
 * @returns boolean <p>Falls die KategorieID im System existiert, wird <b>TRUE</b> zurckgemeldet, andernfalls <b>FALSE</b>.</p>
 * @param integer $CategoryID ID der zu prfenden Kategorie
 */
function IPS_CategoryExists(integer $CategoryID)
{
    
}

/**
 * erstellt eine (Daten-)Verbindung zwischen zwei Instanzen
 * 
 * <p>Der Befehl verbindet die Instanz <b>InstanzID</b> mit der Instanz <b>bergeordneteID</b> von der Hardwaresicht (physikalisch) gesehen aus, so dass Daten ausgetauscht werden knnen. Beispiel wre in FS20 Gert, dass mit einem FHZ Splitter verbunden wird.</p><p>Jede Instanz kann nur eine bergeordnete Instanz haben.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/instanzenverwaltung/verbindungen/ips-connectinstance/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID der Instanz
 * @param integer $ParentID ID der neu zu verbindenen Instanz
 */
function IPS_ConnectInstance(integer $InstanceID, integer $ParentID)
{
    
}

/**
 * legt eine neue Kategorie an
 * 
 * <p>Der Befehl legt eine neue Kategorie an. Er bentigt keine Parameter. Nach Ausfhrung des Befehls erscheint im Kategorienbaum von IP-Symcon ein neues Objekt mit der Bezeichnung z.B. Unnamed Object (ID: 48490). Mit Hilfe des Befehls IPS_SetName kann dem Objekt (hier der Kategorie) ein aussagefhiger Name gegeben werden. Der Name ist jedoch fr die Identifikation irrelevant. Hierfr ist immer die ID zustndig. Mit dem Befehl IPS_SetParent kann das Objekt einem anderen Objekt untergeordnet werden.</p><p>Die Funktion liefert eine ID, mit deren Hilfe die erzeugte Kategorie eindeutig identifiziert werden kann.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/kategorieverwaltung/ips-createcategory/
 * @returns integer <p>ID des neu erstellten Objekts</p>
 */
function IPS_CreateCategory()
{
    
}

/**
 * legt ein neues Ereignis an
 * 
 * <p>Der Befehl legt ein Ereignisobjekt vom Typ <b>EreignisTyp</b> an.</p><p>Die Funktion liefert eine ID, mit deren Hilfe das erzeugte Ereignisobjekt eindeutig identifiziert werden kann. Das erzeugte Objekt ist nach dem Anlegen noch umkonfiguriert und muss mit den Funktionen IPS_SetEventActive, IPS_SetEventScript und den entsprechenden IPS_SetEventCyclic / IPS_SetEventTrigger konfiguriert werden.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/ereignisverwaltung/ips-createevent/
 * @returns integer <p>ID des neu erstellten Ereignisses</p>
 * @param integer $EventType 
 *   enum[0=etTrigger, 1=etCyclic, 2=etSchedule]
 */
function IPS_CreateEvent(integer $EventType)
{
    
}

/**
 * legt eine Instanz an
 * 
 * <p>Der Befehl legt eine unkonfigurierte Instanz der ID <b>ModulID</b> an. Zulssige Werte fr <b>ModulID</b> knnen ber die Funktion IPS_GetModuleList ermittelt werden. Die ModulID ist eine 32Bit GUID im Format {00000000-0000-0000-0000-000000000000}.</p><p>Die Funktion liefert eine ID, mit deren Hilfe die erzeugte Instanz eindeutig identifiziert werden kann. Das erzeugte Objekt ist nach dem Anlegen noch unkonfiguriert und mit mit den entsprechenden gertespezifischen Funktionen konfiguriert werden. Anschlieend muss die Konfiguration mit dem Befehl IPS_ApplyChanges bernommen werden.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/instanzenverwaltung/ips-createinstance/
 * @returns integer <p>ID der neu erstellten Instanz</p>
 * @param string $ModuleID ModulID des zu erstellenden Objekts
 */
function IPS_CreateInstance(string $ModuleID)
{
    
}

/**
 * legt einen neuen Link an
 * 
 * <p>Der Befehl legt eine neuen Link an. Er bentigt keine Parameter. Nach Ausfhrung des Befehls erscheint im Kategorienbaum von IP-Symcon ein neues Objekt mit der Bezeichnung z.B. Unnamed Object (ID: 48490). Mit Hilfe des Befehls IPS_SetName kann dem Objekt (hier der Link) ein aussagefhiger Name gegeben werden. Der Name ist jedoch fr die Identifikation irrelevant. Hierfr ist immer die ID zustndig.Weiterhin sollte der Link mit einem anderen Objekt verknpft werden. Dies kann ber die Funktion IPS_SetLinkTargetID gemacht werden.</p><p>Die Funktion liefert eine ID, mit deren Hilfe der erzeugte Link eindeutig identifiziert werden kann.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/linkverwaltung/ips-createlink/
 * @returns integer <p>ID des neu erstellten Links</p>
 */
function IPS_CreateLink()
{
    
}

/**
 * legt ein neues Medienobjekt im MedienPool an
 * 
 * <p>Der Befehl legt ein leeres Medienobjekt vom Typ <b>MedienTyp</b> an.</p><p>Die Funktion liefert eine ID, mit deren Hilfe das erzeugte Medienobjekt eindeutig identifiziert werden kann. Das erzeugte Objekt ist nach dem Anlegen noch leer und muss mit der Funktion IPS_SetMediaFile noch mit einer realen Mediendatei verbunden werden.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/medienverwaltung/ips-createmedia/
 * @returns integer <p>ID des neu erstellten Medienobjekts</p>
 * @param integer $MediaType 
 *   enum[0=mtForm, 1=mtImage, 2=mtSound, 3=mtStream, 4=mtChart]
 */
function IPS_CreateMedia(integer $MediaType)
{
    
}

/**
 * legt ein neues Skript an
 * 
 * <p>Der Befehl legt ein Skript vom Typ <b>SkriptTyp</b> an.</p><p>Die Funktion liefert eine ID, mit deren Hilfe das erzeugte Skript eindeutig identifiziert werden kann. Der Befehlt erzeugt auch automatisch eine passende Skriptdatei, die normalerweise vom Format SkriptID.ips.php ist. Falls Sie eine andere Datei zuordnen mchten, knnen Sie dies ber den Befehl  IPS_SetScriptFile tun. Beachten Sie, dass Sie in dem Zusammenhang auch die alte Skriptdatei lschen sollten, um unntige Skriptdateien zu vermeiden.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/skriptverwaltung/ips-createscript/
 * @returns integer <p>ID des neu erstellten Skripts</p>
 * @param integer $ScriptType 
 *   enum[0=stPHPScript, 1=stMacroScript, 2=stBrickScript]
 */
function IPS_CreateScript(integer $ScriptType)
{
    
}

/**
 * legt eine Variable an
 * 
 * <p>Der Befehl legt eine neue IPS-Variable vom Typ VariablenTyp an.</p><p>Die Funktion liefert eine ID, mit deren Hilfe die erzeugte Variable eindeutig identifiziert werden kann.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/variablenverwaltung/ips-createvariable/
 * @returns integer <p>ID der neu erstellten Variable</p>
 * @param integer $VariableType 
 *   enum[0=vtBoolean, 1=vtInteger, 2=vtFloat, 3=vtString]
 */
function IPS_CreateVariable(integer $VariableType)
{
    
}

/**
 * legt ein Variablenprofil an
 * 
 * <p>Der Befehl legt ein neues Variablenprofile fr den Typ <b>VariablenTyp</b> an.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/variablenverwaltung/variablenprofile/ips-createvariableprofile/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param string $ProfileName Name des Profils. Erlaubt sind A-Z, Punkt, Komma, Unterstrich
 * @param integer $ProfileType 
 *   enum[0=vtBoolean, 1=vtInteger, 2=vtFloat, 3=vtString]
 */
function IPS_CreateVariableProfile(string $ProfileName, integer $ProfileType)
{
    
}

/**
 * lscht eine bestehende Kategorie
 * 
 * <p>Der Befehl lscht die vorhandene Kategorie mit der ID <b>KategorienID</b>.</p><p>Alle der Kategorie untergeordneten Objekte werden in die Root-Kategorie verschoben.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/kategorieverwaltung/ips-deletecategory/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $CategoryID ID der zu lschenden Kategorie
 */
function IPS_DeleteCategory(integer $CategoryID)
{
    
}

/**
 * lscht eine bestehendes Ereignis
 * 
 * <p>Der Befehl lscht eine vorhandene Variable mit der ID <b>EreignisID</b>.</p><p>Alle dem Medienobjekt untergeordneten Objekte werden in die Root-Kategorie verschoben.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/ereignisverwaltung/ips-deleteevent/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $EventID ID des zu lschenden Ereignisses
 */
function IPS_DeleteEvent(integer $EventID)
{
    
}

/**
 * lscht eine Instanz
 * 
 * <p>Der Befehl lscht eine vorhandene Instanz mit der ID <b>InstanzID</b>.</p><p>Alle der Instanz untergeordneten Objekte werden in die Root-Kategorie verschoben. Verbundene StatusVariablen werden gelscht.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/instanzenverwaltung/ips-deleteinstance/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID der zu lschenden Instanz
 */
function IPS_DeleteInstance(integer $InstanceID)
{
    
}

/**
 * lscht einen bestehenden Link
 * 
 * <p>Der Befehl lscht die vorhandene Kategorie mit der ID <b>LinkID</b>.</p><p>Alle dem Link untergeordneten Objekte werden in die Root-Kategorie verschoben.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/linkverwaltung/ips-deletelink/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $LinkID ID des zu lschenden Links
 */
function IPS_DeleteLink(integer $LinkID)
{
    
}

/**
 * lscht ein Medienobjekt aus dem MedienPool
 * 
 * <p>Der Befehl entfernt das Medienobjekt mit der ID <b>MedienID</b> aus dem MedienPool.</p><p>Alle dem Medienobjekt untergeordneten Objekte werden in die Root-Kategorie verschoben.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/medienverwaltung/ips-deletemedia/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $MediaID ID des zu lschenden Medienobjekts
 * @param boolean $DeleteFile 
 */
function IPS_DeleteMedia(integer $MediaID, boolean $DeleteFile)
{
    
}

/**
 * entfernt eine bestehendes Skript aus der Skriptliste
 * 
 * <p>Der Befehl entfernt das Skript mit der ID <b>SkriptID</b> aus der internen Skriptliste. Das Skript erscheint nicht mehr im Strukturbaum und kann auch nicht mehr bearbeitet werden.</p><p>Gelsche Skripte werden in den /scripts/deleted/ Ordner verschoben.</p><p>Alle dem Skript untergeordneten Objekte werden in die Root-Kategorie verschoben.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/skriptverwaltung/ips-deletescript/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $ScriptID ID des zu lschenden Skripts
 * @param boolean $DeleteFile 
 */
function IPS_DeleteScript(integer $ScriptID, boolean $DeleteFile)
{
    
}

/**
 * lscht eine Variable
 * 
 * <p>Der Befehl lscht eine vorhandene Variable mit der ID VariablenID.</p><p>Alle der Variable untergeordneten Objekte werden in die Root-Kategorie verschoben.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/variablenverwaltung/ips-deletevariable/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $VariableID ID der zu lschenden Variable
 */
function IPS_DeleteVariable(integer $VariableID)
{
    
}

/**
 * lscht ein Variablenprofil
 * 
 * <p>Der Befehl lscht ein vorhandenes Variablenprofil mit dem Namen <b>ProfilName</b>.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/variablenverwaltung/variablenprofile/ips_deletevariableprofile/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param string $ProfileName Name des zu lschenden Profils
 */
function IPS_DeleteVariableProfile(string $ProfileName)
{
    
}

/**
 * IPS_DisableAction
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param string $VariableIdent
 */
function IPS_DisableAction(integer $InstanceID, string $VariableIdent)
{
    
}

/**
 * IPS_DisableDebug
 * 
 * @returns boolean
 * @param integer $ID
 */
function IPS_DisableDebug(integer $ID)
{
    
}

/**
 * lst eine (Daten-)Verbindung zwischen zwei Instanzen
 * 
 * <p>Der Befehl lst eine verbundene Instanz <b>InstanzID</b> von der bergeordneten Instanz. Die Angabe der bergeordneten Instanz ist nicht notwendig, da es nur eine geben kann und somit die zu lsenden Verbindung eindeutig ist.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/instanzenverwaltung/verbindungen/ips-disconnectinstance/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID der Instanz
 */
function IPS_DisconnectInstance(integer $InstanceID)
{
    
}

/**
 * IPS_EnableAction
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param string $VariableIdent
 */
function IPS_EnableAction(integer $InstanceID, string $VariableIdent)
{
    
}

/**
 * IPS_EnableDebug
 * 
 * @returns boolean
 * @param integer $ID
 * @param integer $Duration
 */
function IPS_EnableDebug(integer $ID, integer $Duration)
{
    
}

/**
 * prft, ob ein Ereignis bereits existiert
 * 
 * <p>Der Befehl berprft ob ein Ereignis mit der ID <b>EreignisID</b> existiert.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/ereignisverwaltung/ips-eventexists/
 * @returns boolean <p>Falls die EreignisID im System existiert, wird <b>TRUE</b> zurckgemeldet, andernfalls <b>FALSE</b>.</p>
 * @param integer $EventID ID des zu prfenden Ereignisses
 */
function IPS_EventExists(integer $EventID)
{
    
}

/**
 * startet ein externes Programm
 * 
 * <p>Der Befehl veranlasst den Start des externen Programms mit dem Namen <b>ProgrammName</b>. Dem Programm wird der <b>String</b>-Parameter als Aufrufparameter bergeben. Der Boolean-Wert <b>Warten</b> legt fest, ob das Programmende abgewartet oder das aufrufende Skript sofort fortgesetzt werden soll. Wird auf das Ergebnis gewartet, erscheint dieses, falls vorhanden, als String im Rckgabewert.</p><p>Als Quelle fr den Rckgabewert kommt eine der folgenden Programmausgaben in Frage:</p><ul><li>Ausgabe nach <b>stderror</b></li><li>Ausgabe nach <b>stdout</b></li></ul><p>Werden vom Programm beide Mglichkeiten genutzt, erhlt <b>stderror</b> den Vorrang, um z.B. Fehlermeldungen nicht zu verlieren.</p><p><b>Vorsicht:</b> Beim Warten auf das Programmende verlngert sich die Laufzeit des Skripts entsprechend. Dabei ist darauf zu achten, dass die in der Datei <b>php.ini</b> definierte maximale Laufzeit nicht berschritten wird. Andernfalls wird das Skript mit einer Fehlermeldung abgebrochen. Dies ist vor allem dann wichtig, wenn das Programm Benutzereingaben erwartet.</p><p><b>Achtung:</b> Wenn das zu startende Programm interaktiv ist (z.B. ein Fenster beinhaltet), wird dieses nicht angezeigt/ sichtbar. Es wird im Hintergrund als System-Prozess gestartet und kann dann nur mit Hilfe des Task-Managers gestoppt werden. Soll das Programm auf dem Desktop angezeigt werden, muss die IPS_ExecuteEx Funktion verwendet werden.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/ablaufsteuerung/ips-execute/
 * @returns string <p>Den Rckgabewert von stderr/stdout, wenn der <b>Warten</b> Parameter auf True ist, sonst ist die Rckgabe ein leerer String.</p>
 * @param string $Filename Vollstndiger Pfad zum Programm
 * @param string $Parameter An das Programm zu bergebende Parameter (optional)
 * @param boolean $ShowWindow V1 Parameter. Wird in der V2 nicht ausgewertet.
 * @param boolean $WaitResult Gibt an, ob auf das Programmende gewartet werden soll.
 */
function IPS_Execute(string $Filename, string $Parameter, boolean $ShowWindow, boolean $WaitResult)
{
    
}

/**
 * startet ein externes Programm im Userkontext
 * 
 * <p>Der Befehl veranlasst den Start des externen Programms mit dem Namen <b>ProgrammName</b>. Dem Programm wird der String-<b>Parameter</b> als Aufrufparameter bergeben. Der Boolean-Wert <b>Warten</b> legt fest, ob das Programmende abgewartet oder das aufrufende Skript sofort fortgesetzt werden soll.</p><p>Der Parameter SessionID gibt an, in welcher User-Session das Programm gestartet werden soll. (Unter Windows 2003 knnen z.B. mehrere Terminal Sessions parallel gestartet sein.) Wird der Parameter kleiner 0 gewhlt, so ermittelt IP-Symcon die erste verfgbare Session automatisch und startet dort das gewnschte Programm.</p><p><b>Vorsicht:</b> Beim Warten auf das Programmende verlngert sich die Laufzeit des Skripts entsprechend. Dabei ist darauf zu achten, dass die in der Datei <b>php.ini</b> definierte maximale Laufzeit nicht berschritten wird. Andernfalls wird das Skript mit einer Fehlermeldung abgebrochen. Dies ist vor allem dann wichtig, wenn das Programm Benutzereingaben erwartet.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/ablaufsteuerung/ips-executeex/
 * @returns string <p>Leerstring</p>
 * @param string $Filename Vollstndiger Pfad zum Programm
 * @param string $Parameter An das Programm zu bergebende Parameter (optional)
 * @param boolean $ShowWindow 
 * @param boolean $WaitResult Gibt an, ob aus das Programmende gewartet werden soll.
 * @param integer $SessionID Die User Session ID, die genutzt werden soll (Unter XP ab 0, 2003/Vista ab 1), &lt; 0 fr automatische Auswahl
 */
function IPS_ExecuteEx(string $Filename, string $Parameter, boolean $ShowWindow, boolean $WaitResult, integer $SessionID)
{
    
}

/**
 * prft, ob eine bestimmte Funktion existiert
 * 
 * <p>Der Befehl prft, ob die Funktion mit dem Namen Funktionsname innerhalb von IP-Symcon registriert ist.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/programminformationen/ips-functionexists/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param string $FunctionName Name, der zu prfenden Funktion
 */
function IPS_FunctionExists(string $FunctionName)
{
    
}

/**
 * IPS_GetCategory
 * 
 * @returns array
 * @param integer $CategoryID
 */
function IPS_GetCategory(integer $CategoryID)
{
    
}

/**
 * sucht und liefert die ID einer bestehenden Kategorie ber dessen Namen
 * 
 * <p>Der Befehl versucht die ID der Kategorie mit dem Namen <b>KategorienName</b>, deren bergeordnetes Objekt die ID <b>bergeordneteID</b> besitzt, zu ermitteln. Es wird die ID der ersten gefundenen Kategorie verwendet, deren Name mit <b>KategorienName</b> bereinstimmt. Falls eine solche Kategorie gefunden wurde, wird deren ID zurckgemeldet, andernfalls FALSE.</p><p><b>Vorsicht:</b> Da Namen in IP-Symcon beliebig vergeben werden knnen, und damit <b>nicht eindeutig</b> sind, kann der Befehl eine falsche ID zurckmelden.</p><p>Diese Funktion generiert eine <b>Warnung</b>. Sollte der Name nicht gefunden werden, benutzen Sie den @ Operator, falls Sie diese Meldung unterdrcken wollen. Die genau Funktionsweise dieses Operators knnen Sie dem PHP Handbuch entnehmen.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/kategorieverwaltung/ips-getcategoryidbyname/
 * @returns integer <p>ID der gefundenen Kategorie, sonst FALSE</p>
 * @param string $Name Zu suchender KategorieName
 * @param integer $ParentID Objekt, in deren direkten Unterobjekten gesucht werden soll
 */
function IPS_GetCategoryIDByName(string $Name, integer $ParentID)
{
    
}

/**
 * liefert eine Liste aller existierenden Kategorien
 * 
 * <p>Der Befehl ermittelt die IDs aller in IP-Symcon eingerichteten Kategorien. Die IDs werden in einem Array aufgelistet. Falls keine Kategorie existiert, ist das Array leer.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/kategorieverwaltung/ips-getcategorylist/
 * @returns array <p>Ein Array von Integer-Werten aller IDs der Kategorien in IP-Symcon</p>
 */
function IPS_GetCategoryList()
{
    
}

/**
 * liefert eine Aufstellung aller untergeordneten Objekte
 * 
 * <p>Der Befehl ermittelt die IDs aller Unterobjekte von Objekt <b>ObjektID</b>. Die IDs werden in einem Array aufgelistet.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/objektverwaltung/ips-getchildrenids/
 * @returns array <p>Ein Array von Integer-Werten aller IDs der Unterobjekte von Objekt <b>ObjektID</b></p>
 * @param integer $ID ID fr die die Unterobjekte zurckgegeben werden sollen
 */
function IPS_GetChildrenIDs(integer $ID)
{
    
}

/**
 * liefert kompatible Instanzen zu einer Instanz
 * 
 * <p>Der Befehl ermittelt die IDs aller in IP-Symcon verfgbaren Instanzen, die zur <b>InstanzID</b> kompatibel sind. Die IDs werden in einem Array aufgelistet.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/instanzenverwaltung/verbindungen/ips-getcompatibleinstances/
 * @returns array <p>Array von Integer-Werten aller kompatiblen InstanzIDs zur <b>InstanzID</b></p>
 * @param integer $InstanceID ID der zu prfenden Instanz
 */
function IPS_GetCompatibleInstances(integer $InstanceID)
{
    
}

/**
 * liefert alle Kompatiblen Module zu einem bestimmten Modul
 * 
 * <p>Der Befehl ermittelt die IDs aller in IP-Symcon verfgbaren Module, die zur <b>ModulID</b> kompatibel sind. Die IDs werden in einem Array aufgelistet.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/modulverwaltung/ips-getcompatiblemodules/
 * @returns array <p>Array von String-Werten aller kompatiblen ModulIDs zu <b>ModulID</b></p>
 * @param string $ModuleID ID des zu prfenden Moduls
 */
function IPS_GetCompatibleModules(string $ModuleID)
{
    
}

/**
 * liest eine Konfiguration aus
 * 
 * <p>Gibt die Konfiguration der Instanz mit der ID <b>InstanzID</b> als String zurck.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/instanzenverwaltung/konfiguration/ips-getconfiguration/
 * @returns string <p>Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis die Konfiguration der Instanz als String.</p>
 * @param integer $InstanceID ID der Instanz
 */
function IPS_GetConfiguration(integer $InstanceID)
{
    
}

/**
 * IPS_GetConfigurationForParent
 * 
 * @returns string
 * @param integer $InstanceID
 */
function IPS_GetConfigurationForParent(integer $InstanceID)
{
    
}

/**
 * IPS_GetConfigurationForm
 * 
 * @returns string
 * @param integer $InstanceID
 */
function IPS_GetConfigurationForm(integer $InstanceID)
{
    
}

/**
 * IPS_GetDemoExpiration
 * 
 * @returns integer
 */
function IPS_GetDemoExpiration()
{
    
}

/**
 * liefert umfassende Informationen ber ein Ereignis
 * 
 * <p>Der Befehl liefert ein Array mit Informationen ber Ereignis mit der ID <b>EreignisID</b>.</p><p>Seit IP-Symcon 3.1 sind die Felder CyclicDateFrom, CyclicDateTo, CyclicTimeFrom und CyclicTimeTo jeweils Arrays. Wer Kompatibilitt zur Version 3.0 und lter bentigt, kann auf die seit IP-Symcon 3.1 verfgbare Funktion IPS_GetEventCompatibility zurckgreifen, welche die alte Funktionsweise wiederherstellt.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/ereignisverwaltung/ips-getevent/
 * @returns array <p>Folgende Informationen stehen als <b>key =&gt; value</b> Paare zur Verfgung:</p><li><b>CyclicDateType</b>  integer  Datumtyp. Siehe: IPS_SetEventCyclic</li><li><b>CyclicDateValue</b>  integer  Datumintervall. Siehe: IPS_SetEventCyclic</li><li><b>CyclicDateDay</b>  integer  Datumstage. Siehe: IPS_SetEventCyclic</li><li><b>CyclicDateDayValue</b>  integer  Datumstagesintervall. Siehe IPS_SetEventCyclic</li><li><b>CyclicDateFrom</b>  array  Startdatum als Array von Tag, Monat, Jahr; 0/0/0 = Immer. Siehe IPS_SetEventCyclicDateFrom</li><li><b>CyclicDateTo</b>  array  Enddatum als Array von Tag, Monat, Jahr; 0/0/0 = Nie. Siehe IPS_SetEventCyclicDateTo</li><li><b>CyclicTimeType</b>  integer  Zeittyp. Siehe: IPS_SetEventCyclic</li><li><b>CyclicTimeValue</b>  integer  Zeitintervall. Siehe: IPS_SetEventCyclic</li><li><b>CyclicTimeFrom</b>  array  Startzeit als Array von Stunde, Minute, Sekunde; 0/0/0 = Mitternacht. Siehe IPS_SetEventCyclicTimeFrom</li><li><b>CyclicTimeTo</b>  array  Endzeit als Array von Stunde, Minute, Sekunde; 0/0/0 = Nie. Siehe IPS_SetEventCyclicTimeTo</li><li><b>ScheduleActions</b>  array  Array von Aktionen, welche dem Wochenplan zugehrig sind. Siehe IPS_SetEventScheduleAction</li><li><b>ScheduleGroups</b>  array  Array von Gruppen mit Schaltpunkten, welche dem Wochenplan zugehrig sind. Siehe IPS_SetEventScheduleGroup und IPS_SetEventScheduleGroupPoint</li><li><b>EventID</b>  integer  EreignisID</li><li><b>EventLimit</b>  integer  Restliche Anzahl der Ausfhrungen. 0 = Kein Limit</li><li><b>EventScript</b>  string  PHP Code der auszufhrenden Operation</li><li><b>EventActive</b>  boolean  TRUE, wenn das Ereignis aktiv ist</li><li><b>EventType</b>  integer  Ereignis-Typ: (0: Auslser, 1: Zyklisch, 2: Wochenplan)</li><li><b>LastRun</b>  float  Unix Timestamp der letzten Ausfhrung, 0 = Nie</li><li><b>NextRun</b>  float  Unix Timestamp der nchsten Ausfhrung, 0 = Nie</li><li><b>TriggerSubsequentExecution</b>  boolean  Erlaube erneute Ausfhrung bei Auslsung ohne Wertnderung</li><li><b>TriggerType</b>  integer  Wert fr den Auslser-Typ: Siehe: IPS_SetEventTrigger</li><li><b>TriggerValue</b>  variant  Wert, der fr die Prfung je nach Auslsertyp verwendet wird</li><li><b>TriggerVariableID</b>  integer  VariablenID, die als Auslser genutzt werden soll</li>
 * @param integer $EventID Die zu zeigende EreignisID
 */
function IPS_GetEvent(integer $EventID)
{
    
}

/**
 * ermittelt die ID eines Ereignisses anhand des Namens
 * 
 * <p>Der Befehl versucht die ID des Ereignisses mit dem Namen <b>EreignisName</b>, dessen bergeordnetes Objekt die ID <b>bergeordneteID</b> besitzt, zu ermitteln. Es wird die ID des ersten gefundenen Ereignisses verwendet, dessen Name mit <b>EreignisName</b> bereinstimmt. Falls ein solches Ereignis gefunden wurde, wird dessen ID zurckgemeldet, andernfalls FALSE.</p><p><b>Vorsicht:</b> Da Namen in IP-Symcon beliebig vergeben werden knnen, und damit <b>nicht eindeutig</b> sind, kann der Befehl eine falsche ID zurckmelden.</p><p>Diese Funktion generiert eine <b>Warnung</b>, sollte der Name nicht gefunden werden. Benutzen Sie den @ Operator, falls Sie diese Meldung unterdrcken wollen. Die genau Funktionsweise dieses Operators knnen Sie dem PHP Handbuch entnehmen.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/ereignisverwaltung/ips-geteventidbyname/
 * @returns integer <p>ID des gefundenen Ereignisses, sonst FALSE</p>
 * @param string $Name Zu suchender EreignisName
 * @param integer $ParentID Objekt, in dessen direkten Unterobjekten gesucht werden soll
 */
function IPS_GetEventIDByName(string $Name, integer $ParentID)
{
    
}

/**
 * liefert eine Liste aller existierenden Ereignisse
 * 
 * <p>Der Befehl ermittelt die IDs aller in IP-Symcon registrierten Ereignisse. Die IDs werden in einem Array aufgelistet. Falls kein Ereignis existiert, ist das Array leer.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/ereignisverwaltung/ips-geteventlist/
 * @returns array <p>Ein Array von Integer-Werten aller IDs der Ereignisse in IP-Symcon</p>
 */
function IPS_GetEventList()
{
    
}

/**
 * liefert eine Liste aller Ereignisse eines bestimmten Typs
 * 
 * <p>Der Befehl ermittelt die IDs aller Ereignisse eines bestimmten <b>EreignisTyps</b>. Die IDs werden in einem Array aufgelistet. Falls kein Ereignis des angeforderten Typs existiert, ist das Array leer.</p><p>Es werden nur Objekte des Ereignistyps <b>EreignisTyp</b> aufgelistet. Sollen alle Ereignisse aufgelistet werden, so kann hierfr der Befehl IPS_GetEventList verwendet werden.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/ereignisverwaltung/ips-geteventlistbytype/
 * @returns array <p>Ein Array von Integer-Werten aller IDs der Ereignisse vom Typ EreignisTyp in IP-Symcon</p>
 * @param integer $EventType 
 *   enum[0=etTrigger, 1=etCyclic, 2=etSchedule]
 */
function IPS_GetEventListByType(integer $EventType)
{
    
}

/**
 * liefert umfassende Informationen ber eine Funktion
 * 
 * <p>Dieser Befehl liefert weitere Informationen zu einer in IP-Symcon registrierten Funktion. Der Parameter Funktionsname gibt an, welche Funktion inspiziert werden soll.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/programminformationen/ips-getfunction/
 * @returns array <p>Ein Array mit folgenden <b>key =&gt; value</b> Paaren</p><li><b>FunctionName</b>  string  Funktionsname</li><li><b>Parameters</b>  array  Parameterliste</li><li><b>Result</b>  array  Rckgabeinformation</li>
 * @param string $FunctionName Name, der zu prfenden Funktion
 */
function IPS_GetFunction(string $FunctionName)
{
    
}

/**
 * liefert eine Liste mit allen Verfgbaren Funktionen
 * 
 * <p>Der Befehl ermittelt alle in der aktuellen Konfiguration von IP-Symcon verfgbaren IPS-Befehle. Die Funktionen werden in einem Array aufgelistet. Die Anzahl der Befehle ist abhngig von der derzeitigen Konfiguration von IP-Symcon. Wenn z.B. eine Instanz des TTS-Moduls (Text-To-Speech) konfiguriert ist, dann werden zustzlich auch alle TTS-Befehle aufgefhrt.</p><p>Als Parameter kann die InstanzID als Filter angegeben werden. Somit werden nur die Funktionen angezeigt, die die betreffende Instanz verffentlicht. Wird als InstanzID 0 angegeben, so ist der Filtermechanismus nicht aktiv und es werden alle in IP-Symcon verfgbaren Funktionen ausgegeben.</p><p>Details zu den einzelnen Funktionen knnen ber IPS_GetFunction ermitteln werden.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/programminformationen/ips-getfunctionlist/
 * @returns array <p>Ein Array von String-Werten aller Funktionen</p>
 * @param integer $InstanceID InstanzID, fr zu suchende Funktion. 0, um alle zu suchen.
 */
function IPS_GetFunctionList(integer $InstanceID)
{
    
}

/**
 * IPS_GetFunctionListByModuleID
 * 
 * @returns array
 * @param string $ModuleID
 */
function IPS_GetFunctionListByModuleID(string $ModuleID)
{
    
}

/**
 * IPS_GetFunctions
 * 
 * @returns array
 * @param array $Parameter
 */
function IPS_GetFunctions(array $Parameter)
{
    
}

/**
 * IPS_GetFunctionsMap
 * 
 * @returns array
 * @param array $Parameter
 */
function IPS_GetFunctionsMap(array $Parameter)
{
    
}

/**
 * liefert umfassende Informationen zu einer bestimmten Instanz
 * 
 * <p>Der Befehl liefert ein Array mit Informationen ber die Instanz mit der ID <b>InstanzID</b>. Sollte die Instanz nicht vorhanden sein, wird eine Warnung generiert.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/instanzenverwaltung/ips-getinstance/
 * @returns array <p>Folgende Informationen stehen als key =&gt; value Paare zur Verfgung:</p><li><b>InstanceID</b>  integer  InstanzID</li><li><b>InstanceStatus</b>  integer  siehe Tabelle "Status der Instanz"</li><li><b>LastChange</b>  float  reserved</li><li><b>ModuleInfo</b>  array  siehe Tabelle "Modulinformationen"</li><li><b>ConnectionID</b>  integer  Daten-Verbindung zu einer Splitter/IO Instanz</li><p><em>Tabelle: Status der Instanz</em><br></p><li>101  Instanz wird erstellt</li><li>102  Instanz ist aktiv</li><li>103  Instanz wird gelscht</li><li>104  Instanz ist inaktiv</li><li>&gt;=200  Instanz ist fehlerhaft</li><p><em>Tabelle: Modulinformationen</em><br></p><li>ModuleID  string  ModulID zur Instanz</li><li>ModuleName  string  ModulName der Instanz</li><li>ModuleType  integer  ModulTyp der Instanz (siehe "Modultype" bei IPS_GetModule)</li>
 * @param integer $InstanceID Die zu zeigende InstanzID
 */
function IPS_GetInstance(integer $InstanceID)
{
    
}

/**
 * liefert die ID einer Instanz anhand des Namens
 * 
 * <p>Der Befehl versucht die ID der Instanz mit dem Namen <b>InstanzName</b>, deren bergeordnetes Objekt die ID <b>bergeordneteID</b> besitzt, zu ermitteln. Es wird die ID der ersten gefundenen Instanz verwendet, deren Name mit <b>InstanzName</b> bereinstimmt. Falls eine solche Instanz gefunden wurde, wird deren ID zurckgemeldet, andernfalls FALSE.</p><p><b>Vorsicht:</b> Da Namen in IP-Symcon beliebig vergeben werden knnen, und damit <b>nicht eindeutig</b> sind, kann der Befehl eine falsche ID zurckmelden.</p><p>Diese Funktion generiert eine <b>Warnung</b>, sollte der Name nicht gefunden werden. Benutzen Sie den @ Operator, falls Sie diese Meldung unterdrcken wollen. Die genau Funktionsweise dieses Operators knnen Sie dem PHP Handbuch entnehmen.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/instanzenverwaltung/ips-getinstanceidbyname/
 * @returns integer <p>ID der gefundenen Instanz, sonst FALSE</p>
 * @param string $Name Zu suchender InstanzName
 * @param integer $ParentID Objekt, in deren direkten Unterobjekten gesucht werden soll
 */
function IPS_GetInstanceIDByName(string $Name, integer $ParentID)
{
    
}

/**
 * liefert eine Aufstellung aller existierenden Instanzen
 * 
 * <p>Der Befehl ermittelt die IDs aller in IP-Symcon registrierten IPS-Instanzen. Die IDs werden in einem Array aufgelistet. Falls keine Instanz existiert, ist das Array leer.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/instanzenverwaltung/ips-getinstancelist/
 * @returns array <p>Ein Array von Integer-Werten aller IDs der Instanzen in IP-Symcon</p>
 */
function IPS_GetInstanceList()
{
    
}

/**
 * liefert alle Instanzen die von einer bestimmten ModulID sind
 * 
 * <p>Der Befehl gibt alle Instanzen, die der angegebenen ModulID entsprechen, in einem Array zurck.</p><p>Die GUIDs knnen bei IPS_GetModuleList nachgeschlagen werden.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/instanzenverwaltung/ips-getinstancelistbymoduleid/
 * @returns array <p>Ein Array von Integer-Werten aller gefundenen IDs</p>
 * @param string $ModuleID ModulID der zu suchenden Instanzen
 */
function IPS_GetInstanceListByModuleID(string $ModuleID)
{
    
}

/**
 * liefert eine Liste aller Instanzen eines bestimmten Typs
 * 
 * <p>Der Befehl ermittelt die IDs aller Instanzen eines bestimmten <b>InstanzTyps</b>. Die IDs werden in einem Array aufgelistet. Falls keine Instanz des angeforderten Typs existiert, ist das Array leer.</p><p>Es werden nur Objekte des Instanztyps <b>InstanzTyp</b> aufgelistet. Sollen alle Instanzen aufgelistet werden, so kann hierfr der Befehl IPS_GetInstanceList verwendet werden.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/instanzenverwaltung/ips-getinstancelistbymoduletype/
 * @returns array <p>Ein Array von Integer-Werten aller IDs der Instanzen vom Typ <b>InstanzTyp</b> in IP-Symcon</p>
 * @param integer $ModuleType 
 *   enum[0=mtCore, 1=mtIO, 2=mtSplitter, 3=mtDevice, 4=mtConfigurator]
 */
function IPS_GetInstanceListByModuleType(integer $ModuleType)
{
    
}

/**
 * liefert den Pfad zum IP-Symcon Programmverzeichnis
 * 
 * <p>Der Befehl liefert einen String mit dem vollstndigen Pfad zum IP-Symcon Programmverzeichnis (Settings, Skripte, Medien...). Je nach Betriebssystem enthlt der Pfad ein abschlieendes Slash (/) oder Backslash (\).</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/programminformationen/ips-getkerneldir/
 * @returns string <p>Gibt den vollstndigen Pfad zum IP-Symcon Programmverzeichnis als String zurck</p>
 */
function IPS_GetKernelDir()
{
    
}

/**
 * liefert den Pfad zum IP-Symcon Installationsverzeichnis
 * 
 * <p>Der Befehl liefert einen String mit dem vollstndigen Pfad zu den IP-Symcon Installationsverzeichnis. Je nach Betriebssystem enthlt der Pfad ein abschlieendes Slash (/) oder Backslash (\).</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/programminformationen/ips-getkerneldirex/
 * @returns string <p>Gibt den vollstndigen Pfad zum IP-Symcon Installationsverzeichnis als String zurck</p>
 */
function IPS_GetKernelDirEx()
{
    
}

/**
 * liefert den Runlevel des Kernels
 * 
 * <p>Der Befehl liefert den Runlevel des Systems zurck.</p><li>KR_CREATE  10101  Kernel wird erstellt</li><li>KR_INIT  10102  Kernel wird initialisiert. z.B. werden Module geladen und Instanzen erstellt</li><li>KR_READY  10103  Kernel ist bereit und luft</li><li>KR_UNINIT  10104  Kernel wird heruntergefahren und alles sauber beendet</li><li>KR_SHUTDOWN  10105  Kernel wurde vollstndig beendet</li>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/programminformationen/ips-getkernelrunlevel/
 * @returns integer <p>Runlevel des Kernels.</p>
 */
function IPS_GetKernelRunlevel()
{
    
}

/**
 * liefert den Zeitpunkt, an dem IP-Symcon gestartet wurde
 * 
 * <p>Der Befehl liefert Datum und Uhrzeit des Startzeitpunkts von IP-Symcon als Unix Timestamp.</p><p>Dieser Befehl ist ab Version 4.0 implementiert. Bis Version 3.4 kann der Befehl IPS_GetUpTime genutzt werden.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/programminformationen/ips-getkernelstarttime/
 * @returns integer <p>Zeitpunkt, an dem IP-Symcon gestartet wurde</p>
 */
function IPS_GetKernelStartTime()
{
    
}

/**
 * liefert die Versionsnummer des verwendeten Kernels
 * 
 * <p>Der Befehl liefert einen String mit der Nummer der IP-Symcon Programmversion. Durch Abfrage der Programmversion kann entschieden werden, ob ein Skript unter der gemeldeten Version lauffhig ist.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/programminformationen/ips-getkernelversion/
 * @returns string <p>Programmversion. Major/Minorversion durch Punkt (.) getrennt.</p>
 */
function IPS_GetKernelVersion()
{
    
}

/**
 * IPS_GetLibraries
 * 
 * @returns array
 * @param array $Parameter
 */
function IPS_GetLibraries(array $Parameter)
{
    
}

/**
 * gibt Details zu einer Bibliothek
 * 
 * <p>Der Befehl liefert ein Array mit Informationen ber die Bibliothek mit der ID <b>BibliothekID</b>.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/modulverwaltung/ips-getlibrary/
 * @returns array <p>Folgende Informationen stehen als <b>key =&gt; value</b> Paare zur Verfgung:</p><li><b>Author</b>  string  Name des Autors</li><li><b>Build</b>  integer  Fortlaufende Zahl zur Versionierung</li><li><b>Date</b>  integer  Unix-Timestamp</li><li><b>LibraryID</b>  string  BibliothekID</li><li><b>Name</b>  string  Name der Bibliothek</li><li><b>URL</b>  string  Internetadresse des Bibliothekautors</li><li><b>Version</b>  integer  HighByte: Major Version, LowByte: Minor Version</li>
 * @param string $LibraryID Die zu zeigende BibliothekID
 */
function IPS_GetLibrary(string $LibraryID)
{
    
}

/**
 * liefert eine Liste der Bibliotheken
 * 
 * <p>Der Befehl ermittelt die IDs aller in IP-Symcon verfgbaren Bibliotheken. Die IDs werden in einem Array aufgelistet.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/modulverwaltung/ips-getlibrarylist/
 * @returns array <p>Ein Array von String-Werten aller GUIDs der Bibliotheken in IP-Symcon</p>
 */
function IPS_GetLibraryList()
{
    
}

/**
 * gibt eine Liste der Module einer Bibliothek
 * 
 * <p>Der Befehl ermittelt die IDs der verfgbaren Module in einer angegebenen Bibliothek. Die IDs werden in einem Array aufgelistet.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/modulverwaltung/ips-getlibrarymodules/
 * @returns array <p>Ein Array von String-Werten aller GUIDs der Module in einer Bibliothek in IP-Symcon</p>
 * @param string $LibraryID Die zu zeigende BibliothekID
 */
function IPS_GetLibraryModules(string $LibraryID)
{
    
}

/**
 * IPS_GetLicensee
 * 
 * @returns string
 */
function IPS_GetLicensee()
{
    
}

/**
 * IPS_GetLimitDemo
 * 
 * @returns integer
 */
function IPS_GetLimitDemo()
{
    
}

/**
 * IPS_GetLimitServer
 * 
 * @returns string
 */
function IPS_GetLimitServer()
{
    
}

/**
 * IPS_GetLimitVariables
 * 
 * @returns integer
 */
function IPS_GetLimitVariables()
{
    
}

/**
 * IPS_GetLimitWebFront
 * 
 * @returns integer
 */
function IPS_GetLimitWebFront()
{
    
}

/**
 * liefert umfassende Informationen ber einen Link
 * 
 * <p>Der Befehl liefert ein Array mit Informationen ber den Link mit der ID <b>LinkID</b>. Sollte der Link nicht vorhanden sein, wird eine Warnung generiert.</p><p>Ab Version 4.0 wird die bis 3.4 vorhandene Funktion als<br>"array IPS_GetLinkCompatibility( integer $LinkID )" zur Verfgung gestellt.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/linkverwaltung/ips-getlink/
 * @returns array <p>Folgende Informationen stehen als <b>key =&gt; value</b> Paare zur verfgung:</p><li><b>LinkID</b>  integer  ObjektID</li><li><b>LinkChildID</b> (bis 3.4)  integer  ID des Objektes mit dem dieser Link verknpft ist. Siehe IPS_SetLinkTargetID (ab 4.0 dauerhaft ersetzt durch TargetID)</li><li><b>TargetID</b> (ab 2.6)  integer  ID des Objektes mit dem dieser Link verknpft ist. Siehe IPS_SetLinkTargetID</li>
 * @param integer $LinkID Die zu zeigende LinkID
 */
function IPS_GetLink(integer $LinkID)
{
    
}

/**
 * ermittelt die ID eines Links anhand des Namens
 * 
 * <p>Der Befehl versucht die ID des Links mit dem Namen <b>LinkName</b>, deren bergeordnetes Objekt die ID <b>bergeordneteID</b> besitzt, zu ermitteln. Es wird die ID des ersten gefundenen Links verwendet, deren Name mit <b>LinkName</b> bereinstimmt. Falls ein solcher Link gefunden wurde, wird deren ID zurckgemeldet, andernfalls FALSE.</p><p><b>Vorsicht:</b> Da Namen in IP-Symcon beliebig vergeben werden knnen, und damit <b>nicht eindeutig</b> sind, kann der Befehl eine falsche ID zurckmelden.</p><p>Diese Funktion generiert eine <b>Warnung</b>, sollte der Name nicht gefunden werden. Benutzen Sie den @ Operator, falls Sie diese Meldung unterdrcken wollen. Die genau Funktionsweise dieses Operators knnen Sie dem PHP Handbuch entnehmen.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/linkverwaltung/ips-getlinkidbyname/
 * @returns integer <p>ID des gefundenen Links, sonst FALSE</p>
 * @param string $Name Zu suchender LinkName
 * @param integer $ParentID Objekt, in deren direkten Unterobjekten gesucht werden soll
 */
function IPS_GetLinkIDByName(string $Name, integer $ParentID)
{
    
}

/**
 * liefert eine Liste aller existierenden Links
 * 
 * <p>Der Befehl ermittelt die IDs aller in IP-Symcon eingerichteten Links . Die IDs werden in einem Array aufgelistet. Falls kein Link existiert, ist das Array leer.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/linkverwaltung/ips-getlinklist/
 * @returns array <p>Ein Array von Integer-Werten aller IDs der Links in IP-Symcon</p>
 */
function IPS_GetLinkList()
{
    
}

/**
 * IPS_GetLiveConsoleCRC
 * 
 * @returns string
 */
function IPS_GetLiveConsoleCRC()
{
    
}

/**
 * IPS_GetLiveConsoleFile
 * 
 * @returns string
 */
function IPS_GetLiveConsoleFile()
{
    
}

/**
 * IPS_GetLiveUpdateVersion
 * 
 * @returns string
 */
function IPS_GetLiveUpdateVersion()
{
    
}

/**
 * liefert den kompletten Pfad des Objekts
 * 
 * <p>Dieser Befehl dient dazu den kompletten Pfad inklusive Namen eines Objektes zu erhalten</p><p>Ab Version 4.0: Es gilt zustzlich die gleiche Sonderfallregel wie bei IPS_GetName</p><p>Diese Funktion dient nur zur schnellen Visualisierung des Pfades. Da im Namen eines Objektes Backslashes \ enthalten sein knnen, ist der Rckgabewert nicht eindeutig. Eine Weiterverwendung mit z.B. explode ist daher nicht sinnvoll.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/objektverwaltung/ips-getlocation/
 * @returns string <p>Pfad/Name des Objekts im logischen Objektbaum</p>
 * @param integer $ID ID fr die der Pfad/Namen erstellt werden soll
 */
function IPS_GetLocation(integer $ID)
{
    
}

/**
 * liefert den Pfad zum IP-Symcon Logverzeichnis
 * 
 * <p>Der Befehl liefert einen String mit dem vollstndigen Pfad zum IP-Symcon Logverzeichnis. Je nach Betriebssystem enthlt der Pfad ein abschlieendes Slash (/) oder Backslash (\).</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/programminformationen/ips-getlogdir/
 * @returns string <p>Gibt den vollstndigen Pfad zum IP-Symcon Logverzeichnis als String zurck</p>
 */
function IPS_GetLogDir()
{
    
}

/**
 * liefert umfassende Information ber ein bestimmtes Medienobjekt
 * 
 * <p>Der Befehl liefert ein Array mit Informationen ber Medien mit der ID <b>MedienID</b>.</p><p>Ab Version 4.0 wird die bis 3.4 vorhandene Funktion als<br>"array IPS_GetMediaCompatibility( integer $MedienID )" zur Verfgung gestellt.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/medienverwaltung/ips-getmedia/
 * @returns array <p>Folgende Informationen stehen als <b>key =&gt; value</b> Paare zur Verfgung:</p><li><b>IsAvailable</b> (bis 3.4)  boolean  TRUE, wenn MediaFile vorhanden (ab Version 4.0 ersetzt durch MediaIsAvailable)</li><li><b>IsLinked</b> (bis 3.4)  boolean  TRUE, wenn Datei auerhalb des Media Ordners liegt (entfllt ab Version 4.0)</li><li><b>LastUpdate</b> (bis 3.4)  integer  Unix Timestamp der letzten Aktualisierung (ab Version 4.0 ersetzt durch MediaUpdated)</li><li><b>MediaCRC</b>  string  CRC32 der Datei</li><li><b>MediaFile</b>  string  Pfad zur Datei</li><li><b>MediaID</b>  integer  MediaID</li><li><b>MediaIsAvailable</b> (ab 4.0)  boolean  TRUE, wenn MediaFile vorhanden</li><li><b>MediaIsCached</b> (ab 4.0)  boolean  TRUE, wenn das Medienobjekt in den Arbeitsspeicher geladen werden soll. Siehe IPS_SetMediaCached</li><li><b>MediaSize</b>  integer  Gre in Byte</li><li><b>MediaType</b>  integer  Medien-Typ (0: Formular, 1: Bild, 2: Ton, 3: Stream, 4: Chart)</li><li><b>MediaUpdated</b> (ab 4.0)  integer  Unix Timestamp der letzten Aktualisierung</li><li><b>SendEvent</b> (bis 3.4)  boolean  TRUE, wenn automatisch Dateinderungen versendet werden sollen (entfllt ab Version 4.0)</li>
 * @param integer $MediaID Die zu zeigende MedienID
 */
function IPS_GetMedia(integer $MediaID)
{
    
}

/**
 * liefert den Inhalt eines Medienobjekts
 * 
 * <p>Diese Funktion liefert den Base64 kodierten Inhalt fr das Medienobjekt mit der ID <b>MedienID</b>. Dabei wird der Inhalt aus der im Medienobjekt definierten Datei ausgelesen.</p><p>Ein praktisches Beispiel fr diese Funktion ist das Einlesen eines Bildes in eine externe Applikation, welche z.B. ber die JSON-RPC API keinen Zugriff auf das Dateisystem hat.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/medienverwaltung/ips-getmediacontent/
 * @returns string <p>Gibt den Inhalt des Medienobjekts Base64 kodiert zurck</p>
 * @param integer $MediaID ID des Medienobjekts, dessen Inhalt geliefert werden soll
 */
function IPS_GetMediaContent(integer $MediaID)
{
    
}

/**
 * ermittelt die ID eines Medienobjekts anhand der Datei
 * 
 * <p>Der Befehl versucht, die ID von Medien mit dem Pfad <b>MedienPfad</b> zu finden. Sollte der MediePfad in IP-Symcon nicht vorhanden sein, wird eine Warnung generiert. Die kann mit dem @ Operator abgefangen werden.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/medienverwaltung/ips-getmediaidbyfile/
 * @returns integer <p>ID des gefundenen Medienobjekts, sonst 0 und Warning</p>
 * @param string $FilePath Relativer MedienPfad vom KernelDir gesehen
 */
function IPS_GetMediaIDByFile(string $FilePath)
{
    
}

/**
 * ermittelt die ID eines Medienobjekts anhand des Namens
 * 
 * <p>Der Befehl versucht die ID von Median mit dem Namen <b>MediaName</b>, dessen bergeordnetes Objekt die ID <b>bergeordneteID</b> besitzt, zu ermitteln. Es wird die ID des ersten gefundenen Medien verwendet, dessen Name mit <b>MediaName</b> bereinstimmt. Falls ein solches Medium gefunden wurde, wird dessen ID zurckgemeldet, andernfalls FALSE.</p><p>Da hier im Gegensatz zu IPS_GetMediaID ein zustzliches Kriterium (bergeordneteID) bei der Suche verwendet wird, ist die Wahrscheinlichkeit die richtige ID zu finden erheblich grer. Trotzdem gilt:</p><p><b>Vorsicht:</b> Da Namen in IP-Symcon beliebig vergeben werden knnen, und damit <b>nicht eindeutig</b> sind, kann der Befehl eine falsche ID zurckmelden.</p><p>Diese Funktion generiert eine <b>Warnung</b>, sollte der Name nicht gefunden werden. Benutzen Sie den @ Operator, falls Sie diese Meldung unterdrcken wollen. Die genau Funktionsweise dieses Operators knnen Sie dem PHP Handbuch entnehmen.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/medienverwaltung/ips-getmediaidbyname/
 * @returns integer <p>ID des gefundenen Medienobjekts, sonst FALSE</p>
 * @param string $Name Zu suchender MedienName
 * @param integer $ParentID 
 */
function IPS_GetMediaIDByName(string $Name, integer $ParentID)
{
    
}

/**
 * liefert eine Liste aller Medienobjekte im MedienPool
 * 
 * <p>Der Befehl ermittelt die IDs aller im MedienPool registrierten Medienobjekte. Die IDs werden in einem Array aufgelistet. Falls kein Medienobjekt existiert, ist das Array leer.</p><p>Es werden Objekte aller Medientypen aufgelistet. Sollen nur Objekte eines bestimmten Medientyps bercksichtigt werden, so kann hierfr der Befehl IPS_GetMediaListByType verwendet werden.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/medienverwaltung/ips-getmedialist/
 * @returns array <p>Ein Array von Integer-Werten aller IDs der Medienobjekte in IP-Symcon</p>
 */
function IPS_GetMediaList()
{
    
}

/**
 * liefert eine Liste aller Medienobjekte eines bestimmten Typs
 * 
 * <p>Der Befehl ermittelt die IDs aller im MedienPool registrierten Medienobjekte eines bestimmten <b>MedienTyps</b>. Die IDs werden in einem Array aufgelistet. Falls kein Medienobjekt des angeforderten Typs existiert, ist das Array leer.</p><p>Es werden nur Objekte des Medientyps <b>MedienTyp</b> aufgelistet. Sollen alle Medienobjekte aufgelistet werden, so kann hierfr der Befehl IPS_GetMediaList verwendet werden.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/medienverwaltung/ips-getmedialistbytype/
 * @returns array <p>Ein Array von Integer-Werten aller IDs der Medienobjekt vom Typ <b>MedienTyp</b> in IP-Symcon</p>
 * @param integer $MediaType 
 *   enum[0=mtForm, 1=mtImage, 2=mtSound, 3=mtStream, 4=mtChart]
 */
function IPS_GetMediaListByType(integer $MediaType)
{
    
}

/**
 * gibt Details zu einem Modul
 * 
 * <p>Der Befehl liefert ein Array mit Informationen ber das Modul mit der ID <b>ModulID</b>.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/modulverwaltung/ips-getmodule/
 * @returns array <p>Folgende Informationen stehen als <b>key =&gt; value</b> Paare zur Verfgung:</p><li><b>Aliases</b>  array  Array von alternativen Namen (string) fr das Modul</li><li><b>ChildRequirements</b>  array  Array von GUIDs (string), die von untergeordnete Objekten erwartet werden</li><li><b>ParentRequirements</b>  array  Array von GUIDs (string), die von bergeordneten Objekten erwartet werden</li><li><b>Implemented</b>  array  Array von GUIDs (string), die das Modul anbietet</li><li><b>LibraryID</b>  string  BibliothekID, in dem das Modul enthalten ist</li><li><b>ModuleID</b>  string       ModulID</li><li><b>ModuleName</b>  string  Name des Moduls</li><li><b>ModuleType</b>  integer  Type des Moduls (0: Kern, 1: I/O,  2: Splitter, 3: Gert, 4: Konfigurator)</li><li><b>Vendor</b>  string  System-/Herstellkennzeichnung</li>
 * @param string $ModuleID Die zu zeigende ModulID
 */
function IPS_GetModule(string $ModuleID)
{
    
}

/**
 * gibt eine Liste aller Module
 * 
 * <p>Der Befehl ermittelt die IDs aller in IP-Symcon verfgbaren Module. Die IDs werden in einem Array aufgelistet.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/modulverwaltung/ips-getmodulelist/
 * @returns array <p>Ein Array von String-Werten aller GUIDs der Module in IP-Symcon</p>
 */
function IPS_GetModuleList()
{
    
}

/**
 * gibt eine Liste aller Module des typs
 * 
 * <p>Der Befehl ermittelt die IDs aller in IP-Symcon verfgbaren Module des angegebenen Typs. Die IDs werden in einem Array aufgelistet.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/modulverwaltung/ips-getmodulelistbytype/
 * @returns array <p>Ein Array von String-Werten aller GUIDs der Module in IP-Symcon mit dem angegebenen Typ</p>
 * @param integer $ModuleType 
 *   enum[0=mtCore, 1=mtIO, 2=mtSplitter, 3=mtDevice, 4=mtConfigurator]
 */
function IPS_GetModuleListByType(integer $ModuleType)
{
    
}

/**
 * IPS_GetModules
 * 
 * @returns array
 * @param array $Parameter
 */
function IPS_GetModules(array $Parameter)
{
    
}

/**
 * liefert den Namen des Objekts
 * 
 * <p>Dieser Befehl gibt den Namen eines Objektes zurck.</p><p>Ab Version 4.0: Wenn das Objekt ein Ereignis ist und keinen Namen hat (Unbenanntes Objekt), wird der beschreibende Name zurckgegeben</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/objektverwaltung/ips-getname/
 * @returns string <p>Name des Objekts im logischen Objektbaum</p>
 * @param integer $ID ID fr die der Namen zurckgegeben werden soll
 */
function IPS_GetName(integer $ID)
{
    
}

/**
 * liefert umfassende Informationen ber ein Objekt
 * 
 * <p>Der Befehl liefert ein Array mit Informationen ber das Objekt mit der ID <b>ObjektID</b>. Sollte das Objekt nicht vorhanden sein, wird eine Warnung generiert.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/objektverwaltung/ips-getobject/
 * @returns array <p>Folgende Informationen stehen als <b>key =&gt; value</b> Paare zur Verfgung:</p><li><b>ChildrenIDs</b>  array  Untergeordnete ObjektIDs. Siehe: IPS_GetChildrenIDs</li><li><b>HasChildren</b>  boolean  TRUE, wenn das Objekt Unterobjekte hat. Siehe: IPS_HasChildren</li><li><b>ObjectID</b>  integer  ObjektID</li><li><b>ObjectIcon</b>  string  Dateiname ohne Erweiterung des Icons. Siehe: IPS_SetIcon</li><li><b>ObjectIdent</b>  string  Identifikator des Objekts. Siehe IPS_SetIdent</li><li><b>ObjectInfo</b>  string  Erweitere Informationen, die der Benutzer angeben kann. Siehe: IPS_SetInfo</li><li><b>ObjectIsDisabled</b> (ab 4.0)  boolean  TRUE, wenn das Objekt inaktiv gesetzt ist. Siehe IPS_SetDisabled</li><li><b>ObjectIsHidden</b>  boolean  TRUE, wenn das Objekt in der Visualisierung versteckt sein soll. Siehe IPS_SetHidden</li><li><b>ObjectIsReadOnly</b>  boolean  TRUE, wenn das Objekt schreibgeschtzt ist. (Wird zur Zeit nur fr Status Variablen benutzt)</li><li><b>ObjectName</b>  string  Name des Objekts. Siehe: IPS_SetName</li><li><b>ObjectPosition</b>  integer  Position, die das Objekt in der Visualisierung haben soll. Dieser Wert muss nicht unbedingt eindeutig sein. Siehe: IPS_SetPosition</li><li><b>ObjectType</b>  integer  Objekt-Typ (0: Kategorie, 1: Instanz, 2: Variable, 3: Skript, 4: Ereignis, 5: Media, 6: Link)</li><li><b>ObjectSummary</b>  string  Kurzbeschreibung eines Objektes, welches vom Modul zur Laufzeit bei Bedarf generiert wird.</li><li><b>ParentID</b>  integer  bergeordnetes Objekt. 0 = Kein bergeordnetes Objekt. Siehe: IPS_SetParent</li>
 * @param integer $ID Die zu zeigende ObjektID
 */
function IPS_GetObject(integer $ID)
{
    
}

/**
 * liefert die ID eines Objekts anhand des Identifikators
 * 
 * <p>Der Befehl versucht die ID des Objekts mit dem Identifikator <b>ObjektIdent</b>, dessen bergeordnetes Objekt die ID <b>bergeordneteID</b> besitzt, zu ermitteln. Falls ein solches Objekt gefunden wurde, wird dessen ID zurckgemeldet, andernfalls FALSE.</p><p><b>Unterschied zu IPS_GetObjectIDByName:</b> Da ObjektIdents innerhalb einer Ebene in IP-Symcon eindeutig sind, wird entweder eine einzelne ID zurckgegeben oder eine Fehlermeldung generiert.</p><p>Diese Funktion generiert eine <b>Warnung</b>, sollte der Name nicht gefunden werden. Benutzen Sie den @ Operator, falls Sie diese Meldung unterdrcken wollen. Die genau Funktionsweise dieses Operators knnen Sie dem PHP Handbuch entnehmen.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/objektverwaltung/ips-getobjectidbyident/
 * @returns integer <p>ID des gefundenen Objekts, sonst FALSE</p>
 * @param string $Ident Zu suchender ObjektIdentifikator
 * @param integer $ParentID Objekt, in dessen direkten Unterobjekten gesucht werden soll
 */
function IPS_GetObjectIDByIdent(string $Ident, integer $ParentID)
{
    
}

/**
 * liefert die ID eines Objekts anhand des Namens
 * 
 * <p>Der Befehl versucht die ID des Objekts mit dem Namen <b>ObjektName</b>, dessen bergeordnetes Objekt die ID <b>bergeordneteID</b> besitzt, zu ermitteln. Es wird die ID des ersten gefundenen Objekts verwendet, dessen Name mit <b>ObjektName</b> bereinstimmt. Falls ein solches Objekt gefunden wurde, wird dessen ID zurckgemeldet, andernfalls FALSE.</p><p><b>Vorsicht:</b> Da Namen in IP-Symcon beliebig vergeben werden knnen, und damit <b>nicht eindeutig</b> sind, kann der Befehl eine falsche ID zurckmelden.</p><p>Diese Funktion generiert eine <b>Warnung</b>. Sollte der Name nicht gefunden werden, benutzen Sie den @ Operator, falls Sie diese Meldung unterdrcken wollen. Die genau Funktionsweise dieses Operators knnen Sie dem PHP Handbuch entnehmen.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/objektverwaltung/ips-getobjectidbyname/
 * @returns integer <p>ID des gefundenen Objekts, sonst FALSE</p>
 * @param string $Name Zu suchender ObjektName
 * @param integer $ParentID Objekt, in dessen direkten Unterobjekten gesucht werden soll
 */
function IPS_GetObjectIDByName(string $Name, integer $ParentID)
{
    
}

/**
 * liefert eine Aufstellung aller existierenden Objekte
 * 
 * <p>Der Befehl ermittelt die IDs aller in IP-Symcon registrierten Objekte. Die IDs werden in einem Array aufgelistet.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/objektverwaltung/ips-getobjectlist/
 * @returns array <p>Ein Array von Integer-Werten aller IDs in IP-Symcon</p>
 */
function IPS_GetObjectList()
{
    
}

/**
 * IPS_GetOption
 * 
 * @returns integer
 * @param string $Option
 */
function IPS_GetOption(string $Option)
{
    
}

/**
 * liefert die ParentID des Objekts
 * 
 * <p>Dieser Befehl gibt die ParentID eines Objektes zurck.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/objektverwaltung/ips-getparent/
 * @returns integer <p>ParentID des Objekts im logischen Objektbaum</p>
 * @param integer $ID ID fr die die ParentID zurckgegeben werden soll
 */
function IPS_GetParent(integer $ID)
{
    
}

/**
 * setzt einen neuen Wert fr eine Eigenschaft
 * 
 * <p>Dieser Befehl liest fr die <b>InstanzID</b> den Ist-Wert der <b>Eigenschaft</b> ein. Eine genaue Auflistung der mglichen Eigenschaften fr die einzelnen Instanzen finden Sie in der Beschreibung des Befehls IPS_SetProperty.Sie knnen einen neuen Soll-Wert mit IPS_SetProperty bergeben und mit IPS_ApplyChanges bernehmen lassen.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/instanzenverwaltung/konfiguration/ips-getproperty/
 * @returns mixed <p>Aktueller Wert der Eigenschaft</p>
 * @param integer $InstanceID ID der Instanz
 * @param string $Name Name der Eigenschaft
 */
function IPS_GetProperty(integer $InstanceID, string $Name)
{
    
}

/**
 * liefert umfassende Informationen ber ein Skript
 * 
 * <p>Der Befehl liefert ein Array mit Informationen ber das Skript mit der ID <b>SkriptID</b>.</p><p>Ab Version 4.0 wird die bis 3.4 vorhandene Funktion als<br>"array IPS_GetScriptCompatibility( integer $SkriptIDID )" zur Verfgung gestellt.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/skriptverwaltung/ips-getscript/
 * @returns array <p>Folgende Informationen stehen als <b>key =&gt; value</b> Paare zur verfgung:</p><li><b>IsBroken</b> (bis 3.4)  boolean  TRUE, wenn beim letzten Skriptaufruf Fehler aufgetreten sind, andernfalls FALSE (ab 4.0 ersetzt durch ScriptIsBroken)</li><li><b>LastExecute</b>  (bis 3.4)  integer  Unix Timestamp des letzten Aufrufs (ab 4.0 ersetzt durch ScriptExecuted)</li><li><b>ScriptIsBroken</b> (ab 4.0)  boolean  TRUE, wenn beim letzten Skriptaufruf Fehler aufgetreten sind, andernfalls FALSE</li><li><b>ScriptExecuted</b>  (ab 4.0)  integer  Unix Timestamp des letzten Aufrufs</li><li><b>ScriptFile</b>  string  Dateiname des Skripts</li><li><b>ScriptID</b>  integer  SkriptID</li><li><b>ScriptType</b>  integer  Skript-Typ (0: PHP Skript)</li>
 * @param integer $ScriptID Die zu zeigende SkriptID
 */
function IPS_GetScript(integer $ScriptID)
{
    
}

/**
 * liefert den Inhalt eines Skripts
 * 
 * <p>Diese Funktion liefert den Inhalt fr das Skript mit der ID <b>SkriptID</b>. Dabei wird der Inhalt aus der im Skript-Objekt definierten Datei ausgelesen.</p><p>Ein praktisches Beispiel fr diese Funktion ist das Einlesen eines Skripts in einen externen Editor, welcher z.B. ber die JSON-RPC API keinen Zugriff auf das Dateisystem hat.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/skriptverwaltung/ips-getscriptcontent/
 * @returns string <p>Gibt den Inhalt des Skripts zurck</p>
 * @param integer $ScriptID ID des Skripts, dessen Inhalt geliefert werden soll
 */
function IPS_GetScriptContent(integer $ScriptID)
{
    
}

/**
 * liefert alle Ereignisse die einem Skript zugeordnet sind
 * 
 * <p>Der Befehl liefert ein Array, dessen Elemente jeweils die IDs zu den Ereignissen des Skripts mit der ID <b>SkriptID</b> enthalten. Die Ereignisse knnen dann mit dem Befehl IPS_GetEvent weiterverarbeitet werden.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/skriptverwaltung/ips-getscripteventlist/
 * @returns array <p>Ein Array von Integer-Werten aller EreignisIDs, die mit dem Skript <b>SkriptID</b> verknpft sind</p>
 * @param integer $ScriptID SkriptID, zu der verknpfte Ereignisse gesucht werden sollen
 */
function IPS_GetScriptEventList(integer $ScriptID)
{
    
}

/**
 * ermittelt den Dateinamen zur SkriptID
 * 
 * <p>Der Befehl gibt den Dateinamenvom Skript mit der ID <b>SkriptID</b> zurck. Dadurch kann die Datei z.B. direkt in andere Skripte inkludiert werden.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/skriptverwaltung/ips-getscriptfile/
 * @returns string <p>Gibt den Dateinamen des Skripts zurck</p>
 * @param integer $ScriptID ID des Skripts, dem der Dateiname zugeordnet werden soll
 */
function IPS_GetScriptFile(integer $ScriptID)
{
    
}

/**
 * liefert die ID eines Skripts andhand der Datei
 * 
 * <p>Der Befehl versucht die ID des Skripts herausfinden, welches zur Skriptdatei <b>Dateipfad</b> zugeordnet ist. Falls ein solches Skript gefunden wurde, wird dessen ID zurckgemeldet, andernfalls FALSE.</p><p>Diese Funktion generiert eine <b>Warnung</b>, sollte der Name nicht gefunden werden. Benutzen Sie den @ Operator, falls Sie diese Meldung unterdrcken wollen. Die genau Funktionsweise dieses Operators knnen Sie dem PHP Handbuch entnehmen.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/skriptverwaltung/ips-getscriptidbyfile/
 * @returns integer <p>ID des gefundenen Skripts, sonst FALSE</p>
 * @param string $FilePath Relativer Dateipfad vom script-Order gesehen
 */
function IPS_GetScriptIDByFile(string $FilePath)
{
    
}

/**
 * liefert die ID eines Skripts andhand des Namens
 * 
 * <p>Der Befehl versucht die ID des Skripts mit dem Namen <b>SkriptName</b>, dessen bergeordnetes Objekt die ID <b>bergeordneteID</b> besitzt, zu ermitteln. Es wird die ID des ersten gefundenen Skripts verwendet, dessen Name mit <b>SkriptName</b> bereinstimmt. Falls ein solches Skript gefunden wurde, wird dessen ID zurckgemeldet, andernfalls FALSE.</p><p>Da hier im Gegensatz zu IPS_GetScriptID ein zustzliches Kriterium (bergeordneteID) bei der Suche verwendet wird, ist die Wahrscheinlichkeit die richtige ID zu finden erheblich grer. Trotzdem gilt:</p><p><b>Vorsicht:</b> Da Namen in IP-Symcon beliebig vergeben werden knnen, und damit <b>nicht eindeutig</b> sind, kann der Befehl eine falsche ID zurckmelden.</p><p>Diese Funktion generiert eine <b>Warnung</b>, sollte der Name nicht gefunden werden. Benutzen Sie den @ Operator, falls Sie diese Meldung unterdrcken wollen. Die genau Funktionsweise dieses Operators knnen Sie dem PHP Handbuch entnehmen.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/skriptverwaltung/ips-getscriptidbyname/
 * @returns integer <p>ID des gefundenen Skripts, sonst FALSE</p>
 * @param string $Name zu suchender SkriptName
 * @param integer $ParentID Objekt in deren direkten Unterobjekten gesucht werden soll
 */
function IPS_GetScriptIDByName(string $Name, integer $ParentID)
{
    
}

/**
 * liefert eine Aufstellung aller existierenden Skripte
 * 
 * <p>Der Befehl ermittelt die IDs aller in IP-Symcon registrierten Skripte. Die IDs werden in einem Array aufgelistet. Falls kein Skript existiert, ist das Array leer.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/skriptverwaltung/ips-getscriptlist/
 * @returns array <p>Ein Array von Integer-Werten aller IDs der Skripte in IP-Symcon</p>
 */
function IPS_GetScriptList()
{
    
}

/**
 * IPS_GetScriptThread
 * 
 * @returns array
 * @param integer $ThreadID
 */
function IPS_GetScriptThread(integer $ThreadID)
{
    
}

/**
 * IPS_GetScriptThreadList
 * 
 * @returns array
 */
function IPS_GetScriptThreadList()
{
    
}

/**
 * IPS_GetScriptThreads
 * 
 * @returns array
 * @param array $Parameter
 */
function IPS_GetScriptThreads(array $Parameter)
{
    
}

/**
 * ermittelt den Startwert des ScriptTimers
 * 
 * <p>Der Befehl liefert einen Integer-Wert mit dem Startwert des ScriptTimers des Skripts mit der ID <b>SkriptID</b>. Der Wert wird in Sekunden angegeben. Mit diesem Befehl kann man prfen, auf welchen Wert der ScriptTimer eines Skripts gesetzt ist und ob dieser korrekt ist.</p><p>Steht der Wert auf 0, so ist der Timer abgeschaltet, und es erfolgt kein Timer-Event.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/skriptverwaltung/ips-getscripttimer/
 * @returns integer <p>Zeit in Sekunden, die der Timer das Skript zyklisch aufruft. (Es ist nicht die Restzeit.)</p>
 * @param integer $ScriptID ID des Skripts, dessen Timer ausgelesen werden soll
 */
function IPS_GetScriptTimer(integer $ScriptID)
{
    
}

/**
 * IPS_GetSnapshot
 * 
 * @returns array
 */
function IPS_GetSnapshot()
{
    
}

/**
 * IPS_GetSnapshotChanges
 * 
 * @returns array
 * @param integer $LastTimestamp
 */
function IPS_GetSnapshotChanges(integer $LastTimestamp)
{
    
}

/**
 * IPS_GetTimer
 * 
 * @returns array
 * @param integer $TimerID
 */
function IPS_GetTimer(integer $TimerID)
{
    
}

/**
 * IPS_GetTimerList
 * 
 * @returns array
 */
function IPS_GetTimerList()
{
    
}

/**
 * IPS_GetTimers
 * 
 * @returns array
 * @param array $Parameter
 */
function IPS_GetTimers(array $Parameter)
{
    
}

/**
 * liefert umfassende Informationen zu einer bestimmten Variablen
 * 
 * <p>Der Befehl liefert ein Array mit Informationen ber die Variable mit der ID <b>VariablenID</b>.</p><p>Um den Wert einer Variable zu bekommen muss ab Version 4.0 die Funktion GetValue genutzt werden</p><p>Ab Version 4.0 wird die bis 3.4 vorhandene Funktion als<br>"array IPS_GetVariableCompatibility( integer $VariablenID )" zur Verfgung gestellt.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/variablenverwaltung/ips-getvariable/
 * @returns array <p>Folgende Informationen stehen als <b>key =&gt; value</b> Paare zur Verfgung:</p><li><b>VariableAction</b>  integer  ID der Instanz, die bei einer gewnschten nderungen der Variable den nderungswunsch entgegen nimmt. 0 bei keiner oder einer deaktivierten Verknpfung.</li><li><b>VariableChanged</b>  integer  Unix-Timestamp, wenn die Variable zuletzt verndert wurde</li><li><b>VariableCustomAction</b>  integer  ID des Skriptes, dass bei einer gewnschten nderung der Variable ber die Visualisierung gestartet werden soll. Sofern aktuell eine vorhandene Standardaktion deaktiviert wird, ist die nichtvorhandene SkriptID Eins (1) angegeben. (Ab Version 2.5 #2300)</li><li><b>VariableCustomProfile</b>  string  Name vom Benutzer gegebenen Profil. Leer, falls kein Profil angeben.</li><li><b>VariableID</b>  integer  VariablenID</li><li><b>VariableIsBinary</b>  boolean  Gibt an, ob die String Variable ber SOAP Base64 kodiert wird.</li><li><b>VariableIsLocked</b>  boolean  Gibt an, ob diese Variable oberhalb des Variablenlimits ist und deshalb nicht beschrieben werden kann (Verfgbar ab Version 2.3).</li><li><b>VariableProfile</b>  string  Name vom System gegebenen Profil. Leer, falls kein Profil angegben</li><li><b>VariableType</b> (ab 4.0)  integer  Enthlt den Variablentyp (0: Boolean, 1: Integer,  2: Float, 3: String)</li><li><b>VariableUpdated</b>  integer  Unix-Timestamp, wenn die Variable zuletzt aktualisiert wurde</li><li><b>VariableValue</b> (bis 3.4)  array  Siehe Tabelle Variablenwert (durch VariableType und GetValue ersetzt)</li><p><em>Tabelle: VariablenWert (bis 3.4)</em></p><li><b>ValueType</b>  integer  Variablentyp (0: Boolean, 1: Integer,  2: Float, 3: String)</li><li><b>ValueBoolean</b>  boolean  Wert der Variable abhngig vom <b>ValueType</b></li><li><b>ValueInteger</b>  integer  Wert der Variable abhngig vom <b>ValueType</b></li><li><b>ValueFloat</b>  float  Wert der Variable abhngig vom <b>ValueType</b></li><li><b>ValueString</b>  string   Wert der Variable abhngig vom <b>ValueType</b></li>
 * @param integer $VariableID Die zu zeigende VariablenID
 */
function IPS_GetVariable(integer $VariableID)
{
    
}

/**
 * liefert alle Ereignisse die einer Variable zugeordnet sind
 * 
 * <p>Der Befehl liefert ein Array, dessen Elemente jeweils die IDs zu den Ereignissen sind, in der die Variable <b>VariableID</b> verwendet wird. Die Ereignisse knnen dann mit dem Befehl IPS_GetEvent weiterverarbeitet werden.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/variablenverwaltung/ips-getvariableeventlist/
 * @returns array <p>Ein Array von Integer-Werten aller EreignisIDs, die mit der Variable <b>VariablenID</b> verknpft sind</p>
 * @param integer $VariableID VariablenID, zu der verknpfte Ereignisse gesucht werden sollen
 */
function IPS_GetVariableEventList(integer $VariableID)
{
    
}

/**
 * liefert die ID einer Variablen anhand des Namens
 * 
 * <p>Der Befehl versucht die ID der Variablen mit dem Namen <b>VariablenName</b>, deren bergeordnetes Objekt die ID <b>bergeordneteID</b> besitzt, zu ermitteln. Es wird die ID der ersten gefundenen Variablen verwendet, deren Name mit <b>VariablenName</b> bereinstimmt. Falls eine solche Variable gefunden wurde, wird deren ID zurckgemeldet, andernfalls FALSE.</p><p>Da hier im Gegensatz zu IPS_GetVariableID ein zustzliches Kriterium (bergeordneteID) bei der Suche verwendet wird, ist die Wahrscheinlichkeit die richtige ID zu finden erheblich grer. Trotzdem gilt:</p><p><b>Vorsicht:</b> Da Namen in IP-Symcon beliebig vergeben werden knnen, und damit <b>nicht eindeutig</b> sind, kann der Befehl eine falsche ID zurckmelden.</p><p>Diese Funktion generiert eine <b>Warnung</b>, sollte der Name nicht gefunden werden. Benutzen Sie den @ Operator, falls Sie diese Meldung unterdrcken wollen. Die genau Funktionsweise dieses Operators knnen Sie dem PHP Handbuch entnehmen.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/variablenverwaltung/ips-getvariableidbyname/
 * @returns integer <p>ID der gefundenen Variable, sonst FALSE</p>
 * @param string $Name Zu suchender VariablenName
 * @param integer $ParentID Objekt, in deren direkten Unterobjekten gesucht werden soll
 */
function IPS_GetVariableIDByName(string $Name, integer $ParentID)
{
    
}

/**
 * liefert eine Liste aller existierenden Variablen
 * 
 * <p>Der Befehl ermittelt die IDs aller in IP-Symcon registrierten IPS-Variablen. Die IDs werden in einem Array aufgelistet. Falls keine Variable existiert, ist das Array leer.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/variablenverwaltung/ips-getvariablelist/
 * @returns array <p>Ein Array von Integer-Werten aller IDs der Variablen in IP-Symcon</p>
 */
function IPS_GetVariableList()
{
    
}

/**
 * liefert umfassende Informationen zu einem bestimmten Variablenprofil
 * 
 * <p>Der Befehl liefert ein Array mit Informationen ber das Variableprofil mit dem Namen <b>ProfilName</b>.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/variablenverwaltung/variablenprofile/ips-getvariableprofile/
 * @returns array <p>Folgende Informationen stehen als <b>key =&gt; value</b> Paare zur Verfgung:</p><li><b>Associations</b>  array  Array mit Wert, Name, Icon, Color Paaren (siehe Associations Tabelle)</li><li><b>Icon</b>  string  Icon des Variablenprofils</li><li><b>IsReadOnly</b>  boolean  TRUE, wenn es ein systemerstelltes Profil ist, welches nicht gendert werden kann.</li><li><b>MaxValue</b>  float  Maximalwert fr die Visualisierung</li><li><b>MinValue</b>  float  Minimalwert fr die Visualisierung</li><li><b>StepSize</b>  float  Schrittweite fr die Visualisierung; 0, wenn Assoziationstabelle genutzt werden soll</li><li><b>Digits</b>  integer  Anzahl der Nachkommastellen</li><li><b>Prefix</b>  string  Prfix fr die Visualisierung</li><li><b>Suffix</b>  string  Suffix fr die Visualisierung</li><li><b>ProfileName</b>  string  Name des Profils (~ = Systemprofil)</li><li><b>ProfileType</b>  integer  Typ des Profils (Siehe VariablenTyp)</li><p><b>Associations Tabelle</b></p><li><b>Value</b>  double  Wert, zu dem der Name und das Icon verknpft werden sollen</li><li><b>Name</b>  string  Name zum angegebenen Wert</li><li><b>Icon</b>  string  Icon zum angegebenen Wert</li><li><b>Color</b>  integer  Farbwert im HTML Farbcode (z.b. 0x0000FF fr Blau). Sonderfall: -1 fr transparent</li>
 * @param string $ProfileName Name des Variablenprofils
 */
function IPS_GetVariableProfile(string $ProfileName)
{
    
}

/**
 * liefert eine Liste aller existierenden Variablenprofile
 * 
 * <p>Der Befehl ermittelt in IP-Symcon vorhandenen Variablenprofile. Die Namen werden in einem Array aufgelistet.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/variablenverwaltung/variablenprofile/ips-getvariableprofilelist/
 * @returns array <p>Ein Array von String-Werten aller Namen der Variablenprofile</p>
 */
function IPS_GetVariableProfileList()
{
    
}

/**
 * liefert eine Liste aller existierenden Variablenprofile eines bestimmten Typs
 * 
 * <p>Der Befehl ermittelt in IP-Symcon vorhandenen Variablenprofile vom Typ <b>Variablentyp</b>. Die Namen werden in einem Array aufgelistet.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/variablenverwaltung/variablenprofile/ips-getvariableprofilelistbytype/
 * @returns array <p>Ein Array von String-Werten aller Namen der Variablenprofile</p>
 * @param integer $ProfileType 
 *   enum[0=vtBoolean, 1=vtInteger, 2=vtFloat, 3=vtString]
 */
function IPS_GetVariableProfileListByType(integer $ProfileType)
{
    
}

/**
 * prft, ob eine Konfiguration verndert wurde
 * 
 * <p>Der Befehl berprft, ob bei einer Instanz nderungen an der Konfiguration vorgenommen wurden, die als aktuelle Ist-Konfiguration bernommen werden soll.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/instanzenverwaltung/konfiguration/ips-haschanges/
 * @returns boolean <p><b>TRUE</b>, wenn es nderungen gibt, sonst <b>FALSE</b></p>
 * @param integer $InstanceID ID der zu berprfenden Instanz
 */
function IPS_HasChanges(integer $InstanceID)
{
    
}

/**
 * prft, ob Objekt untergeordnete Objekte hat
 * 
 * <p>Der Befehl prft, ob ein Objekt mit der ID <b>ObjektID</b> untergeordnete Objekte hat.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/objektverwaltung/ips-haschildren/
 * @returns boolean <p><b>TRUE</b>, falls das Objekte Unterobjekte hat, andernfalls <b>FALSE</b></p>
 * @param integer $ID ID des zu prfenden Objekts
 */
function IPS_HasChildren(integer $ID)
{
    
}

/**
 * prft, ob eine bestimmte Instanz existiert
 * 
 * <p>Der Befehl prft, ob die Instanz mit der ID <b>InstanzID</b> existiert.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/instanzenverwaltung/ips-instanceexists/
 * @returns boolean <p>Falls die InstanzID im System existiert, wird <b>TRUE</b> zurckgemeldet, andernfalls <b>FALSE</b>.</p>
 * @param integer $InstanceID ID der zu prfenden Instanz
 */
function IPS_InstanceExists(integer $InstanceID)
{
    
}

/**
 * prft, ob Objekt einem anderen Objekt untergeordnet ist
 * 
 * <p>Der Befehl prft, ob ein Objekt mit der ID <b>ObjektID</b> dem Objekt <b>ParentID</b> untergeordnet ist. Ist der Parameter <b>Rekursiv</b> aktiviert, werden alle untergeordneten Objekte auf allen untergeordneten Ebenen berprft. Andernfalls werden nur die direkt untergeordneten Objekte berprft.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/objektverwaltung/ips-ischild/
 * @returns boolean <p><b>TRUE</b>, wenn ObjektID Kind von ParentID ist, sonst <b>FALSE</b></p>
 * @param integer $ID ID des zu prfenden Objekts
 * @param integer $ParentID ID des vermeintlichen Elternobjekts
 * @param boolean $Recursive False, wenn nur eine Ebene geprft werden soll, sonst True
 */
function IPS_IsChild(integer $ID, integer $ParentID, boolean $Recursive)
{
    
}

/**
 * prft, ob eine Verbindung zwischen zwei Instanzen mglich ist
 * 
 * <p>Der Befehl ermittelt, ob zwei Instanzen zueinander kompatibel sind.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/instanzenverwaltung/verbindungen/ips-isinstancecompatible/
 * @returns boolean <p><b>TRUE</b>, wenn die Instanz kompatibel sind, sonst <b>FALSE</b></p>
 * @param integer $InstanceID erste InstanzID
 * @param integer $ParentInstanceID zweite InstanzID
 */
function IPS_IsInstanceCompatible(integer $InstanceID, integer $ParentInstanceID)
{
    
}

/**
 * berprft, ob zwei Modul miteinander Kompatibel sind
 * 
 * <p>Der Befehl ermittelt, ob zwei Module zueinander kompatibel sind.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/modulverwaltung/ips-ismodulecompatible/
 * @returns boolean <p><b>TRUE</b>, wenn die Module kompatibel sind, sonst <b>FALSE</b></p>
 * @param string $ModuleID Erste ModulID
 * @param string $ParentModuleID Zweite ModulID
 */
function IPS_IsModuleCompatible(string $ModuleID, string $ParentModuleID)
{
    
}

/**
 * IPS_IsSearching
 * 
 * @returns boolean
 * @param integer $InstanceID
 */
function IPS_IsSearching(integer $InstanceID)
{
    
}

/**
 * berprft, ob Bibliothek existiert
 * 
 * <p>Der Befehl prft, ob die Bibliothek mit der ID <b>BibliothekID</b> existiert.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/modulverwaltung/ips-libraryexists/
 * @returns boolean <p>Falls die BibliothekID im System existiert, wird <b>TRUE</b> zurckgemeldet, andernfalls <b>FALSE</b>.</p>
 * @param string $LibraryID ID der zu prfenden Bibliothek
 */
function IPS_LibraryExists(string $LibraryID)
{
    
}

/**
 * prft, ob ein Link bereits existiert
 * 
 * <p>Der Befehl prft, ob der Link mit der ID <b>LinkID</b> existiert.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/linkverwaltung/ips-linkexists/
 * @returns boolean <p>Falls die LinkID im System existiert, wird <b>TRUE</b> zurckgemeldet, andernfalls <b>FALSE</b>.</p>
 * @param integer $LinkID ID der zu prfenden Links
 */
function IPS_LinkExists(integer $LinkID)
{
    
}

/**
 * schreibt eine benutzerdefinierte Meldung in die Log-Datei
 * 
 * <p>Der Befehl schreibt unter Angabe des Absenders <b>Sender</b> den String <b>Meldung</b> in die IP-Symcon Log-Datei. Der String <b>Sender</b> gibt dabei den Verursacher der Meldung an, z.B. den Namen des Skripts. Die Ausgabe der Meldung kann als Custom Message live im Meldungsfenster beobachtet werden.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/programminformationen/ips-logmessage/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param string $Sender Beliebiger Absenderstring
 * @param string $Message Beliebiger Meldungsstring
 */
function IPS_LogMessage(string $Sender, string $Message)
{
    
}

/**
 * prft, ob sich ein bestimmtes Medienobjekt bereits im MedienPool befindet
 * 
 * <p>Der Befehl prft, ob das Medienobjekt mit der ID <b>MediaID</b> existiert.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/medienverwaltung/ips-mediaexists/
 * @returns boolean <p>Falls die MedienID im System existiert, wird <b>TRUE</b> zurckgemeldet, andernfalls <b>FALSE</b>.</p>
 * @param integer $MediaID ID des zu rfenden Medienobjekts
 */
function IPS_MediaExists(integer $MediaID)
{
    
}

/**
 * berprft, ob Modul existiert
 * 
 * <p>Der Befehl prft, ob das Modul mit der ID <b>ModulID</b> existiert.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/modulverwaltung/ips-moduleexists/
 * @returns boolean <p>Falls die ModulID im System existiert, wird <b>TRUE</b> zurckgemeldet, andernfalls <b>FALSE</b></p>
 * @param string $ModuleID ID des zu prfenden Moduls
 */
function IPS_ModuleExists(string $ModuleID)
{
    
}

/**
 * prft, ob ein bestimmtes Objekt existiert
 * 
 * <p>Der Befehl prft, ob ein Objekt mit der ID <b>ObjektID</b> existiert.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/objektverwaltung/ips-objectExists/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $ID Die zu prfende ObjektID
 */
function IPS_ObjectExists(integer $ID)
{
    
}

/**
 * IPS_RegisterPropertyBoolean
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param string $Name
 * @param boolean $DefaultValue
 */
function IPS_RegisterPropertyBoolean(integer $InstanceID, string $Name, boolean $DefaultValue)
{
    
}

/**
 * IPS_RegisterPropertyFloat
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param string $Name
 * @param float $DefaultValue
 */
function IPS_RegisterPropertyFloat(integer $InstanceID, string $Name, float $DefaultValue)
{
    
}

/**
 * IPS_RegisterPropertyInteger
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param string $Name
 * @param integer $DefaultValue
 */
function IPS_RegisterPropertyInteger(integer $InstanceID, string $Name, integer $DefaultValue)
{
    
}

/**
 * IPS_RegisterPropertyString
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param string $Name
 * @param string $DefaultValue
 */
function IPS_RegisterPropertyString(integer $InstanceID, string $Name, string $DefaultValue)
{
    
}

/**
 * IPS_RequestAction
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param string $VariableIdent
 * @param mixed $Value
 */
function IPS_RequestAction(integer $InstanceID, string $VariableIdent, mixed $Value)
{
    
}

/**
 * setzt eine vernderte Konfiguration auf die aktuelle zurck
 * 
 * <p>Der Befehl berschreibt die neue Soll-Konfiguration durch die aktuelle Ist-Konfiguration.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/instanzenverwaltung/konfiguration/ips-resetchanges/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID der zu ndernden Instanz
 */
function IPS_ResetChanges(integer $InstanceID)
{
    
}

/**
 * startet ein anderes IP-Symcon Skript
 * 
 * <p>Der Befehl veranlasst den Start des Skripts mit der ID <b>SkriptID</b>. Das aufgerufene Skript luft parallel (gleichzeitig) zum aufrufenden Skript.</p><p><b>Vergleich zwischen IPS_RunScript und der PHP-Anweisung include</b>:</p><p><b>include</b> ist eine PHP-Anweisung, kein IPS-Befehl. Das durch <b>include</b> eingebundene Skript wird so abgearbeitet, als stnde es anstelle der <b>include</b>-Anweisung. Es wirkt sich so aus, als wre es ein Bestandteil des aufrufenden Skripts. Das bedeutet, dass alle Variablen, die dem aufrufenden Skript bekannt sind auch dem eingebundenen Skript zur Verfgung stehen. Die Laufzeit des Skripts verlngert sich um die Laufzeit des eingebundenen Skripts.</p><p>Bei Verwendung von <b>IPS_RunScript</b> wird das aufgerufene Skript in einem eigenen Kontext gestartet. Es wei also folglich nichts von den Variablen des aufrufenden Skripts. Daten knnen hier nur ber externe Variablen ausgetauscht werden. Der Befehl ist geeignet fr Situationen, wo ein Skript zeitgerecht ausgefhrt werden muss, aber kein direkter Bezug zum aufrufenden Skript erforderlich ist. Die Laufzeit des Skripts ndert sich nicht, da beide Skripte (quasi) gleichzeitig ausgefhrt werden.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/ablaufsteuerung/ips-runscript/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $ScriptID Eindeutige ID des Skriptes
 */
function IPS_RunScript(integer $ScriptID)
{
    
}

/**
 * startet ein anderes IP-Symcon Skript und bergibt Variablen
 * 
 * <p>Der Befehl veranlasst den Start des Skripts mit der ID <b>SkriptID</b> und bergibt dabei das Array Parameter als Argument. Das aufgerufene Skript luft parallel (gleichzeitig) zum aufrufenden Skript. Auch hier gelten die bei IPS_RunScript beschriebenen Hinweise.</p><p>Das Array <b>Parameter</b> kann beliebig viele <b>Key =&gt; Value</b> Paare enthalten (siehe PHP Arrays). Jedes Paar erscheint im aufgerufenen Skript als Variable <b>Key</b> mit ihrem Inhalt <b>Value</b>.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/ablaufsteuerung/ips-runscriptex/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $ScriptID Eindeutige ID des Skriptes
 * @param array $Parameters Key (string) =&gt; Value (variant) Paar auf die im neu ausgefhrten Skript zu gegriffen werden kann.
 */
function IPS_RunScriptEx(integer $ScriptID, array $Parameters)
{
    
}

/**
 * startet einen Text als IP-Symcon Skript
 * 
 * <p>Der Befehl startet ein Skript mit dem Inhalt <b>SkriptText</b>. Es ist nicht ntig PHP-Tags mit anzugeben.</p><p>Bei Verwendung von <b>IPS_RunScriptText</b> wird der als Skript aufgerufene Text in einem eigenen Kontext gestartet. Es wei also folglich nichts von den Variablen des aufrufenden Skripts. Daten knnen hier nur ber externe Variablen ausgetauscht werden. Der Befehl ist geeignet fr Situationen, wo ein Skript zeitgerecht ausgefhrt werden muss, aber kein direkter Bezug zum aufrufenden Skript erforderlich ist. Die Laufzeit des Skripts ndert sich nicht, da beide Skripte (quasi) gleichzeitig ausgefhrt werden.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/ablaufsteuerung/ips-runscripttext/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param string $ScriptText String welcher als Skript aufgerufen werden soll.
 */
function IPS_RunScriptText(string $ScriptText)
{
    
}

/**
 * startet einen Text als IP-Symcon Skript und bergibt Variablen
 * 
 * <p>Der Befehl startet ein Skript mit dem Inhalt <b>SkriptText</b>. Es ist nicht ntig PHP-Tags mit anzugeben.</p><p>Bei Verwendung von <b>IPS_RunScriptTextEx</b> wird der als Skript aufgerufene Text in einem eigenen Kontext gestartet. Es wei also folglich nichts von den Variablen des aufrufenden Skripts. Daten knnen hier nur ber externe Variablen ausgetauscht werden. Der Befehl ist geeignet fr Situationen, wo ein Skript zeitgerecht ausgefhrt werden muss, aber kein direkter Bezug zum aufrufenden Skript erforderlich ist. Die Laufzeit des Skripts ndert sich nicht, da beide Skripte (quasi) gleichzeitig ausgefhrt werden.</p><p>Das Array <b>Parameter</b> kann beliebig viele <b>Key =&gt; Value</b> Paare enthalten (siehe PHP Arrays). Jedes Paar erscheint im aufgerufenen Skript als Variable <b>Key</b> mit ihrem Inhalt <b>Value</b>.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/ablaufsteuerung/ips-runscripttextex/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param string $ScriptText String welcher als Skript aufgerufen werden soll.
 * @param array $Parameters Key (string) =&gt; Value (variant) Paar auf die im neu ausgefhrten Skript zugegriffen werden kann.
 */
function IPS_RunScriptTextEx(string $ScriptText, array $Parameters)
{
    
}

/**
 * startet einen Text als IP-Symcon Skript
 * 
 * <p>Der Befehl startet ein Skript mit dem Inhalt <b>SkriptText</b> und wartet auf das Ende der Skriptausfhrung, um das Resultat als Rckgabewert zu bergeben. Es ist nicht ntig PHP-Tags mit anzugeben.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/ablaufsteuerung/ips-runscripttextwait/
 * @returns string <p>Resultat des ausgefhrten Skripts</p>
 * @param string $ScriptText String welcher als Skript aufgerufen werden soll.
 */
function IPS_RunScriptTextWait(string $ScriptText)
{
    
}

/**
 * startet einen Text als IP-Symcon Skript und bergibt Variablen
 * 
 * <p>Der Befehl startet ein Skript mit dem Inhalt <b>SkriptText</b>, bergibt dabei das Array Parameter als Argument und wartet auf das Ende der Skriptausfhrung, um das Resultat als Rckgabewert zu bergeben.. Es ist nicht ntig PHP-Tags mit anzugeben.</p><p>Das Array <b>Parameter</b> kann beliebig viele <b>Key =&gt; Value</b> Paare enthalten (siehe PHP Arrays). Jedes Paar erscheint im aufgerufenen Skript als Variable <b>Key</b> mit ihrem Inhalt <b>Value</b>.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/ablaufsteuerung/ips-runscripttextwaitex/
 * @returns string <p>Resultat des ausgefhrten Skripts</p>
 * @param string $ScriptText String welcher als Skript aufgerufen werden soll.
 * @param array $Parameters Key (string) =&gt; Value (variant) Paar auf die im neu ausgefhrten Skript zugegriffen werden kann.
 */
function IPS_RunScriptTextWaitEx(string $ScriptText, array $Parameters)
{
    
}

/**
 * startet ein anderes IP-Symcon Skript und wartet auf das Resultat
 * 
 * <p>Der Befehl veranlasst den Start des Skripts mit der ID <b>SkriptID</b>. Das Skript wird aufgerufen und wartet auf das Ende, um das Resultat als Rckgabewert zu bergeben. Auch hier gelten die bei IPS_RunScript beschriebenen Hinweise.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/ablaufsteuerung/ips-runscriptwait/
 * @returns string <p>Resultat des ausgefhrten Skripts</p>
 * @param integer $ScriptID Eindeutige ID des Skriptes
 */
function IPS_RunScriptWait(integer $ScriptID)
{
    
}

/**
 * startet ein anderes IP-Symcon Skript und bergibt Variablen
 * 
 * <p>Der Befehl veranlasst den Start des Skripts mit der ID <b>SkriptID</b>, bergibt dabei das Array Parameter als Argument und wartet auf das Ende der Skriptausfhrung, um das Resultat als Rckgabewert zu bergeben. Auch hier gelten die bei IPS_RunScript beschriebenen Hinweise.Das Array <b>Parameter</b> kann beliebig viele <b>Key =&gt; Value</b> Paare enthalten (siehe PHP Arrays). Jedes Paar erscheint im aufgerufenen Skript als Variable <b>Key</b> mit ihrem Inhalt <b>Value</b>.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/ablaufsteuerung/ips-runscriptwaitex/
 * @returns string <p>Resultat des ausgefhrten Skripts</p>
 * @param integer $ScriptID Eindeutige ID des Skriptes
 * @param array $Parameters Key (string) =&gt; Value (variant) Paar auf die im neu ausgefhrten Skript zugegriffen werden kann.
 */
function IPS_RunScriptWaitEx(integer $ScriptID, array $Parameters)
{
    
}

/**
 * prft, ob ein bestimmtes Skript existiert
 * 
 * <p>Der Befehl prft, ob das Skript mit der ID <b>SkriptID</b> existiert.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/skriptverwaltung/ips-scriptexists/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $ScriptID ID der zu prfenden Skripte
 */
function IPS_ScriptExists(integer $ScriptID)
{
    
}

/**
 * IPS_ScriptThreadExists
 * 
 * @returns boolean
 * @param integer $ThreadID
 */
function IPS_ScriptThreadExists(integer $ThreadID)
{
    
}

/**
 * erlaubt die Synchronisation mit anderen, gleichzeitig laufenden Skripts
 * 
 * <p>Dieser Befehl setzt ein <b>Semaphor</b> (ein Zeichen mit Signalwirkung), das dazu verwendet werden kann, einen Teil des Skriptes exklusiv auszufhren und diesen vor konkurrierenden Skripten zu schtzen.</p><p>In IP-Symcon knnen grundstzlich mehrere Skripte gleichzeitig laufen. Solange ein Skript keinen exklusiven Zugriff auf Variablen oder System-Ressourcen bentigt, stellt dieser Fall kein Problem dar. Falls aber ein exklusiver Zugriff unumgnglich ist, kann mit dem Befehl ein Semaphor gesetzt werden. Der Befehl prft zuerst, ob das Semaphor mit dem angegebenen Namen bereits gesetzt ist. Existiert es noch nicht, wird es durch den Befehl gesetzt und liefert <b>TRUE</b> als Rckmeldung. Alle anderen Skripte, die danach versuchen das selbe Semaphor zu setzen, versuchen fr die Dauer <b>Wartezeit</b> weiterhin das Semaphor zu setzen. Ist es dabei erfolgreich, wird <b>TRUE</b> zurckgemeldet, andernfalls, nach Ablauf der Wartezeit, <b>FALSE</b>.Wenn man gewhrleisten will, dass whrend der Laufzeit eines Skripts die von ihm verwendeten Daten nicht von anderen, gleichzeitig laufenden Skripten verflscht werden, kann man diesen Befehl verwenden, um sich exklusiven Zugriff zu sichern.</p><p>Bei der Verwendung dieses Befehls ist darauf zu achten, dass das Semaphor nach Abarbeiten des kritischen Teils wieder mit IPS_SemaphoreLeave zurckgesetzt wird.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/ablaufsteuerung/ips-semaphoreenter/
 * @returns boolean <p><b>TRUE</b>, wenn die Semaphore betreten wurde. <b>FALSE</b>, wenn die Semaphore vor Ablauf der Wartezeit nicht betreten werden konnte</p>
 * @param string $Name Name, der die Semaphore beschreibt
 * @param integer $Milliseconds Millisekunden, die gewartet wird, bis der Befehl abbricht
 */
function IPS_SemaphoreEnter(string $Name, integer $Milliseconds)
{
    
}

/**
 * erlaubt die Synchronisation mit anderen, gleichzeitig laufenden Skripts
 * 
 * <p>Dieser Befehl lscht das zuvor mit IPS_SemaphoreEnter gesetzte Semaphor wieder.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/ablaufsteuerung/ips-semaphoreleave/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param string $Name Name, der die Semaphore beschreibt.
 */
function IPS_SemaphoreLeave(string $Name)
{
    
}

/**
 * IPS_SendDataToChildren
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param string $JSONData
 */
function IPS_SendDataToChildren(integer $InstanceID, string $JSONData)
{
    
}

/**
 * IPS_SendDataToParent
 * 
 * @returns string
 * @param integer $InstanceID
 * @param string $JSONData
 */
function IPS_SendDataToParent(integer $InstanceID, string $JSONData)
{
    
}

/**
 * IPS_SendDebug
 * 
 * @returns boolean
 * @param integer $SenderID
 * @param string $Message
 * @param string $Data
 * @param integer $Format
 *   enum[0=dfText, 1=dfBinary]
 */
function IPS_SendDebug(integer $SenderID, string $Message, string $Data, integer $Format)
{
    
}

/**
 * sendet eine Mitteilung, dass ein Medienobjekt sich gendert hat
 * 
 * <p>Der Befehl sendet eine Mitteilung, dass sich das Medienobjekt mit der ID <b>MedienID</b> verndert hat. Diese Nachricht wird z.B. vom Dashboard verwendet, um ein Bild/Forumular zu aktualisieren.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/medienverwaltung/ips-sendmediaevent/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $MediaID ID des zu prfenden Medienobjekts
 */
function IPS_SendMediaEvent(integer $MediaID)
{
    
}

/**
 * setzt eine neue Konfiguration
 * 
 * <p>Dieser Befehl setzt fr die <b>InstanzID</b> die Konfiguration <b>Konfiguration</b> ein.Um diese zu speichern und wirksam werden zu lassen, muss im Anschluss IPS_ApplyChanges ausgefhrt werden.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/instanzenverwaltung/konfiguration/ips-setconfiguration/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID der Instanz
 * @param string $Configuration Die Konfiguration als String
 */
function IPS_SetConfiguration(integer $InstanceID, string $Configuration)
{
    
}

/**
 * Setzt ein Objekt fr das WebFront inaktiv
 * 
 * <p>Der Befehl setzt das Objekt mit der ID <b>ObjektID</b> inaktiv, d.h. es ist noch im WebFront sichtbar aber nicht mehr klick-/nutzbar.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/objektverwaltung/ips-setdisabled/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $ID ID des zu verndernden Objekts
 * @param boolean $Disabled TRUE wenn das Objekt inaktiv gesetzt werden soll; FALSE wenn es aktiv gesetzt werden soll.
 */
function IPS_SetDisabled(integer $ID, boolean $Disabled)
{
    
}

/**
 * aktiviert/deaktiviert ein Ereignis
 * 
 * <p>Nach dem Aktiveren/Deaktiveren kann ber IPS_GetEvent der neue Status ausgelesen werden. Bei aktiven, zyklischen Ereignissen ist es mglich, den nchsten Ausfhrungszeitpunkt zu bestimmen. Bei einem deaktivierten Ereignis ist der NextRun Wert gleich null.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/ereignisverwaltung/ips-seteventactive/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $EventID ID des zu verndernden Ereignisses
 * @param boolean $Active Gibt an, ob das Ereignis aktiviert (
 */
function IPS_SetEventActive(integer $EventID, boolean $Active)
{
    
}

/**
 * konfiguriert ein zyklisches Ereignis
 * 
 * <p>Um ein zyklisches Ereignis zu konfigurieren, mssen Sie die festlegen, in welchen Intervallen es ausgefhrt werden soll. Dazu gehrt ein <b>Datumsintervall</b>, das das Intervall in einem bestimmten Tages-, Wochen-, Monats- oder Jahresrythmus festlegt und ein Zeitintervall, das an dem jeweiligen Tag ein sekunden-, minuten- oder stundenbasierendes Intervall festlegt.</p><p>Wird das <b>Datumsintervall</b> als Woche gewhlt, so besteht die Mglichkeit die Tage der Woche zu bestimmten an denen das Ereignis gestartet werden soll. Bei Monatlichem oder Jhrlichem <b>Datumsintervall</b> kann der Tag im Monat/Jahr im Parameter <b>Datumswert</b> angegeben werden.  Bei allen anderen Typen kann der Parameter mit dem Platzhalter 0 angegeben werden.</p><p><b>Spitzfindigkeiten:</b>- (Monatlich) Bei der Variante Am X. Tag alle Y Monate bedeutet X &gt; 31, dass der letzte Tag im Monat gewhlt wird. Wenn z.B. fr X = 31 ausgewhlt wird, so werden nur Monate bercksichtigt, die 31 Tage haben.- (Monatlich) Bei der Variante Am X. Wochentag alle Y Monate bedeutet X &gt;5, dass die letzte Woche gewhlt wird. Wenn z.B. fr X = 5 ausgewhlt wird, so werden nur Monate bercksichtigt, die einen jeweiligen 5. Wochentag haben.- (Jhrlich) Bei der Variante Am X. Monat wird ein Timer nur ausgefhrt, wenn X ein gltiger Tag in diesem Monat ist, andernfalls wird der Timer nicht ausgefhrt.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/ereignisverwaltung/ips-seteventcyclic/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $EventID ID des zu verndernden Ereignisses
 * @param integer $DateType 
 *   enum[0=cdtNone, 1=cdtOnce, 2=cdtDay, 3=cdtWeek, 4=cdtMonth, 5=cdtYear]
 * @param integer $DateValue 
 * @param integer $DateDay 
 * @param integer $DateDayValue 
 * @param integer $TimeType 
 *   enum[0=cttOnce, 1=cttSecond, 2=cttMinute, 3=cttHour]
 * @param integer $TimeValue 
 */
function IPS_SetEventCyclic(integer $EventID, integer $DateType, integer $DateValue, integer $DateDay, integer $DateDayValue, integer $TimeType, integer $TimeValue)
{
    
}

/**
 * konfiguriert das Startdatum
 * 
 * <p>Wenn gewnscht, kann das Startdatum fr ein Ereignis definiert werden.</p><p>Wird fr Tag, Monat und Jahr jeweils 0 angegeben, so gibt es kein spezifisches Startdatum und es wird nicht bercksichtigt.</p><p>Das Start-Datum ist besonders relevant, wenn es ein Ereignis gibt, welches nicht Tglich ausgefhrt wird. Bei z.B. einer Ausfhrung alle 2 Wochen am Montag kann ber das Start-Datum der Referenzpunkt bestimmt werden, an dem das erste Ereignis auftritt. Dadurch kann gesteuert werden, ob das Ereignis in einer geraden oder ungeraden Kalenderwoche ausgefhrt wird.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/ereignisverwaltung/ips-seteventcyclicdatefrom/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $EventID ID des zu verndernden Ereignisses
 * @param integer $Day Start-Tag (0, 1..31)
 * @param integer $Month Start-Monat (0, 1..12)
 * @param integer $Year Start-Jahr (0, 1970..2038)
 */
function IPS_SetEventCyclicDateFrom(integer $EventID, integer $Day, integer $Month, integer $Year)
{
    
}

/**
 * konfiguriert das Enddatum
 * 
 * <p>Wenn gewnscht, kann das Enddatum fr ein Ereignis definiert werden.</p><p>Wird fr Tag, Monat und Jahr jeweils 0 angegeben, so gibt es kein spezifisches Enddatum und es wird nicht bercksichtigt.</p><p>Das Ereignis wird inklusive des Enddatums ausgefhrt</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/ereignisverwaltung/ips-seteventcyclicdateto/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $EventID ID des zu verndernden Ereignisses
 * @param integer $Day End-Tag (0, 1..31)
 * @param integer $Month End-Monat (0, 1..12)
 * @param integer $Year End-Jahr (0, 1970..2038)
 */
function IPS_SetEventCyclicDateTo(integer $EventID, integer $Day, integer $Month, integer $Year)
{
    
}

/**
 * konfiguriert die Startzeit
 * 
 * <p>Wenn gewnscht, kann die Startzeit fr ein Ereignis definiert werden. Die Startzeit definiert den ersten Zeitpunkt der Ausfhrung.</p><p>Die Start-Zeit ist besonders relevant, wenn ein Ereignis leicht versetzt gestartet werden soll, um z.B. nicht alle Ereignisse gleichzeitig zur vollen Minute zu starten. Wenn als Startzeit 00:00:05 angegeben wird, so wird das Skript bei einer mintlichen Ausfhrung immer genau 5 Sekunden nach der vollen Minute ausgefhrt.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/ereignisverwaltung/ips-seteventcyclictimefrom/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $EventID ID des zu verndernden Ereignisses
 * @param integer $Hour Start-Stunde (0..23)
 * @param integer $Minute Start-Minute (0..59)
 * @param integer $Second Start-Sekunde (0..59)
 */
function IPS_SetEventCyclicTimeFrom(integer $EventID, integer $Hour, integer $Minute, integer $Second)
{
    
}

/**
 * konfiguriert die Endzeit
 * 
 * <p>Wenn gewnscht, kann die Endzeit fr ein Ereignis definiert werden. Die Endzeit definiert den letzten Zeitpunkt der Ausfhrung.</p><p>Wird fr Stunde, Minute und Sekunde jeweils 0 angegeben, so gibt es keine Endzeit die letzte Ausfhrung ist um sptestens 23:59:59.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/ereignisverwaltung/ips-seteventcyclictimeto/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $EventID ID des zu verndernden Ereignisses
 * @param integer $Hour End-Stunde (0..23)
 * @param integer $Minute End-Minute (0..59)
 * @param integer $Second End-Sekunde (0..59)
 */
function IPS_SetEventCyclicTimeTo(integer $EventID, integer $Hour, integer $Minute, integer $Second)
{
    
}

/**
 * limitiert die Anzahl der Ereignissaufrufe
 * 
 * <p>Die Limitierung auf <b>Anzahl</b> bewirkt, dass das Ereignis nur <b>Anzahl</b> Male ausgefhrt wird. Danach ist die Anzahl gleich null und das Ereignis ist deaktiviert. Die Einstellung Anzahl = 0 hebt die Limitierung auf.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/ereignisverwaltung/ips-seteventlimit/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $EventID ID des zu verndernden Ereignisses
 * @param integer $Count Die Anzahl der Ausfhrung, bevor das Ereignis deaktiviert wird. 0 = Keine Limitierung
 */
function IPS_SetEventLimit(integer $EventID, integer $Count)
{
    
}

/**
 * modifiziert die Aktionsstabelle eines Wocheplans
 * 
 * <p>Der Befehl setzt den <b>Namen</b>, die <b>Farbe</b> und den <b>Skriptinhalt</b> fr die <b>AktionsID</b> eines Wochenplan Ereignisses mit der ID <b>EreignisID</b>. Der <b>SkriptInhalt</b> wird nur ausgewertet, wenn das Ereignis nicht unterhalb eines Skriptes ist. Andernfalls wird das Skript ausgefhrt, und die Systemvariable $_IPS['ACTION'] definiert. Bitte nutzen Sie die Systemvariablen, welche ihnen fr den Skriptinhalt auch zur Verfgung stehen.</p><p>Wenn der <b>Name</b> leer ist, wird die Aktion mit der angegebenen <b>AktionsID</b> gelscht. Dies ist jedoch nur Mglich, wenn kein Schaltpunkt mehr auf diese AktionsID verweist.</p><p>Der Wert -2147483648 ist keine gltige AktionsID.</p><p>Es knnen maximal acht (8) Aktionen erstellt werden.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/ereignisverwaltung/ips-seteventscheduleaction/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $EventID ID des zu verndernden Ereignisses
 * @param integer $ActionID Eindeutige ID fr diese Aktion. Die Sortierung wird anhand der ID vorgenommen.
 * @param string $Name Name zur angegebenen Aktion
 * @param integer $Color Farbwert im HTML Farbcode (z.b. 0x0000FF fr Blau)
 * @param string $ScriptText PHP Skript ohne PHP Tags (&lt;?  ?&gt;)
 */
function IPS_SetEventScheduleAction(integer $EventID, integer $ActionID, string $Name, integer $Color, string $ScriptText)
{
    
}

/**
 * modifiziert die Gruppierung der Tage eines Wocheplans
 * 
 * <p>Der Befehl setzt die Bitmaske <b>Tage</b>  fr die <b>GruppenID</b> eines Wochenplan Ereignisses mit der ID <b>EreignisID</b>. Es knnen in einer Gruppe beliebige Tage kombiniert werden. Dabei ist zu beachten, dass ein bestimmter Tag nur zu einer Gruppe zugehrig sein kann. In einer Gruppe knnen auch alle Tage (Wert = 127) oder nur ein einzelner Tag definiert sein. (z.B. 1 fr Montag) Wenn fr ein Ereignis nicht alle Tage in Gruppen aufgeteilt wurden, so knnen fr diese Tage keine Schaltpunkte definiert werden und der letzte ausgefhrte Schaltpunkt bleibt bestehen.</p><p>Wenn der Wert von <b>Tage</b> Null (0) ist, wird die Gruppe mit der angegebenen <b>GruppenID</b> gelscht. Dabei werden auch alle der Gruppe zugehrigen Schaltpunkte entfernt.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/ereignisverwaltung/ips-seteventschedulegroup/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $EventID ID des zu verndernden Ereignisses
 * @param integer $GroupID Eindeutige ID fr diese Gruppe. Die Sortierung wird anhand der ID vorgenommen.
 * @param integer $Days Addition der Tageswerte, die zur Gruppe gehren. Die Tageswerte knnen der Tabelle bei
 */
function IPS_SetEventScheduleGroup(integer $EventID, integer $GroupID, integer $Days)
{
    
}

/**
 * modifiziert einen Schaltpunkt der Gruppe eines Wocheplans
 * 
 * <p>Der Befehl setzt den Schaltpunkt mit der Kombination aus <b>Stunde</b>, <b>Minute</b> und <b>Sekunde</b> fr die <b>SchaltpunktID</b> der Gruppe mit <b>GruppenID</b> eines Wochenplan Ereignisses mit der ID <b>EreignisID</b>.</p><p>Wenn <b>Stunde</b>, <b>Minute</b> oder <b>Sekunde</b> auerhalb des gltigen Bereichs ist (z.B. -1), wird der Schaltpunkt mit der angegebenen <b>SchaltpunktID</b> gelscht.</p><p>Es darf maximal ein Startpunkt die selbe Kombination aus <b>Stunde</b>, <b>Minute</b> und <b>Sekunde</b> besitzen</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/ereignisverwaltung/ips-seteventschedulegrouppoint/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $EventID ID des zu verndernden Ereignisses
 * @param integer $GroupID Eindeutige ID fr diese Gruppe. Die Sortierung wird anhand der ID vorgenommen.
 * @param integer $PointID Eindeutige ID fr diesen Schaltpunkt. IDs mssen nur fr diese Gruppe eindeutig sein.
 * @param integer $StartHour Start-Stunde (0..23)
 * @param integer $StartMinute Start-Minute (0..59)
 * @param integer $StartSecond Start-Sekunde (0..59)
 * @param integer $ActionID ID der Aktion, welche zum Zeitpunkt ausgefhrt werden soll. Die ID muss gltig sein.
 */
function IPS_SetEventScheduleGroupPoint(integer $EventID, integer $GroupID, integer $PointID, integer $StartHour, integer $StartMinute, integer $StartSecond, integer $ActionID)
{
    
}

/**
 * setzt den auszufhrenden Skriptinhalt
 * 
 * <p>Jedes Ereignis, welches nicht einem Skript, sondern z.B. einer Instanz/Variable untergeordnet ist, kann auf dem bergeordneten Objekt (als der Instanz/Variable) eine Operation ausfhren, die in PHP programmiert werden kann. ber diesen Befehl kann diese Operation als PHP Code definiert werden, die bei Auftreten des Ereignisses ausgefhrt wird. Der PHP wird direkt ohne die PHP Tags (&lt;?  ?&gt;) angegeben.Die Auflistung der Systemvariablen zeigt, welche speziellen Variablen verfgbar sind.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/ereignisverwaltung/ips-seteventscript/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $EventID ID des zu verndernden Ereignisses
 * @param string $EventScript PHP Skript ohne PHP Tags (&lt;?  ?&gt;)
 */
function IPS_SetEventScript(integer $EventID, string $EventScript)
{
    
}

/**
 * konfiguriert ein ausgelstes Ereignis
 * 
 * <p>Um ein auslsendes Ereignis zu konfigurieren, mssen sie festlegen, auf welchen <b>Auslsertyp</b> das Ereignis reagieren soll und welche <b>Variable</b> das Ereignis beobachten soll.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/ereignisverwaltung/ips-seteventtrigger/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $EventID ID des zu verndernden Ereignisses
 * @param integer $TriggerType 
 *   enum[0=evtOnUpdate, 1=evtOnChange, 2=evtOnLimitExceed, 3=evtOnLimitDrop, 4=evtOnValue]
 * @param integer $TriggerVariableID VariablenID, auf dessen nderung/Aktualisierung reagiert werden soll
 */
function IPS_SetEventTrigger(integer $EventID, integer $TriggerType, integer $TriggerVariableID)
{
    
}

/**
 * konfiguriert, ob Ereignis bei gleichem Wert erneut ausgelst wird
 * 
 * <p>Gibt an, ob das Ereignis erneut ausgefhrt werden soll, wenn eine Grenzberschreitung/-unterschreitung zum zweiten Mal ausgelst wird. Andernfalls wird das Ereignis erst wieder ausgefhrt, wenn der Variablenwert innerhalb des Grenzwertbereichs gewesen ist und erneut berschritten wird.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/ereignisverwaltung/ips-seteventtriggersubsequentexecution/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $EventID ID des zu verndernden Ereignisses
 * @param boolean $AllowSubsequentExecutions 
 */
function IPS_SetEventTriggerSubsequentExecution(integer $EventID, boolean $AllowSubsequentExecutions)
{
    
}

/**
 * konfiguriert den Wert bei dem Ausgelst werden sol
 * 
 * <p>Gibt einen Wert an, der beim Vergleich genutzt werden soll.<br>Der Auslsertyp des Ereignisses kann wie folgt eingestellt sein:</p><ul><li>Bei Grenzberschreitung</li><li>Bei Grenzunterschreitung        </li><li>Bei bestimmem Wert</li></ul><p>Der Grenzwert muss als korrekter Typ angegeben werden.<br>Andernfalls kann der Vergleich fehlschlagen oder unerwartet ausgelst werden.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/ereignisverwaltung/ips-seteventtriggervalue/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $EventID ID des zu verndernden Ereignisses
 * @param mixed $TriggerValue Abhnger Wert/Typ je nach VariablenID vom Auslser
 */
function IPS_SetEventTriggerValue(integer $EventID, mixed $TriggerValue)
{
    
}

/**
 * setzt die Sichtbarkeit eines beliebigen Objekts
 * 
 * <p>Der Befehl setzt die Sichtbarkeit des Objekts mit der ID <b>ObjektID</b>. Unsichtbare Objekte werden samt Unterobjekten von der Visualisierung ausgeschlossen und in der Konfiguration als grau hinterlegt dargestellt.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/objektverwaltung/ips-sethidden/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $ID ID des zu verndernden Objekts
 * @param boolean $Hidden TRUE, wenn unsichtbar
 */
function IPS_SetHidden(integer $ID, boolean $Hidden)
{
    
}

/**
 * ordnet einem beliebigen Objekt ein Icon zu
 * 
 * <p>Der Befehl ordnet dem Objekt mit der ID <b>ObjektID</b> ein Icon zu.</p><p>Eine Liste der verfgbaren Icons knnen Sie unter Icons finden.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/objektverwaltung/ips-seticon/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $ID ID des zu verndernden Objekts
 * @param string $Icon Dateiname des Icons ohne Pfad/Erweiterung
 */
function IPS_SetIcon(integer $ID, string $Icon)
{
    
}

/**
 * ordnet einem beliebigen Objekt einen Identifikator zu
 * 
 * <p>Der Befehl ordnet dem Objekt mit der ID <b>ObjektID</b> den Identifikator <b>Ident</b> zu. Der Identifikator ist ein fr den Endbenutzer nicht sichtbarer String. Erlaubte Zeichen sind "a..z","A..Z","0..1","_". Dieser kann genutzt werden, um Objekte innerhalb einer Ebene auffindbar zu machen, ohne die eindeutige und systemabhngige ID zu nutzen. ber den Identifikator werden z.B. alle Statusvariablen der Instanzen realisiert. Der Befehl kann auf alle Objekte angewandt werden, die eine ID zur Identifikation besitzen.</p><p>Es kann nur ein Objekt mit demselben Identifikator innerhalb einer Ebene existieren. Somit ist eine Abfrage ber IPS_GetObjectIDByIdent eindeutig.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/objektverwaltung/ips-setident/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $ID ID des zu verndernden Objekts
 * @param string $Ident Neuer Identifikator fr das Objekt
 */
function IPS_SetIdent(integer $ID, string $Ident)
{
    
}

/**
 * ordnet einem beliebigen Objekt erweiterte Informationen zu
 * 
 * <p>Der Befehl ordnet dem Objekt mit der ID <b>ObjektID</b> erweitere Informationen zu. Diese knnen benutzt werden, um z.B. spezifische Konfigurationen oder spezielle Informationen pro Objekt zu hinterlegen, die zu einem spteren Zeitpunkt wiederverwendet werden knnen.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/objektverwaltung/ips-setinfo/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $ID ID des zu verndernden Objekts
 * @param string $Info Neuer Info-Text fr das Objekt
 */
function IPS_SetInfo(integer $ID, string $Info)
{
    
}

/**
 * IPS_SetInstanceStatus
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param integer $Status
 */
function IPS_SetInstanceStatus(integer $InstanceID, integer $Status)
{
    
}

/**
 * IPS_SetLicense
 * 
 * @returns boolean
 * @param string $Licensee
 * @param string $LicenseContent
 */
function IPS_SetLicense(string $Licensee, string $LicenseContent)
{
    
}

/**
 * setzt die Verknpfung fr den Link
 * 
 * <p>Der Befehl verknpft ein bestimmtest Objekt <b>VerknpftesObjekt</b> mit dem Link <b>LinkID</b> zusammen, so dass der Link auf dieses Objekt zeigt.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/linkverwaltung/ips-setlinktargetid/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $LinkID ID des zu verndernden Links
 * @param integer $ChildID ID des zu verknpfenden Objekts
 */
function IPS_SetLinkTargetID(integer $LinkID, integer $ChildID)
{
    
}

/**
 * aktiviert, dass ein Medienobjekt nur im Arbeitsspeicher bearbeitet wird
 * 
 * <p>Der Befehl aktiviert das Cachen fr ein Medienobjekt mit der ID <b>MedienID</b>. Das Medienobjekt wird im Arbeitsspeicher verndert wenn die Funktionen IPS_SetMediaContent und IPS_GetMediaContent genutzt werden. Beim Herunterfahren von IP-Symcon wird das Medienobjekt automatisch auf den physikalischen Speicher geschrieben und somit persistent.</p><p>Diese Funktion dient zur Schonung der SSD's und Flashspeicher.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/medienverwaltung/ips-setmediacached/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $MediaID ID des zu verndernden Medienobjekts
 * @param boolean $Cached 
 */
function IPS_SetMediaCached(integer $MediaID, boolean $Cached)
{
    
}

/**
 * setzt den Inhalt eines Medienobjekts
 * 
 * <p>Diese Funktion setzt den Inhalt fr das Medienobjekt mit der ID <b>MedienID</b>. Dabei wird der Dateiname, der vorher per IPS_SetMediaFile definiert wurde, genutzt.</p><p>Es wird eine Fehlermeldung zurckgegeben, sofern kein gltiger Dateiname vorhanden ist, oder der Inhalt nicht korrekt Base64 kodiert wurde.</p><p>Diese Funktion ist mit Vorsicht zu verwenden, da der Inhalt ohne Warnung berschrieben wird.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/medienverwaltung/ips-setmediacontent/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $MediaID ID des Medienobjekts, dem der Inhalt zugeordnet werden soll
 * @param string $Content Base64 kodierter Inhalt
 */
function IPS_SetMediaContent(integer $MediaID, string $Content)
{
    
}

/**
 * bindet eine Mediendatei an ein Medienobjekt
 * 
 * <p>Der Befehl bindet den Dateinamen <b>DateiName</b> an das Medienobjekt mit der ID <b>MedienID</b>. Der Parameter <b>DateiMussExistieren</b> gibt an, ob intern geprft werden soll, ob die Datei vorhanden ist. Die zuzuordnende Mediendatei muss zum Medientyp des Medienobjekts passen.</p><p>Der DateiName muss eindeutig sein. Wenn der DateiName bereits einem anderen Medienobjekt zugehrig ist, wird ein Fehler zurckgegeben.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/medienverwaltung/ips-setmediafile/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $MediaID ID des zu verndernden Medienobjekts
 * @param string $FilePath 
 * @param boolean $FileMustExists 
 */
function IPS_SetMediaFile(integer $MediaID, string $FilePath, boolean $FileMustExists)
{
    
}

/**
 * ordnet einem beliebigen Objekt einen Namen zu
 * 
 * <p>Der Befehl ordnet dem Objekt mit der ID <b>ObjektID</b> den Namen <b>Name</b> zu. Der Name ersetzt im Strukturbaum den bisherigen Namen (Standard: unbekanntes Objekt: #12345) und kann so zur besseren Lesbarkeit beitragen. Der Befehl kann auf alle Objekte angewandt werden, die eine ID zur Identifikation besitzen.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/objektverwaltung/ips-setname/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $ID ID des zu verndernden Objekts
 * @param string $Name Neuer Name fr das Objekt
 */
function IPS_SetName(integer $ID, string $Name)
{
    
}

/**
 * IPS_SetOption
 * 
 * @returns boolean
 * @param string $Option
 * @param integer $Value
 */
function IPS_SetOption(string $Option, integer $Value)
{
    
}

/**
 * verschiebt ein Objekt im logischen Strukturbaum
 * 
 * <p>Der Befehl verschiebt das Objekt mit der ID <b>ObjektID</b> im IP-Symcon Strukturbaum unter das Objekt mit der ID <b>bergeordneteID</b>. Das Objekt ist danach dem bergeordneten-Objekt optisch untergeordnet. Die neue Zuordnung wird im logischen Strukturbaum (Logical Treeview) sichtbar. Auf diese Weise kann die logische Ansicht so angepasst werden, dass sie bestmglich die Zusammengehrigkeit und/oder Abhngigkeit verschiedener Komponenten widerspiegelt.</p><p>Durch die Zuweisung an ein neues bergeordnetes-Objekt ndert sich nichts an bestehenden physikalischen Verbindungen. Sie dient lediglich einer besseren Darstellungsweise.</p><p>Falls das Objekt einen Ident besitzt, darf kein gleicher Ident an der neuen Zielposition existieren.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/objektverwaltung/ips-setparent/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $ID ID des zu verndernden Objekts
 * @param integer $ParentID ID des neuen bergeordneten Objekts im logischen Objektbaum
 */
function IPS_SetParent(integer $ID, integer $ParentID)
{
    
}

/**
 * ordnet einem beliebigen Objekt eine Position zu
 * 
 * <p>Der Befehl ordnet dem Objekt mit der ID <b>ObjektID</b> eine <b>Position</b> zu. Die Position wird in der Visualisierung verwendet, um die Objekte in der gewnschten Reihenfolge anzuzeigen. Defaultwert ist Null. Der Positionswert muss nicht eindeutig sein. Sollten zwei Positionen denselben Wert haben, wird der Name als zweites Sortierkriterium verwendet.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/objektverwaltung/ips-setposition/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $ID ID des zu verndernden Objekts
 * @param integer $Position Positionswert des Objekts
 */
function IPS_SetPosition(integer $ID, integer $Position)
{
    
}

/**
 * setzt einen neuen Wert fr eine Eigenschaft
 * 
 * <p>Dieser Befehl setzt fr die <b>InstanzID</b> den Soll-Wert der <b>Eigenschaft</b> ein.Sie knnen einen neuen Soll-Wert mit IPS_SetProperty bergeben und mit IPS_ApplyChanges bernehmen lassen.</p><p><b>AESGI</b></p><li>InverterAdresse  integer  1</li><p><b>ALL2x</b></p><li>DeviceNum  integer  0</li><li>DeviceType  integer  0</li><li>Interval  integer  0</li><li>IPAddress  string  </li><p><b>ALL3690</b></p><li>Interval  integer  0</li><li>IPAddress  string  </li><p><b>ALL3691</b></p><li>Interval  integer  0</li><li>IPAddress  string  </li><p><b>ALL4000</b></p><li>Devices  string  [0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0]</li><li>Interval  integer  0</li><li>IPAddress  string  </li><p><b>ALLUniversal</b></p><li>Interval  integer  0</li><li>IPAddress  string  </li><p><b>Archive Control</b></p><li>Aggregation  string  {}</li><li>Statistics  string  {}</li><p><b>Calendar Control</b></p><li>Items  string  []</li><p><b>Client Socket</b></p><li>Host  string  </li><li>Open  boolean  </li><li>Port  integer  0</li><p><b>Connect Control</b></p><li>Active  boolean  </li><p><b>Cutter</b></p><li>DeleteCutChars  boolean  </li><li>InputLength  integer  0</li><li>LeftCutChar  string  </li><li>ParseType  integer  0</li><li>RightCutChar  string  </li><li>SyncChar  string  </li><li>Timeout  integer  0</li><p><b>DMX Gateway</b></p><li>GatewayMode  integer  0</li><li>Universe  integer  0</li><p><b>DMX Output</b></p><li>ChannelBase  integer  1</li><li>ChannelCount  integer  1</li><p><b>DMX RGB</b></p><li>ChannelB  integer  3</li><li>ChannelG  integer  2</li><li>ChannelR  integer  1</li><p><b>dS Apartment</b></p><li>GroupID  integer  0</li><p><b>dS Configurator</b></p><li>    </li><p><b>dS Light</b></p><li>dSID  string  </li><p><b>dS Shutter</b></p><li>dSID  string  </li><p><b>dS Splitter</b></p><li>IPAddress  string  dss.local</li><li>Token  string  </li><p><b>dS Zone</b></p><li>GroupID  integer  0</li><li>ZoneID  integer  0</li><p><b>Dummy Module</b></p><li>    </li><p><b>EIB Gateway</b></p><li>GatewayMode  integer  1</li><p><b>EIB Group</b></p><li>GroupAddress1  integer  0</li><li>GroupAddress2  integer  0</li><li>GroupAddress3  integer  0</li><li>GroupCapabilityRead  boolean  </li><li>GroupCapabilityReceive  boolean  1</li><li>GroupCapabilityTransmit  boolean  </li><li>GroupCapabilityWrite  boolean  1</li><li>GroupFunction  string  Switch</li><li>GroupInterpretation  string  Standard</li><li>GroupMapping  string  []</li><p><b>EIB RGB</b></p><li>GroupAddress1  integer  0</li><li>GroupAddress2  integer  0</li><li>GroupAddress3  integer  0</li><p><b>EIB RGBW</b></p><li>GroupAddress1  integer  0</li><li>GroupAddress2  integer  0</li><li>GroupAddress3  integer  0</li><p><b>EIB Shutter</b></p><li>GroupMoveAddress1  integer  0</li><li>GroupMoveAddress2  integer  0</li><li>GroupMoveAddress3  integer  0</li><li>GroupMoveMapping  string  []</li><li>GroupPositionReadAddress1  integer  -1</li><li>GroupPositionReadAddress2  integer  -1</li><li>GroupPositionReadAddress3  integer  -1</li><li>GroupPositionWriteAddress1  integer  -1</li><li>GroupPositionWriteAddress2  integer  -1</li><li>GroupPositionWriteAddress3  integer  -1</li><li>GroupStepAddress1  integer  0</li><li>GroupStepAddress2  integer  0</li><li>GroupStepAddress3  integer  0</li><li>GroupStepMapping  string  []</li><li>GroupStopAddress1  integer  0</li><li>GroupStopAddress2  integer  0</li><li>GroupStopAddress3  integer  0</li><li>GroupStopMapping  string  []</li><p><b>EnOcean alphaEOS SENSE TF-H</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A50201RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A50202RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A50203RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A50204RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A50205RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A50206RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A50207RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A50208RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A50209RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A5020ARX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A5020BRX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A50210RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A50211RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A50212RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A50213RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A50214RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A50215RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A50216RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A50217RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A50218RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A50219RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A5021ARX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A5021BRX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A50220RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A50230RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A50401RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A50601RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A50602RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A50603RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A50701RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A50702RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A50703RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A50801RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A50802RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A50803RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A50901RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A50902RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A50904RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A50905RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A50906RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A50907RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A50908RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A51001RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A51002RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A51003RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A51004RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A51005RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A51006RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A51007RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A51008RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A51009RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A5100ARX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A5100BRX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A5100CRX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A5100DRX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A51010RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A51011RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A51012RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A51013RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A51014RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A51015RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A51016RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A51017RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A51018RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A51019RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A5101ARX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A5101BRX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A5101CRX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A5101DRX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A5101FRX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A51020RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A51021RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A51101RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A51102RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A51103RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A51104RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A51200RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A51201RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A51202RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A51203RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A51301RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A51302RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A51303RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A51304RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A51305RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A51401RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A51402RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A51403RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A51404RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A51405RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A51406RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A52012RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A52012TX</b></p><li>DeviceID  integer  0</li><p><b>EnOcean EEP A53001RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A53002RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A53003RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A53004RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A53701RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A53808RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP A53809RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP D50001RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP F60201RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP F60202RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP F60203RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP F60204RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP F60301RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP F60302RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP F60401RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP F60402RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EEP F60501RX</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EltakoDimmer</b></p><li>ButtonMode  integer  0</li><li>DeviceID  integer  0</li><li>DualStatus  boolean  </li><li>EmulateStatus  boolean  1</li><li>ReturnID  string  00000000</li><p><b>EnOcean EltakoFABH65S</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EltakoFAFT60</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EltakoFAH60</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EltakoFHK14</b></p><li>DeviceID  integer  0</li><p><b>EnOcean EltakoFSS12</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EltakoFWS61</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean EltakoShutter</b></p><li>ButtonMode  integer  0</li><li>DeviceID  integer  0</li><li>EmulateStatus  boolean  1</li><li>ReturnID  string  00000000</li><p><b>EnOcean EltakoSwitch</b></p><li>ButtonMode  integer  0</li><li>DeviceID  integer  0</li><li>DualStatus  boolean  </li><li>EmulateStatus  boolean  1</li><li>ReturnID  string  00000000</li><p><b>EnOcean Gateway</b></p><li>GatewayMode  integer  2</li><p><b>EnOcean Hoppe</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean Opus</b></p><li>ButtonMode  integer  0</li><li>DeviceID  integer  0</li><p><b>EnOcean PTM200</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean PTM200RX</b></p><li>ButtonMode  integer  0</li><li>DeviceID  string  00000000</li><p><b>EnOcean RCM100</b></p><li>ButtonMode  integer  0</li><li>DeviceID  integer  0</li><p><b>EnOcean SmartDrive MX</b></p><li>DeviceID  integer  0</li><li>ReturnID  string  00000000</li><li>WUC  integer  0</li><p><b>EnOcean STM100</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean STM250</b></p><li>DeviceID  string  00000000</li><p><b>EnOcean Thermokon SR0x</b></p><li>DeviceID  string  00000000</li><li>TempOffset  double  0</li><li>TempRange  double  40</li><p><b>EnOcean Thermokon Thanos</b></p><li>BaseSetPoint1  integer  22</li><li>DeviceID  integer  0</li><li>LowerSetPoint1  integer  17</li><li>ReturnID  string  00000000</li><li>StepSetPoint1  double  0.5</li><li>UpperSetPoint1  integer  30</li><p><b>EnOcean Valve Actuator</b></p><li>DeviceID  integer  0</li><li>ReturnID  string  00000000</li><li>SPMode  integer  0</li><p><b>Event Control</b></p><li>ShutdownScript  integer  0</li><li>StartupScript  integer  0</li><li>StatusEvents  string  []</li><li>WatchdogScript  integer  0</li><p><b>FHT</b></p><li>Address  string  0000</li><li>EmulateStatus  boolean  </li><p><b>FHZ</b></p><li>    </li><p><b>FS10</b></p><li>DeviceID  integer  0</li><li>DeviceType  integer  0</li><p><b>FS10 Gateway</b></p><li>    </li><p><b>FS20</b></p><li>Address  string  11</li><li>EnableReceive  boolean  1</li><li>EnableTimer  boolean  1</li><li>HomeCode  string  11111111</li><li>Mapping  string  []</li><li>SubAddress  string  11</li><p><b>FS20EX</b></p><li>DeviceList  string  []</li><li>HomeCode  string  11111111</li><p><b>Heating Control</b></p><li>HandlerScript  integer  0</li><li>Hysteresis  double  0</li><li>OverrideVariables  string  []</li><li>ResendInterval  integer  15</li><li>SetBack  double  0</li><li>SetBackVariables  string  []</li><li>SourceVariable  integer  0</li><li>TransmitDevices  string  []</li><p><b>HID</b></p><li>DeviceProductID  integer  0</li><li>DeviceSerial  string  </li><li>DeviceVendorID  integer  0</li><li>Open  boolean  </li><p><b>HMS</b></p><li>DeviceID  integer  0</li><li>DeviceType  integer  0</li><p><b>HomeMatic Configurator</b></p><li>    </li><p><b>HomeMatic Device</b></p><li>Address  string  </li><li>EmulateStatus  boolean  1</li><li>Protocol  integer  0</li><p><b>HomeMatic Socket</b></p><li>Host  string  </li><li>IPAddress  string  172.17.31.80</li><li>Mode  integer  0</li><li>Open  boolean  </li><li>Port  integer  5544</li><li>RFPort  integer  2001</li><li>WRPort  integer  2000</li><p><b>Image Grabber</b></p><li>AuthPass  string  </li><li>AuthUser  string  </li><li>ImageAddress  string  http://localhost/cam.jpg</li><li>ImageType  integer  0</li><li>Interval  integer  300</li><li>MediaID  integer  0</li><li>UseBasicAuth  boolean  </li><p><b>IMAP</b></p><li>CacheInterval  integer  300</li><li>CacheSize  integer  10</li><li>Host  string  imap.gmail.com</li><li>Password  string  </li><li>Port  integer  993</li><li>UseAuthentication  boolean  1</li><li>Username  string  mail@gmail.com</li><li>UseSSL  boolean  1</li><p><b>IPS-868 Accelerometer</b></p><li>DeviceID  integer  0</li><p><b>IPS-868 AirQuality</b></p><li>DeviceID  integer  176</li><li>Interval  integer  0</li><li>LimitRed  integer  1500</li><li>LimitYellow  integer  1000</li><p><b>IPS-868 Counter</b></p><li>CounterID  integer  1</li><li>DeviceID  integer  128</li><li>Impulses  integer  1000</li><li>Interval  integer  0</li><li>Mode  integer  1</li><p><b>IPS-868 Display</b></p><li>DeviceID  integer  0</li><p><b>IPS-868 Display Input</b></p><li>DeviceID  integer  0</li><p><b>IPS-868 Display Output</b></p><li>DeviceID  integer  0</li><li>OutputID  integer  0</li><p><b>IPS-868 Gateway</b></p><li>GatewayMode  integer  0</li><p><b>IPS-868 Input</b></p><li>DeviceID  integer  0</li><li>InputID  integer  1</li><p><b>IPS-868 Level</b></p><li>DeviceID  integer  166</li><li>Interval  integer  0</li><p><b>IPS-868 Servo</b></p><li>DeviceID  integer  144</li><p><b>IPS-868 Servo Input</b></p><li>DeviceID  integer  1</li><p><b>IPS-868 Stripe</b></p><li>DeviceID  integer  144</li><li>Mode  integer  0</li><p><b>IPS-868 Stripe Input</b></p><li>DeviceID  integer  1</li><p><b>IPS-868 Thermo</b></p><li>DeviceID  integer  166</li><li>Interval  integer  0</li><li>Mode  integer  1</li><p><b>IPS-868 Tracker</b></p><li>DeviceID  integer  0</li><li>TrackerID  integer  1</li><p><b>IPS-868 WatchDogTimer</b></p><li>DeviceID  integer  165</li><p><b>IRTrans Device</b></p><li>DeviceID  integer  0</li><p><b>IRTrans Gateway</b></p><li>    </li><p><b>KNX/EIB Configurator</b></p><li>    </li><p><b>KS300</b></p><li>    </li><p><b>LCN Configurator</b></p><li>    </li><p><b>LCN Data</b></p><li>DataType  integer  0</li><p><b>LCN Gateway</b></p><li>Password  string  </li><li>Username  string  </li><p><b>LCN Module</b></p><li>Segment  integer  0</li><li>Target  integer  0</li><p><b>LCN Shutter</b></p><li>DirectionChannel  integer  0</li><li>MoveChannel  integer  0</li><li>Unit  integer  0</li><p><b>LCN Unit</b></p><li>Channel  integer  0</li><li>Unit  integer  0</li><p><b>LCN Value</b></p><li>A10ValueType  integer  0</li><li>A11ValueType  integer  0</li><li>A12ValueType  integer  0</li><li>A1ValueType  integer  0</li><li>A2ValueType  integer  0</li><li>A3ValueType  integer  0</li><li>A4ValueType  integer  0</li><li>A5ValueType  integer  0</li><li>A6ValueType  integer  0</li><li>A7ValueType  integer  0</li><li>A8ValueType  integer  0</li><li>A9ValueType  integer  0</li><li>EmulateStatus  boolean  </li><li>Interval  integer  0</li><li>R1ValueType  integer  0</li><li>R2ValueType  integer  0</li><li>TValueType  integer  0</li><li>ValueTypes  string  []</li><p><b>LevelJet</b></p><li>    </li><p><b>Location Control</b></p><li>IsDayEnd  integer  1</li><li>IsDayStart  integer  2</li><li>Latitude  double  53.87</li><li>Longitude  double  10.66</li><p><b>M-Bus Device</b></p><li>Address  integer  1</li><li>Interval  integer  5</li><p><b>M-Bus Gateway</b></p><li>GatewayMode  integer  1</li><p><b>Media Player</b></p><li>DeviceDriver  string  </li><li>DeviceName  string  </li><li>DeviceNum  integer  0</li><li>UpdateInterval  integer  0</li><p><b>ModBus Address</b></p><li>DataType  integer  0</li><li>EmulateStatus  boolean  1</li><li>Factor  double  0</li><li>Poller  integer  5000</li><li>ReadAddress  integer  0</li><li>ReadOnly  boolean  </li><li>WriteAddress  integer  0</li><p><b>ModBus Gateway</b></p><li>DeviceID  integer  1</li><li>GatewayMode  integer  0</li><li>SwapWords  boolean  1</li><p><b>Module Control</b></p><li>    </li><p><b>Notification Control</b></p><li>    </li><p><b>OneWire Configurator</b></p><li>    </li><p><b>OneWire F05</b></p><li>DeviceID  string  </li><li>Interval  integer  60</li><li>Invert  boolean  </li><li>PortSettings  integer  0</li><p><b>OneWire F10</b></p><li>DeviceID  string  </li><li>Interval  integer  60</li><p><b>OneWire F12</b></p><li>DeviceID  string  </li><li>Interval  integer  60</li><li>Invert0  boolean  </li><li>Invert1  boolean  </li><li>PortSettings0  integer  0</li><li>PortSettings1  integer  0</li><p><b>OneWire F1D</b></p><li>DeviceID  string  </li><li>Interval  integer  60</li><p><b>OneWire F20</b></p><li>DeviceID  string  </li><li>Interval  integer  60</li><li>PortType0  integer  0</li><li>PortType1  integer  0</li><li>PortType2  integer  0</li><li>PortType3  integer  0</li><li>Resolution0  integer  12</li><li>Resolution1  integer  12</li><li>Resolution2  integer  12</li><li>Resolution3  integer  12</li><li>Voltage0  integer  0</li><li>Voltage1  integer  0</li><li>Voltage2  integer  0</li><li>Voltage3  integer  0</li><p><b>OneWire F26</b></p><li>DeviceID  string  </li><li>Interval  integer  60</li><p><b>OneWire F28</b></p><li>DeviceID  string  </li><li>Interval  integer  60</li><li>Precision  integer  0</li><p><b>OneWire F29</b></p><li>DeviceID  string  </li><li>Interval  integer  60</li><li>Invert0  boolean  </li><li>Invert1  boolean  </li><li>Invert2  boolean  </li><li>Invert3  boolean  </li><li>Invert4  boolean  </li><li>Invert5  boolean  </li><li>Invert6  boolean  </li><li>Invert7  boolean  </li><li>PortSettings0  integer  0</li><li>PortSettings1  integer  0</li><li>PortSettings2  integer  0</li><li>PortSettings3  integer  0</li><li>PortSettings4  integer  0</li><li>PortSettings5  integer  0</li><li>PortSettings6  integer  0</li><li>PortSettings7  integer  0</li><p><b>OneWire F2C</b></p><li>DeviceID  string  </li><li>Interval  integer  60</li><li>UseCPC  boolean  </li><p><b>OneWire F3A</b></p><li>DeviceID  string  </li><li>Interval  integer  60</li><li>Invert0  boolean  </li><li>Invert1  boolean  </li><li>PortSettings0  integer  0</li><li>PortSettings1  integer  0</li><p><b>OneWire Gateway</b></p><li>GatewayMode  integer  0</li><p><b>OZW Configurator</b></p><li>    </li><p><b>OZW DataPoint</b></p><li>Id  integer  0</li><li>Interval  integer  60</li><li>WriteAccess  boolean  </li><p><b>OZW Device</b></p><li>SerialNumber  string  </li><p><b>OZW Gateway</b></p><li>IPAddress  string  </li><li>Password  string  Password</li><li>Username  string  Administrator</li><p><b>POP3</b></p><li>CacheInterval  integer  300</li><li>CacheSize  integer  10</li><li>Host  string  pop.gmail.com</li><li>Password  string  </li><li>Port  integer  995</li><li>UseAuthentication  boolean  1</li><li>Username  string  mail@gmail.com</li><li>UseSSL  boolean  1</li><p><b>Popup Module</b></p><li>    </li><p><b>Register Variable</b></p><li>RXObjectID  integer  0</li><p><b>Serial Port</b></p><li>BaudRate  string  9600</li><li>DataBits  string  8</li><li>Open  boolean  </li><li>Parity  string  None</li><li>Port  string  </li><li>StopBits  string  1</li><p><b>Server Socket</b></p><li>Limit  integer  0</li><li>Open  boolean  </li><li>Port  integer  1024</li><p><b>Shutter Control</b></p><li>DriveDownTimeClose  double  0</li><li>DriveDownTimeDown  double  0</li><li>DriveDownTimeHalf  double  0</li><li>DriveUpTimeDown  double  0</li><li>DriveUpTimeHalf  double  0</li><li>DriveUpTimeOpen  double  0</li><li>HandlerScript  integer  0</li><li>MotorDelay  integer  0</li><li>ShutterType  integer  0</li><li>TransmitDevice  integer  0</li><li>TransmitDevice2  integer  0</li><p><b>Siemens Device</b></p><li>Address  integer  0</li><li>Area  integer  7</li><li>AreaAddress  integer  0</li><li>Bit  integer  0</li><li>DataType  integer  1</li><li>EmulateStatus  boolean  1</li><li>Factor  double  0</li><li>Poller  integer  0</li><li>ReadOnly  boolean  </li><p><b>Siemens Gateway</b></p><li>ClientTSAPHi  integer  1</li><li>ClientTSAPLo  integer  2</li><li>ServerTSAPHi  integer  1</li><li>ServerTSAPLo  integer  2</li><p><b>Skin Control</b></p><li>    </li><p><b>SMS</b></p><li>APIID  integer  0</li><li>Password  string  </li><li>Sender  string  </li><li>Username  string  </li><p><b>SMTP</b></p><li>Host  string  smtp.gmail.com</li><li>Password  string  </li><li>Port  integer  587</li><li>Recipient  string  </li><li>SenderAddress  string  </li><li>SenderName  string  </li><li>UseAuthentication  boolean  1</li><li>Username  string  mail@gmail.com</li><li>UseSSL  boolean  1</li><p><b>Text Parser</b></p><li>Rules  string  []</li><p><b>Text To Speech</b></p><li>TTSAudioOutput  string  </li><li>TTSEngine  string  </li><p><b>ThermoJet</b></p><li>    </li><p><b>UDP Socket</b></p><li>BindIP  string  172.17.31.80</li><li>BindPort  integer  0</li><li>Host  string  </li><li>Open  boolean  </li><li>Port  integer  0</li><p><b>Universal RX</b></p><li>DeviceID  string  00000000</li><li>RORG  integer  165</li><li>ScriptID  integer  0</li><p><b>Util Control</b></p><li>    </li><p><b>UVR1611</b></p><li>DeviceCount  integer  1</li><li>Interval  integer  0</li><p><b>Velleman USB</b></p><li>    </li><p><b>Virtual IO</b></p><li>Open  boolean  </li><p><b>WebFront Configurator</b></p><li>Editable  boolean  1</li><li>GraphContinuousSpan  boolean  </li><li>GraphDynamicScaling  boolean  </li><li>GraphHighDensity  boolean  </li><li>GraphShowExtrema  boolean  </li><li>GraphShowLegend  boolean  </li><li>GraphTimeSpan  integer  1</li><li>IPAutoStart  string  []</li><li>Items  string  </li><li>LANPasswordNeeded  boolean  1</li><li>MobileID  integer  0</li><li>Nested  boolean  </li><li>Password  string  </li><li>RetroID  integer  -1</li><li>RetroMobileID  integer  -1</li><li>RetroMobileRefresh  integer  30</li><li>RetroRefresh  integer  30</li><li>Skin  string  </li><p><b>WebHook Control</b></p><li>Hooks  string  []</li><p><b>WebServer</b></p><li>Active  boolean  </li><li>AuthPassword  string  </li><li>AuthUsername  string  </li><li>EnableBasicAuth  boolean  </li><li>EnableLogFile  boolean  </li><li>EnableSSL  boolean  </li><li>HomeDir  string  webfront</li><li>Port  integer  82</li><li>Server  string  0.0.0.0</li><p><b>WinLIRC</b></p><li>    </li><p><b>WMRS200</b></p><li>DeviceID  integer  0</li><li>DeviceType  integer  0</li><p><b>WMRS200 Gateway</b></p><li>    </li><p><b>WuT Counter</b></p><li>Impulses  integer  1000</li><li>IONum  integer  0</li><p><b>WuT Gateway</b></p><li>Interval  integer  0</li><li>IPAddress  string  </li><li>Password  string  </li><p><b>WuT Input</b></p><li>IONum  integer  0</li><p><b>WuT Output</b></p><li>IONum  integer  0</li><p><b>WuT ThermoHygro</b></p><li>Interval  integer  0</li><li>IPAddress  string  </li><p><b>WWW Reader</b></p><li>Active  boolean  1</li><li>AuthPass  string  </li><li>AuthUser  string  </li><li>Interval  integer  0</li><li>URL  string  </li><li>UseBasicAuth  boolean  </li><p><b>XBee Gateway</b></p><li>    </li><p><b>XBee Splitter</b></p><li>DeviceID  integer  0</li><p><b>xComfort Binary Input</b></p><li>DataPoint  integer  0</li><p><b>xComfort Configurator</b></p><li>    </li><p><b>xComfort Dimmer</b></p><li>DataPoint  integer  0</li><li>EmulateStatus  boolean  </li><p><b>xComfort Energy</b></p><li>DataPoint  integer  0</li><li>EnergyType  integer  0</li><p><b>xComfort Gateway</b></p><li>GatewayMode  integer  0</li><p><b>xComfort Heating</b></p><li>DataPoint  integer  0</li><li>TemperatureVariableID  integer  0</li><p><b>xComfort HRV</b></p><li>DataPoint  integer  0</li><li>TemperatureVariableID  integer  0</li><p><b>xComfort Humidity</b></p><li>DataPoint  integer  0</li><p><b>xComfort Impulse</b></p><li>DataPoint  integer  0</li><li>Impulses  integer  1000</li><p><b>xComfort Remote</b></p><li>DataPoint  integer  0</li><p><b>xComfort Room Control</b></p><li>DataPoint  integer  0</li><p><b>xComfort Shutter</b></p><li>DataPoint  integer  0</li><li>EmulateStatus  boolean  </li><p><b>xComfort Switch</b></p><li>DataPoint  integer  0</li><li>EmulateStatus  boolean  </li><p><b>xComfort Temperature</b></p><li>DataPoint  integer  0</li><p><b>xComfort Value RX</b></p><li>DataPoint  integer  0</li><li>ValueType  integer  0</li><p><b>xComfort Value TX</b></p><li>DataPoint  integer  0</li><li>ValueType  integer  0</li><p><b>Z-Wave Configurator</b></p><li>    </li><p><b>Z-Wave Gateway</b></p><li>GatewayMode  integer  1</li><p><b>Z-Wave Module</b></p><li>AlarmVersion  integer  1</li><li>DisableTransmitQueue  boolean  </li><li>EnableSceneActivationClass  boolean  </li><li>EnforceBasicClass  boolean  </li><li>Interval  integer  0</li><li>ManufacturerID  string  </li><li>MeterSupportedScale  integer  0</li><li>MeterSupportedType  integer  0</li><li>MeterSupportsReset  boolean  </li><li>MultiInstanceClasses  string  []</li><li>MultiInstanceCount  integer  0</li><li>MultiInstanceID  integer  0</li><li>MultiInstanceVersion  integer  1</li><li>NodeClasses  string  []</li><li>NodeID  integer  0</li><li>ProductID  string  </li><li>ProductType  string  </li><li>SensorAlarmSupported  string  []</li><li>ThermostatSupportedFanMode  integer  0</li><li>ThermostatSupportedMode  integer  0</li><li>ThermostatSupportedSetPoint  integer  0</li>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/instanzenverwaltung/konfiguration/ips-setproperty/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID der Instanz
 * @param string $Name Name der Eigenschaft
 * @param mixed $Value Neuer Wert der Eigenschaft
 */
function IPS_SetProperty(integer $InstanceID, string $Name, mixed $Value)
{
    
}

/**
 * setzt den Inhalt eines Skripts
 * 
 * <p>Diese Funktion setzt den Inhalt fr das Skript mit der ID <b>SkriptID</b>. Dabei wird der Dateiname, der standardmig definiert ist, genutzt, sofern kein anderer per IPS_SetScriptFile definiert wurde.</p><p>Diese Funktion ist mit Vorsicht zu verwenden, da der Inhalt ohne Warnung berschrieben wird.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/skriptverwaltung/ips-setscriptcontent/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $ScriptID ID des Skripts, dem der Inhalt zugeordnet werden soll
 * @param string $Content Inhalt inklusive PHP Tags ( und ?&gt;)
 */
function IPS_SetScriptContent(integer $ScriptID, string $Content)
{
    
}

/**
 * ordnet einem Skript einen Dateinamen zu
 * 
 * <p>Der Befehl bindet den Dateinamen <b>DateiName</b> an das Skript mit der ID <b>SkriptID</b>. Normalerweise besteht der Dateiname eines Skripts nur aus dessen ID mit der Extension .ips.php. Mit diesem Befehl ist es mglich, einen anderen Dateinamen zu verwenden.</p><p>Der Dateiname hat nichts mit dem Skriptnamen zu tun, der im Location Tree zu sehen ist. Skriptname und Dateiname knnen vllig verschieden sein. Die SkriptID bleibt auch nach der Zuordnung erhalten. Weder der Skriptname noch der Dateiname knnen direkt zur Identifikation des Skripts verwendet werden. Von IP-Symcon wird hierfr immer nur die numerische SkriptID benutzt.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/skriptverwaltung/ips-setscriptfile/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $ScriptID ID des Skripts, dem der Dateiname zugeordnet werden soll
 * @param string $FilePath Dateiname des PHP Skripts (relativ zum /scripts Ordner)
 */
function IPS_SetScriptFile(integer $ScriptID, string $FilePath)
{
    
}

/**
 * setzt den Startwert des ScriptTimers
 * 
 * <p>Der Befehl setzt den Integer-Startwert des ScriptTimers des Skripts mit der ID <b>SkriptID</b> auf den Wert <b>TimerWert</b> in Sekunden. Mit diesem Befehl kann man den ScriptTimer auf einen bestimmten Wert setzen. Der Wert wird in Sekundenschritten heruntergezhlt. Beim Erreichen des Werts 0 wird das Skript gestartet und der ScriptTimer erneut auf den Startwert gesetzt. Dieser Vorgang wiederholt sich bis der Timer explizit gelscht (auf 0 gesetzt) wurde.</p><p>Dieser Befehl funktioniert nur sekundengenau, wenn Werte kleiner als 3600 angegeben werden. Bei Werten ber 3600 kann es je nach Startzeit/Teiler zu unregelmigkeiten kommen, da der SkriptTimer an die Limitation von normalen Ereignissen und dessen Zeitmuster gebunden ist. z.B. wird ein SkriptTimer, welcher alle 5 Stunden starten soll und um 6h frh gesetzt wird, tglich um 6h, 11h, 16h, 21h und dann wieder um 1h, statt wie vielleicht erwartet um 2h, gestartet. Werte ber die Tagesgrenze hinaus werden zu vollen Tagen abgerundet.</p><p>Steht der Wert auf 0, so ist der Timer abgeschaltet, und es erfolgt kein Ausfhrung.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/skriptverwaltung/ips-setscripttimer/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $ScriptID ID des Skripts, dessen Timer eingestellt werden solll
 * @param integer $Interval Zeit in Sekunden, in denen das Skript zyklisch aufgerufen werden soll
 */
function IPS_SetScriptTimer(integer $ScriptID, integer $Interval)
{
    
}

/**
 * ordnet der Variable ein benutzerdefiniertes Aktionsskript zu
 * 
 * <p>Der Befehl vergibt der Variable <b>VariablenID</b> eine benutzerdefinierte Aktion, die in der Visualisierung benutzt wird, um eine nderung der Variable an die richtige Funktion des Moduls weiterzuleiten. Ein Beispiel fr ein Aktionsskript kann hier gefunden werden: Variablenprofile</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/variablenverwaltung/ips-setvariablecustomaction/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $VariableID ID der Variable, der die Aktion zugeordnet werden soll
 * @param integer $ScriptID ID eines Skriptes, das als Aktions aufgefhrt werden soll. Sofern eine vorhandene Standardaktion deaktiviert werden soll, kann die nichtvorhandene SkriptID Eins (1) angegeben werden, wodurch die Standardaktion ausgeschaltet wird. Wenn eine gltige SkriptID angegebenen wird, so hat diese Vorrang vor der Standardaktion.
 */
function IPS_SetVariableCustomAction(integer $VariableID, integer $ScriptID)
{
    
}

/**
 * ordnet der Variable ein benutzerdefiniertes Profil zu
 * 
 * <p>Der Befehl vergibt der Variable <b>VariablenID</b> das benutzerdefinierte Profil <b>ProfilName</b>.</p><p>Diese Funktion berprft vor dem Setzen die Existenz des zu setzenden Profils und die bereinstimmung von Profiltyp und Variablentyp.</p><p>Standardprofile, die nicht gendert werden knnen, fangen mit einer Tilde (~) an.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/variablenverwaltung/ips-setvariablecustomprofile/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $VariableID ID der Variable, der das Profil zugeordnet werden soll
 * @param string $ProfileName Name des Profils. Verfgbare Profile knnen ber
 */
function IPS_SetVariableCustomProfile(integer $VariableID, string $ProfileName)
{
    
}

/**
 * modifiziert die Assoziationstabelle eines Variablenprofils
 * 
 * <p>Der Befehl setzt den <b>Namen</b>, das <b>Icon</b> und die <b>Farbe</b> fr einen <b>Wert</b> eines Variablenprofils mit Namen <b>ProfilName</b>. Die Farbe wird nicht angezeigt fr Profile vom Typ Wertanzeige/Slider (siehe Objekt-Darstellung).</p><p>Wenn <b>Name</b> und <b>Icon</b> leer sind, wird die Assoziation zum angegebenen <b>Wert</b> gelscht.</p><p>Standardprofile, die nicht gendert werden knnen, fangen mit einer Tilde (~) an.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/variablenverwaltung/variablenprofile/ips-setvariableprofileassociation/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param string $ProfileName Name des Profils. Verfgbare Profile knnen ber
 * @param float $AssociationValue Wert, zu dem der Name und das Icon verknpft werden sollen
 * @param string $AssociationName Name zum angegebenen Wert
 * @param string $AssociationIcon Icon zum angegebenen Wert
 * @param integer $AssociationColor Farbwert im HTML Farbcode (z.b. 0x0000FF fr Blau). Sonderfall: -1 fr transparent
 */
function IPS_SetVariableProfileAssociation(string $ProfileName, float $AssociationValue, string $AssociationName, string $AssociationIcon, integer $AssociationColor)
{
    
}

/**
 * setzt die Anzahl der Nachkommastellen eines Variablenprofils
 * 
 * <p>Der Befehl setzt die Anzahl der <b>Nachkommastellen</b> eines Variablenprofils mit Namen <b>ProfilName</b>.</p><p>Standardprofile, die nicht gendert werden knnen, fangen mit einer Tilde (~) an.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/variablenverwaltung/variablenprofile/ips-setvariableprofiledigits/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param string $ProfileName Name des Profils. Verfgbare Profile knnen ber
 * @param integer $Digits Anzahl der in der Visualisierung angezeigten Nachkommastellen
 */
function IPS_SetVariableProfileDigits(string $ProfileName, integer $Digits)
{
    
}

/**
 * setzt das Icon eines Variablenprofils
 * 
 * <p>Der Befehl setzt das standardmig genutzte Icon eines Variablenprofils mit Namen <b>ProfilName</b>.</p><p>Die Reihenfolge der genutzten Icons ist wie folgt: AssoziationsIcon -&gt; ProfilIcon -&gt; LinkIcon -&gt; ObjektIcon</p><p>Wenn Name und Icon leer sind, wird die Assoziation zum angegebenen Wert gelscht.</p><p>Standardprofile, die nicht gendert werden knnen, fangen mit einer Tilde (~) an.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/variablenverwaltung/variablenprofile/ips-setvariableprofileicon/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param string $ProfileName Name des Profils. Verfgbare Profile knnen ber
 * @param string $Icon Icon zum angegebenen Wert
 */
function IPS_SetVariableProfileIcon(string $ProfileName, string $Icon)
{
    
}

/**
 * setzt das Prefix und Suffix eines Variablenprofils
 * 
 * <p>Der Befehl setzt den Prfix und Suffix eines Variablenprofils mit Namen <b>ProfilName</b>.</p><p>Standardprofile, die nicht gendert werden knnen, fangen mit einer Tilde (~) an.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/variablenverwaltung/variablenprofile/ips-setvariableprofiletext/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param string $ProfileName Name des Profils. Verfgbare Profile knnen ber
 * @param string $Prefix Prefix fr den Wert
 * @param string $Suffix Suffix fr den Wert
 */
function IPS_SetVariableProfileText(string $ProfileName, string $Prefix, string $Suffix)
{
    
}

/**
 * setzt den Minimalwert, Maximalwert und die Schrittweite eines Variablenprofils
 * 
 * <p>Der Befehl setzt den <b>MinimalWert</b>, <b>MaximalWert</b> und die <b>Schrittweite</b> eines Variablenprofils mit Namen <b>ProfilName</b>.</p><p>Standardprofile, die nicht gendert werden knnen, fangen mit einer Tilde (~) an.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/variablenverwaltung/variablenprofile/ips-setvariableprofilevalues/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param string $ProfileName Name des Profils. Verfgbare Profile knnen ber
 * @param float $MinValue Der fr die Visualisierung genutzte Minimalwert. Diese Soft-Limitation beeinflusst nicht den Variablenwert.
 * @param float $MaxValue Der fr die Visualisierung genutzte Maximalwert. Diese Soft-Limitation beeinflusst nicht den Variablenwert.
 * @param float $StepSize Die fr die Visualisierung genutzte Schrittweite zur Erstellung der Sollwert-Vernderngsleiste. Eine Schrittweite von
 */
function IPS_SetVariableProfileValues(string $ProfileName, float $MinValue, float $MaxValue, float $StepSize)
{
    
}

/**
 * verzgert ein Skript um ein bestimme zeit
 * 
 * <p>Der Befehl setzt die Abarbeitung des Skripts fr <b>Wartezeit</b> Millisekunden aus. Nach Ablauf dieser Zeit wird das Skript fortgesetzt. Mit Hilfe dieses Befehls lassen sich <b>kurze</b> (!) Wartezeiten realisieren. Lngere Wartezeiten sollten nicht durch Sleep Befehle realisiert, sondern ber geeignete <b>Ereignisse</b> gesteuert werden.</p><p>Da sich die Laufzeit des Skripts um <b>Wartezeit</b> verlngert, ist darauf zu achten, dass die maximale Laufzeit (30 Sekunden) nicht berschritten wird. Andernfalls wird das Skript mit einer Fehlermeldung abgebrochen. Lngere Wartezeiten im Bereich von mehreren Sekunden und lnger sollten mit anderen Methoden realisiert werden.</p><p>IPS_Sleep hat keinen Einfluss auf andere gleichzeitig laufende Skripte.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/ablaufsteuerung/ips-sleep/
 * @returns integer Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $Milliseconds Gibt die Wartezeit in Millisekunden an
 */
function IPS_Sleep(integer $Milliseconds)
{
    
}

/**
 * IPS_StartSearch
 * 
 * @returns boolean
 * @param integer $InstanceID
 */
function IPS_StartSearch(integer $InstanceID)
{
    
}

/**
 * IPS_StopSearch
 * 
 * @returns boolean
 * @param integer $InstanceID
 */
function IPS_StopSearch(integer $InstanceID)
{
    
}

/**
 * IPS_SupportsSearching
 * 
 * @returns boolean
 * @param integer $InstanceID
 */
function IPS_SupportsSearching(integer $InstanceID)
{
    
}

/**
 * IPS_TimerExists
 * 
 * @returns boolean
 * @param integer $TimerID
 */
function IPS_TimerExists(integer $TimerID)
{
    
}

/**
 * prft, ob eine bestimmte Variable existiert
 * 
 * <p>Der Befehl prft, ob die Variable mit der ID <b>VariablenID</b> existiert.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/variablenverwaltung/ips-variableexists/
 * @returns boolean <p>Falls die VariablenID im System existiert, wird <b>TRUE</b> zurckgemeldet, andernfalls <b>FALSE</b>.</p>
 * @param integer $VariableID ID der zu prfenden Variable
 */
function IPS_VariableExists(integer $VariableID)
{
    
}

/**
 * prft, ob ein bestimmtes Variablenprofil existiert
 * 
 * <p>Der Befehl prft, ob das Variablenprofil  mit dem Namen <b>ProfilName</b> existiert.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/variablenverwaltung/variablenprofile/ips-variableprofileexists/
 * @returns boolean <p>Falls die VariablenID im System existiert, wird <b>TRUE</b> zurckgemeldet, andernfalls <b>FALSE</b>.</p>
 * @param string $ProfileName Name des gesuchten Variablenprofils
 */
function IPS_VariableProfileExists(string $ProfileName)
{
    
}

/**
 * IQLFT_Update
 * 
 * @returns mixed
 * @param integer $InstanceID
 */
function IQLFT_Update(integer $InstanceID)
{
    
}

/**
 * IRT_ListButtons
 * 
 * @returns array
 * @param integer $InstanceID
 * @param string $Remote
 */
function IRT_ListButtons(integer $InstanceID, string $Remote)
{
    
}

/**
 * IRT_ListRemotes
 * 
 * @returns array
 * @param integer $InstanceID
 */
function IRT_ListRemotes(integer $InstanceID)
{
    
}

/**
 * sendet einen IR Befehl
 * 
 * <p>Sendet einen Fernbedienungsbefehl ber die Instanz mit der ID <b>InstanzID</b> ab. Die Werte Fernbedienung und Knopf geben an, welcher Befehl gesendet werden soll. Diese mssen in der Client Software (IRTrans Tray) entsprechend eingerichtet worden sein.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/irtrans/irt-sendonce/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param string $Remote Name der Fernbedienung, der in der Fernbedienungsdatenbank eingetragen ist/wurde.
 * @param string $Button Name der Fernbedienungsfunktion, die in der Fernbedienungsdatenbank eingetragen ist/wurde.
 */
function IRT_SendOnce(integer $InstanceID, string $Remote, string $Button)
{
    
}

/**
 * LCN_AddGroup
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param integer $Group
 */
function LCN_AddGroup(integer $InstanceID, integer $Group)
{
    
}

/**
 * erhht die Leuchtintensitt ein Gert
 * 
 * <p>Dimmt das Gert mit der ID <b>InstanzID</b> um den Wert <b>Intensitt</b> heller.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/lcn/lcn-addintensity/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param integer $Intensity 0-100%
 */
function LCN_AddIntensity(integer $InstanceID, integer $Intensity)
{
    
}

/**
 * lsst ein Gert piepen
 * 
 * <p>Lsst das Modul mit der ID <b>InstanzID</b> piepen</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/lcn/lcn-beep/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des Moduls. (In IP-Symcon die Splitter Instanz zum Modul)
 * @param boolean $SpecialTone 
 * @param integer $Count Anzahl zwischen 1..15
 */
function LCN_Beep(integer $InstanceID, boolean $SpecialTone, integer $Count)
{
    
}

/**
 * veringert die Leuchtintensitt ein Gert
 * 
 * <p>Dimmt das Gert mit der ID InstanzID um den Wert Intensitt dunkler.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/lcn/lcn-deductintensity/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param integer $Intensity 0-100%
 */
function LCN_DeductIntensity(integer $InstanceID, integer $Intensity)
{
    
}

/**
 * LCN_Fadeout
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param integer $Intensity
 * @param integer $Ramp
 */
function LCN_Fadeout(integer $InstanceID, integer $Intensity, integer $Ramp)
{
    
}

/**
 * schaltet ein Relais um
 * 
 * <p>Schaltet das Relais mit der ID <b>InstanzID</b> um</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/lcn/lcn-fliprelay/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Relais
 */
function LCN_FlipRelay(integer $InstanceID)
{
    
}

/**
 * LCN_GetKnownDevices
 * 
 * @returns array
 * @param integer $InstanceID
 */
function LCN_GetKnownDevices(integer $InstanceID)
{
    
}

/**
 * LCN_LimitOutput
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param integer $Value
 * @param integer $Time
 * @param string $TimeType
 */
function LCN_LimitOutput(integer $InstanceID, integer $Value, integer $Time, string $TimeType)
{
    
}

/**
 * LCN_LoadScene
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param integer $Scene
 */
function LCN_LoadScene(integer $InstanceID, integer $Scene)
{
    
}

/**
 * LCN_LockTargetValue
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param integer $Target
 *   enum[0=ltR1, 1=ltR2, 2=ltS1, 3=ltS2]
 */
function LCN_LockTargetValue(integer $InstanceID, integer $Target)
{
    
}

/**
 * stoppt einen Dimmvorgang
 * 
 * <p>Stoppt den Dimmvorgang von Gert mit der ID <b>InstanzID</b></p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/lcn/lcn-rampstop/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 */
function LCN_RampStop(integer $InstanceID)
{
    
}

/**
 * LCN_ReleaseTargetValue
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param integer $Target
 *   enum[0=ltR1, 1=ltR2, 2=ltS1, 3=ltS2]
 */
function LCN_ReleaseTargetValue(integer $InstanceID, integer $Target)
{
    
}

/**
 * LCN_RemoveGroup
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param integer $Group
 */
function LCN_RemoveGroup(integer $InstanceID, integer $Group)
{
    
}

/**
 * LCN_RequestLights
 * 
 * @returns boolean
 * @param integer $InstanceID
 */
function LCN_RequestLights(integer $InstanceID)
{
    
}

/**
 * LCN_RequestRead
 * 
 * @returns boolean
 * @param integer $InstanceID
 */
function LCN_RequestRead(integer $InstanceID)
{
    
}

/**
 * LCN_RequestStatus
 * 
 * @returns boolean
 * @param integer $InstanceID
 */
function LCN_RequestStatus(integer $InstanceID)
{
    
}

/**
 * LCN_RequestThresholds
 * 
 * @returns boolean
 * @param integer $InstanceID
 */
function LCN_RequestThresholds(integer $InstanceID)
{
    
}

/**
 * LCN_SaveScene
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param integer $Scene
 */
function LCN_SaveScene(integer $InstanceID, integer $Scene)
{
    
}

/**
 * LCN_SearchDevices
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param integer $Segment
 */
function LCN_SearchDevices(integer $InstanceID, integer $Segment)
{
    
}

/**
 * LCN_SelectSceneRegister
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param integer $Register
 */
function LCN_SelectSceneRegister(integer $InstanceID, integer $Register)
{
    
}

/**
 * sendet einen benutzerdefinierten Befehl
 * 
 * <p>Sendet einen benutzerdefinierten Befehl an das Modul der ID <b>InstanzID</b>. Mgliche Befehle entnehmen Sie bitte der PCHK Dokumentation. Falls Sie diese nicht besitzen, knnen Sie diese u.U. von Ihrem Fachhndler beziehen. Wir haben leider keine Mglichkeit diese bereitzustellen.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/lcn/lcn-sendcommand/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des Moduls. (In IP-Symcon die Splitter Instanz zum Modul)
 * @param string $Function Die ersten beiden (2) Zeichen des PCHK Befehls (z.B. A1)
 * @param string $Data Die restlichen Zeichen des PCHK Befehls (z.B. DI000000). Eventuelle Zahlen mssen in der dezimalen Darstellung (3 Zeichen) gesendet werden.
 */
function LCN_SendCommand(integer $InstanceID, string $Function, string $Data)
{
    
}

/**
 * dimmt ein Gert in einer bestimmten Zeit
 * 
 * <p>Dimmt das Gert mit der ID <b>InstanzID</b> auf Wert <b>Intensitt</b> in <b>Rampe</b> Sekunden</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/lcn/lcn-setintensity/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param integer $Intensity 0-100%
 * @param integer $Ramp 0 = Sofort; n = Sekunden
 */
function LCN_SetIntensity(integer $InstanceID, integer $Intensity, integer $Ramp)
{
    
}

/**
 * LCN_SetLamp
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param integer $Lamp
 * @param string $Action
 */
function LCN_SetLamp(integer $InstanceID, integer $Lamp, string $Action)
{
    
}

/**
 * setzt alle Relais in einem Modul (8Bit)
 * 
 * <p>Setzt alle Relais des Moduls mit der ID <b>InstanzID</b> auf <b>Wert</b></p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/lcn/lcn-setrelay/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des Moduls. (In IP-Symcon die Splitter Instanz zum Modul)
 * @param string $Value 8fache Zeichenkombination der folgenden Werte: - = Nichts tun; 0 = Ausschalten; 1 = Einschalten; U = Umschalten
 */
function LCN_SetRelay(integer $InstanceID, string $Value)
{
    
}

/**
 * setzt einen Regler auf einen bestimmten Wert
 * 
 * <p>Setzt den Regler <b>Ziel</b> der ID <b>InstanzID</b> auf den <b>Wert</b></p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/lcn/lcn-settargetvalue/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des Moduls. (In IP-Symcon die Splitter Instanz zum Modul)
 * @param integer $Target 0 = Regler A; 1 = Regler B; 2 = Regler 1; 3 = Regler 2
 *   enum[0=ltR1, 1=ltR2, 2=ltS1, 3=ltS2]
 * @param float $Value Wert
 */
function LCN_SetTargetValue(integer $InstanceID, integer $Target, float $Value)
{
    
}

/**
 * LCN_ShiftTargetValue
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param integer $Target
 *   enum[0=ltR1, 1=ltR2, 2=ltS1, 3=ltS2]
 * @param float $RelativeValue
 */
function LCN_ShiftTargetValue(integer $InstanceID, integer $Target, float $RelativeValue)
{
    
}

/**
 * LCN_ShutterMoveDown
 * 
 * @returns boolean
 * @param integer $InstanceID
 */
function LCN_ShutterMoveDown(integer $InstanceID)
{
    
}

/**
 * LCN_ShutterMoveUp
 * 
 * @returns boolean
 * @param integer $InstanceID
 */
function LCN_ShutterMoveUp(integer $InstanceID)
{
    
}

/**
 * LCN_ShutterStop
 * 
 * @returns boolean
 * @param integer $InstanceID
 */
function LCN_ShutterStop(integer $InstanceID)
{
    
}

/**
 * ein Gert flackern lassen
 * 
 * <p>Das Gert mit der ID <b>InstanzID</b> auf Flackern lassen</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/lcn/lcn-startflicker/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param string $Depth G = Gering; M = Mittel; S = Start
 * @param string $Speed L = Langsam (ca. 0,5x / Sek); M = Mittel (ca. 1x / Sek); S = Schnell (ca. 2x / Sek)
 * @param integer $Count Anzahl zwischen 1..15
 */
function LCN_StartFlicker(integer $InstanceID, string $Depth, string $Speed, integer $Count)
{
    
}

/**
 * stoppt das Flackern eines Gerts
 * 
 * <p>Flackern des Gerts mit der InstanzID sofort beenden</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/lcn/lcn-stopflicker/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 */
function LCN_StopFlicker(integer $InstanceID)
{
    
}

/**
 * LCN_SwitchDurationMin
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param integer $Minutes
 * @param string $Fadeout
 * @param boolean $Retentive
 */
function LCN_SwitchDurationMin(integer $InstanceID, integer $Minutes, string $Fadeout, boolean $Retentive)
{
    
}

/**
 * LCN_SwitchDurationSec
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param integer $Seconds
 * @param string $Fadeout
 * @param boolean $Retentive
 */
function LCN_SwitchDurationSec(integer $InstanceID, integer $Seconds, string $Fadeout, boolean $Retentive)
{
    
}

/**
 * setzt das Gert auf einen gespeicherten Wert
 * 
 * <p>Schaltet das Gert mit der ID <b>InstanzID</b> auf einen abgespeicherten Wert</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/lcn/lcn-switchmemory/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param integer $Ramp Anzahl Sekunden, 0 = Sofort
 */
function LCN_SwitchMemory(integer $InstanceID, integer $Ramp)
{
    
}

/**
 * schaltet ein Gert an/aus
 * 
 * <p>Schaltet das Gert mit der ID <b>InstanzID</b> um.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/lcn/lcn-switchmode/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param integer $Ramp Anzahl Sekunden, 0 = Sofort
 */
function LCN_SwitchMode(integer $InstanceID, integer $Ramp)
{
    
}

/**
 * schaltet ein Relais An/Aus
 * 
 * <p>Schaltet das Relais mit der ID <b>InstanzID</b> auf Wert <b>Status</b></p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/lcn/lcn-switchrelay/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param boolean $SwitchOn 
 */
function LCN_SwitchRelay(integer $InstanceID, boolean $SwitchOn)
{
    
}

/**
 * aktualisiert alle gertespezifischen Werte
 * 
 * <p>Aktualisiert die Werte mit der ID <b>InstanzID</b></p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/mbus/mbus-updatevalues/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu aktualisierenden Gerts
 */
function MBUS_UpdateValues(integer $InstanceID)
{
    
}

/**
 * MC_CreateModule
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param string $ModuleURL
 */
function MC_CreateModule(integer $InstanceID, string $ModuleURL)
{
    
}

/**
 * MC_DeleteModule
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param string $Module
 */
function MC_DeleteModule(integer $InstanceID, string $Module)
{
    
}

/**
 * MC_GetModuleList
 * 
 * @returns array
 * @param integer $InstanceID
 */
function MC_GetModuleList(integer $InstanceID)
{
    
}

/**
 * MC_GetModuleRepositoryInfo
 * 
 * @returns array
 * @param integer $InstanceID
 * @param string $Module
 */
function MC_GetModuleRepositoryInfo(integer $InstanceID, string $Module)
{
    
}

/**
 * MC_UpdateModule
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param string $Module
 */
function MC_UpdateModule(integer $InstanceID, string $Module)
{
    
}

function MXC_DimBrighter(integer $InstanceID)
{
    
}

/**
 * fngt einen Dimmvorgang auf eine dunklere Stufe an
 * 
 * <p>Beginnt den Dimmvorgang fr Gert mit der ID InstanzID auf einer niedrigeren Helligkeitsstufe. Der Vorgang kann mit dem Befehl MXC_DimStop beendet werden. Wird die maximale Stufe erreicht, stoppt der Vorgang automatisch. Die Statusmeldung wird von dem Gert gesendet, sobald der Vorgang beendet wurde. Es werden keine Meldungen zwischendurch versandt.</p><p>Die Geschwindigkeit und Strke der Dimmung muss vorher ber die xComfort Programmierschnittstelle festgelegt werden. IP-Symcon ruft nur die Dimmung auf.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/xcomfort/mxc-dimdarker/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 */
function MXC_DimDarker(integer $InstanceID)
{
    
}

/**
 * dimmt ein xComfort Gert auf eine bestimmte Stufe
 * 
 * <p>Dimmt das Gert mit der ID <b>InstanzID</b> auf Wert <b>Intensitt</b></p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/xcomfort/mxc-dimset/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param integer $Intensity Wert von 0-100 (in %)
 */
function MXC_DimSet(integer $InstanceID, integer $Intensity)
{
    
}

/**
 * hlt einen Dimmvorgang an
 * 
 * <p>Schaltet das Gert mit der ID <b>InstanzID</b> auf Wert <b>Status</b></p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/xcomfort/mxc-dimstop/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 */
function MXC_DimStop(integer $InstanceID)
{
    
}

/**
 * MXC_GetKnownDevices
 * 
 * @returns array
 * @param integer $InstanceID
 */
function MXC_GetKnownDevices(integer $InstanceID)
{
    
}

/**
 * MXC_RequestInfo
 * 
 * @returns boolean
 * @param integer $InstanceID
 */
function MXC_RequestInfo(integer $InstanceID)
{
    
}

/**
 * sende eine Statusmeldungsanfrage an ein Gert
 * 
 * <p>Fordert ein erneutes Senden der Statusmeldungen fr Gert mit der ID <b>InstanzID</b> an.</p><p>Da Statusmeldungen im xComfort System nicht geroutet werden, kann es sein, dass der Befehl erfolgreich ausgefhrt, aber kein neuer Status empfangen wird. Dieser Befehlt fragt den Status nicht ab, sondern fordert nur einen neue Statusmeldung an.</p><p><b>Diese Funktion belastet den Funkverkehr erheblich.</b>Sie sollte ausschlielich verwendet werden, um kritische Gert zum IP-Symcon-Start zu aktualisieren. Ein erneutes Abfragen zur Laufzeit wird nicht bentigt, da xComfort alle Statusnderungen direkt an IP-Symcon weiterleitet.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/xcomfort/mxc-requeststatus/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des Gerts
 */
function MXC_RequestStatus(integer $InstanceID)
{
    
}

/**
 * MXC_SearchDevices
 * 
 * @returns boolean
 * @param integer $InstanceID
 */
function MXC_SearchDevices(integer $InstanceID)
{
    
}

/**
 * sendet einen Boolean-Wert an den Room-Mananger
 * 
 * <p>Sendet einen booleanischen Wert an die Instanz mit der <b>InstanzID</b>, welche an einen Room-Manager angeschlossen ist.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/xcomfort/mxc-sendboolean/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param boolean $Value True fr An, False fr Aus
 */
function MXC_SendBoolean(integer $InstanceID, boolean $Value)
{
    
}

/**
 * sendet einen Float-Wert an den Room-Mananger
 * 
 * <p>Sendet eine Gleitkommazahl an die Instanz mit der <b>InstanzID</b>, welche an einen Room-Manager angeschlossen ist.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/xcomfort/mxc-sendfloat/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param float $Value Zahlenwert mit Nachkommastelle
 */
function MXC_SendFloat(integer $InstanceID, float $Value)
{
    
}

/**
 * sendet einen Integer-Wert an den Room-Mananger
 * 
 * <p>Sendet einen booleanischen Wert an die Instanz mit der <b>InstanzID</b>, welche an einen Room-Manager angeschlossen ist.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/xcomfort/mxc-sendinteger/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param integer $Value Zahlenwert ohne Nachkommastellen
 */
function MXC_SendInteger(integer $InstanceID, integer $Value)
{
    
}

/**
 * sendet einen Sollwert an den Stellantrieb
 * 
 * <p>Setzt die neue Soll-Temperatur des Stellventils mit der <b>InstanzID</b> InstanzID auf die neue <b>Temperatur</b>.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/xcomfort/mxc-settemperature/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param float $Temperature Temperatur in C
 */
function MXC_SetTemperature(integer $InstanceID, float $Temperature)
{
    
}

/**
 * bewegt den Rolladen nach unten bis zur Endposition/Stop
 * 
 * <p>Bewegt den Rolladen mit der ID <b>InstanzID</b> nach unten, bis MXC_ShutterStop ausgefhrt wird oder die Endposition erreicht wird.</p><p>Beachten Sie, dass die Laufzeitlimitierung ber das MRF Tool von Moeller programmiert wird. IP-Symcon kann diese Limitierung nicht beeinflussen.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/xcomfort/mxc-shuttermovedown/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 */
function MXC_ShutterMoveDown(integer $InstanceID)
{
    
}

/**
 * bewegt den Rolladen nach oben bis zur Endposition/Stop
 * 
 * <p>Bewegt den Rolladen mit der ID <b>InstanzID</b> nach oben, bis MXC_ShutterStop ausgefhrt wird oder die Endposition erreicht wird.</p><p>Beachten Sie, dass die Laufzeitlimitierung ber das MRF Tool von Moeller programmiert wird. IP-Symcon kann diese Limitierung nicht beeinflussen.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/xcomfort/mxc-shuttermoveup/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 */
function MXC_ShutterMoveUp(integer $InstanceID)
{
    
}

/**
 * bewegt den Rolladen ein Stck nach unten
 * 
 * <p>Bewegt den Rolladen mit der ID <b>InstanzID</b> einen Schritt nach unten.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/xcomfort/mxc-shutterstepdown/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 */
function MXC_ShutterStepDown(integer $InstanceID)
{
    
}

/**
 * bewegt den Rolladen ein Stck nach oben
 * 
 * <p>Bewegt den Rolladen mit der ID <b>InstanzID</b> einen Schritt nach oben.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/xcomfort/mxc-shutterstepup/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 */
function MXC_ShutterStepUp(integer $InstanceID)
{
    
}

/**
 * stoppt einen Bewegungsvorgang
 * 
 * <p>Stoppt eine aktuelle Bewegung des Rolladens.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/xcomfort/mxc-shutterstop/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 */
function MXC_ShutterStop(integer $InstanceID)
{
    
}

/**
 * schaltet ein xComfort Gert an/aus
 * 
 * <p>Schaltet das Gert mit der ID <b>InstanzID</b> auf Wert <b>Status</b></p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/xcomfort/mxc-switchmode/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param boolean $DeviceOn 
 */
function MXC_SwitchMode(integer $InstanceID, boolean $DeviceOn)
{
    
}

/**
 * MXC_UploadDataPointFile
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param string $Content
 */
function MXC_UploadDataPointFile(integer $InstanceID, string $Content)
{
    
}

/**
 * fhrt einen Lesevorgang auf einem Gert aus
 * 
 * <p>Fhrt einen erneuten Lesevorgang fr das Gert mit der ID <b>InstanzID</b> aus.</p><p>Sobald die Funktion ausgefhrt wurde, sind die neuen Werte in den Status Variablen abrufbar.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/modbus-rtu-tcp/modbus-requestread/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 */
function ModBus_RequestRead(integer $InstanceID)
{
    
}

/**
 * setzt eine Adresse auf An/Aus
 * 
 * <p>Setzt die Adresse mit der ID <b>InstanzID</b> auf Wert <b>Status</b></p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/modbus-rtu-tcp/modbus-writecoil/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param boolean $Value 
 */
function ModBus_WriteCoil(integer $InstanceID, boolean $Value)
{
    
}

/**
 * ModBus_WriteRegister
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param float $Value
 */
function ModBus_WriteRegister(integer $InstanceID, float $Value)
{
    
}

/**
 * setzt eine Adresse auf einen bestimmten Bytewert
 * 
 * <p>Setzt die Adresse mit der ID <b>InstanzID</b> auf Wert</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/modbus-rtu-tcp/modbus-writeregisterbyte/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param integer $Value 0-255
 */
function ModBus_WriteRegisterByte(integer $InstanceID, integer $Value)
{
    
}

/**
 * setzt eine Adresse auf einen bestimmten unsigned Integerwert
 * 
 * <p>Setzt die Adresse mit der ID <b>InstanzID</b> auf <b>Wert</b></p><p>Aufgrund einer Beschrnkung auf 32-Bit Integer innerhalb von PHP, kann nur der Bereich bis 2147483647 genutzt werden.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/modbus-rtu-tcp/modbus-writeregisterdword/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param integer $Value 0-4294967295
 */
function ModBus_WriteRegisterDWord(integer $InstanceID, integer $Value)
{
    
}

/**
 * setzt eine Adresse auf einen bestimmten 64bit Integerwert
 * 
 * <p>Setzt die Adresse mit der ID <b>InstanzID</b> auf <b>Wert</b></p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/modbus-rtu-tcp/modbus-writeregisterint64/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param float $Value -2147483648 bis 2147483647
 */
function ModBus_WriteRegisterInt64(integer $InstanceID, float $Value)
{
    
}

/**
 * setzt eine Adresse auf einen bestimmten Integerwert
 * 
 * <p>Setzt die Adresse mit der ID <b>InstanzID</b> auf <b>Wert</b></p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/modbus-rtu-tcp/modbus-writeregisterinteger/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param integer $Value -2147483648 bis 2147483647
 */
function ModBus_WriteRegisterInteger(integer $InstanceID, integer $Value)
{
    
}

/**
 * setzt eine Adresse auf einen bestimmten Floatwert
 * 
 * <p>Setzt die Adresse mit der ID <b>InstanzID</b> auf <b>Wert</b></p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/modbus-rtu-tcp/modbus-writeregisterreal/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param float $Value 32Bit Gleitkommawert nach IEEE754
 */
function ModBus_WriteRegisterReal(integer $InstanceID, float $Value)
{
    
}

/**
 * ModBus_WriteRegisterReal64
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param float $Value
 */
function ModBus_WriteRegisterReal64(integer $InstanceID, float $Value)
{
    
}

/**
 * setzt eine Adresse auf einen bestimmten Shortintegerwert
 * 
 * <p>Setzt die Adresse mit der ID <b>InstanzID</b> auf <b>Wert</b></p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/modbus-rtu-tcp/modbus-writeregistershortint/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param integer $Value -128 bis 127
 */
function ModBus_WriteRegisterShortInt(integer $InstanceID, integer $Value)
{
    
}

/**
 * setzt eine Adresse auf einen bestimmten Smallintegerwert
 * 
 * <p>Setzt die Adresse mit der ID <b>InstanzID</b> auf <b>Wert</b></p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/modbus-rtu-tcp/modbus-writeregistersmallint/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param integer $Value -32768 bis 32767
 */
function ModBus_WriteRegisterSmallInt(integer $InstanceID, integer $Value)
{
    
}

/**
 * setzt eine Adresse auf einen bestimmten unsigned Smallintegerwert
 * 
 * <p>Setzt die Adresse mit der ID <b>InstanzID</b> auf <b>Wert</b></p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/modbus-rtu-tcp/modbus-writeregisterword/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param integer $Value 0-65535
 */
function ModBus_WriteRegisterWord(integer $InstanceID, integer $Value)
{
    
}

/**
 * OW_GetKnownDevices
 * 
 * @returns array
 * @param integer $InstanceID
 */
function OW_GetKnownDevices(integer $InstanceID)
{
    
}

/**
 * OW_RequestStatus
 * 
 * @returns boolean
 * @param integer $InstanceID
 */
function OW_RequestStatus(integer $InstanceID)
{
    
}

/**
 * setzt einen Pin vom DS2450 auf an/aus
 * 
 * <p>Setzt den Zustand vom Pin <b>Pin</b> des Gerts mit der ID <b>InstanzID</b> auf Wert <b>Status</b></p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/1-wire/ds2450/ow-setpin/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param integer $Pin 0-3 (A-D)
 * @param boolean $SwitchOn 
 */
function OW_SetPin(integer $InstanceID, integer $Pin, boolean $SwitchOn)
{
    
}

/**
 * setzt den kompletten Port vom DS2408 auf Wert
 * 
 * <p>Setzt den Zustand von allen acht Pins auf den Wert von <b>Bitmaske</b> des Gerts mit der ID <b>InstanzID</b>.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/1-wire/ds2408/ow-setport/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param integer $Value 0-255 (Bit0 = Pin0  Bit7 = Pin7)
 */
function OW_SetPort(integer $InstanceID, integer $Value)
{
    
}

/**
 * setzt die Position vom DS2490 auf an/aus
 * 
 * <p>Setzt das Gert mit der ID <b>InstanzID</b> auf Wert <b>Wert</b></p><p>Bitte beachten Sie den CPC Parameter in der Konfiguration.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/1-wire/ds2890/ow-setposition/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param integer $Value 0-255
 */
function OW_SetPosition(integer $InstanceID, integer $Value)
{
    
}

/**
 * schaltet den Strobe vom DS2408 an/aus
 * 
 * <p>Ermglicht es, den RSTZ-Pin des DS2408 des Gerts mit der ID <b>InstanzID</b> auf Wert <b>Status</b> zu setzten</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/1-wire/ds2408/ow-setstrobe/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param boolean $Status 
 */
function OW_SetStrobe(integer $InstanceID, boolean $Status)
{
    
}

/**
 * setzt den Pin vom DS2405 auf an/aus
 * 
 * <p>Setzt den Zustand des Gerts mit der ID <b>InstanzID</b> auf Wert <b>Status</b></p><p>Da der Baustein kein definiertes Setzen untersttzt, funktioniert der Befehl auf dem Prinzip, den Eingang zu lesen und fr den Fall, dass Status &lt;&gt; Eingangsstatus ist, den Ausgang des Bausteins zu toggeln. Beim Design externer Schaltungen sollte dies unbedingt beachtet werden.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/1-wire/ds2405/ow-switchmode/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param boolean $SwitchOn 
 */
function OW_SwitchMode(integer $InstanceID, boolean $SwitchOn)
{
    
}

/**
 * toggelt den Pin vom DS2405
 * 
 * <p>Wechselt den Zustand des Gerts mit der ID <b>InstanzID</b>. Der aktuelle Wert kann nach dem Vorgang in der Status Variable abgefragt werden.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/1-wire/ds2405/ow-togglemode/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 */
function OW_ToggleMode(integer $InstanceID)
{
    
}

/**
 * sendet mehrere Bytes an den DS2408
 * 
 * <p>Setzt eine Abfolge von Bytes (<b>Daten</b>) ber alle Pins des Gerts mit der ID <b>InstanzID</b> ab.</p><p>Nur als Output definierte Pins werden beschrieben.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/1-wire/ds2408/ow-writebytes/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param string $Data Folge von Bytes, die versendet werden sollen
 */
function OW_WriteBytes(integer $InstanceID, string $Data)
{
    
}

/**
 * sendet mehrere Bytes an den DS2408 unter Bercksichtigung einer Bitmaske
 * 
 * <p>Setzt eine Abfolge von Bytes (<b>Daten</b>)unter Bercksichtung einer Bitmaske <b>Maske</b> ber alle Pins des Gerts mit der ID <b>InstanzID</b> ab.</p><p>Nur als Output definierte Pins werden beschrieben!</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/1-wire/ds2408/ow-writebytesmasked/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param string $Data Folge von Bytes, die versendet werden sollen
 * @param integer $Mask Bitmaske der Bit die gesetzt werden sollen
 */
function OW_WriteBytesMasked(integer $InstanceID, string $Data, integer $Mask)
{
    
}

/**
 * OZW_GetKnownDevices
 * 
 * @returns array
 * @param integer $InstanceID
 */
function OZW_GetKnownDevices(integer $InstanceID)
{
    
}

/**
 * OZW_GetKnownItems
 * 
 * @returns array
 * @param integer $InstanceID
 * @param integer $RootID
 */
function OZW_GetKnownItems(integer $InstanceID, integer $RootID)
{
    
}

/**
 * fragt den Status eines Gerts ab
 * 
 * <p>Fragt den Status des Gerts mit InstanzID <b>InstanzID</b> ab.</p><p>Setzt den Wert des Datenpunktes mit der ID <b>InstanzID</b> auf angegebenen Wert.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/siemens-ozw/ozw-requeststatus/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des abzufragenden Gerts
 */
function OZW_RequestStatus(integer $InstanceID)
{
    
}

/**
 * schreibt einen bestimmten Wert in einen Datenpunkt
 * 
 * <p>Setzt den Wert des Datenpunktes mit der ID <b>InstanzID</b> auf angegebenen Wert.</p><p>Sofern das angezeigte Profil ber Assoziationen verfgt, muss der Integer-Wert der gewnschten Assoziation angegeben werden (z.B. 0) anstatt des String-Wertes (z.B. Aus).</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/siemens-ozw/ozw-writedatapoint/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu verndernden Gerts
 * @param mixed $Value z.B. 23.5
 */
function OZW_WriteDataPoint(integer $InstanceID, mixed $Value)
{
    
}

/**
 * schaltet die Displaybeleuchtung An oder Aus
 * 
 * <p>Schaltet die Displaybeleuchtung im FD-868 mit der ID <b>InstanzID</b> an oder aus.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/ips-868/fd-868/pj-backlight/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param boolean $Status 
 */
function PJ_Backlight(integer $InstanceID, boolean $Status)
{
    
}

/**
 * gibt ein Tonsignal aus
 * 
 * <p>Gibt ein Tonsignal im FD-868 mit der ID <b>InstanzID</b> aus.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/ips-868/fd-868/pj-beep/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param integer $TenthOfASecond Lnge des Tones in 1/10 Sekunden
 */
function PJ_Beep(integer $InstanceID, integer $TenthOfASecond)
{
    
}

/**
 * dimmt einen LED Stripe
 * 
 * <p>Dimmt einen <b>RGB</b>-Farbwert mit der Helligkeit <b>W</b> mit individueller Zeitspanne in Sekunden an dem RGBW-868 Controller mit der ID <b>InstanzID</b>.</p><p>Der Wert fr die Zeit ist intern in zwei Bereiche unterteilt. Werden Zeiten ber 255 Sekunden angegeben, werden automatisch alle Zeiten, die kleiner als 255 waren auf 255 gesetzt. Dieser Bereich ist fr langsame Szenarien zum Aufwecken oder in Terrarien gedacht.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/ips-868/rgbw-868/pj-dimrgbw/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param integer $R Helligkeitswert 0 (aus) bis 255 (an, maximale Helligkeit)
 * @param integer $RTime In Sekunden in die der gewnschte Helligkeitswert erreicht werden soll: 0 (sofort) bis 2550 Sekunden (42,5 Minuten)
 * @param integer $G Helligkeitswert 0 (aus) bis 255 (an, maximale Helligkeit)
 * @param integer $GTime In Sekunden in die der gewnschte Helligkeitswert erreicht werden soll: 0 (sofort) bis 2550 Sekunden (42,5 Minuten)
 * @param integer $B Helligkeitswert 0 (aus) bis 255 (an, maximale Helligkeit)
 * @param integer $BTime In Sekunden in die der gewnschte Helligkeitswert erreicht werden soll: 0 (sofort) bis 2550 Sekunden (42,5 Minuten)
 * @param integer $W Helligkeitswert 0 (aus) bis 255 (an, maximale Helligkeit)
 * @param integer $WTime In Sekunden in die der gewnschte Helligkeitswert erreicht werden soll: 0 (sofort) bis 2550 Sekunden (42,5 Minuten)
 */
function PJ_DimRGBW(integer $InstanceID, integer $R, integer $RTime, integer $G, integer $GTime, integer $B, integer $BTime, integer $W, integer $WTime)
{
    
}

/**
 * setzt Schrittweise einen Servo-Wert
 * 
 * <p>Setzt einen Servo-Kanal <b>Kanal</b> an dem Controller mit der ID <b>InstanzID</b> auf den Wert <b>Wert</b> in der Geschwindigkeit <b>Schritte</b>.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/ips-868/servo-868/pj-dimservo/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param integer $Channel Servo-Kanal 1..4
 * @param integer $Value Wert von 0..255
 * @param integer $Steps Schritte von 0 (sofort) ber 1 (langsam) bis 255 (schnell)
 */
function PJ_DimServo(integer $InstanceID, integer $Channel, integer $Value, integer $Steps)
{
    
}

/**
 * sendet einen Text an das Display
 * 
 * <p>Sendet einen Text an das FD-868 der ID <b>InstanzID</b>.</p><p>Da das Komma als Steuerzeichen verwendet wird, darf es im Text nicht vorkommen.Der o.g. Befehl ersetzt es automatisch in einen Punkt.Sonderzeichen wie z.B.  drfen nicht vorkommen.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/ips-868/fd-868/pj-lcdtext/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param integer $Line Zeilennummer des Display (1 oder 2)
 * @param string $Text Zeilentext, maximal 16 Zeichen  der Rest wird abgeschnitten
 */
function PJ_LCDText(integer $InstanceID, integer $Line, string $Text)
{
    
}

/**
 * fragt die aktuellen Werte ab
 * 
 * <p>Fragt die aktuellen Werte fr das Gert mit der ID <b>InstanzID</b> ab und schreibt diese in die entsprechenden Status-Variablen.</p><p><b>Diese Funktion belastet den Funkverkehr erheblich.</b>Sie sollte ausschlielich verwendet werden, wenn der interne Timer nicht eingesetzt werden soll, um ungleichmige Intervalle zu realisieren. Eine stndige Abfrage der Werte blockiert ggf. den Funkverkehr anderer Teilnehmer.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/ips-868/ekm-868/pj-requeststatus/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des Gerts
 */
function PJ_RequestStatus(integer $InstanceID)
{
    
}

/**
 * startet ein Lichtprogramm
 * 
 * <p>Startet ein Lichtprogramm <b>Programm</b> an dem RGBW-868 Controller mit der ID <b>InstanzID</b>.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/ips-868/rgbw-868/pj-runprogram/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param integer $Type 0  alle RGBW auf Aus; 1  alle RGBW auf den letzten Helligkeits-Wert; 2-  Blinken langsam; 3-  Blinken schnell; 4-  Blitzen (Flash) langsam; 5-  Blitzen (Flash) schnell; 6-  An- u. Abschwellen (Fade)  langsam
 */
function PJ_RunProgram(integer $InstanceID, integer $Type)
{
    
}

/**
 * schaltet LEDs am LuftGteSensor
 * 
 * <p>Schaltet die LEDs an dem Controller mit der ID <b>InstanzID</b>.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/ips-868/lgs-868/pj-setleds/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param boolean $Green Schaltet die grne LED
 * @param boolean $Yellow Schaltet die gelbe LED
 * @param boolean $Red Schaltet die rote LED
 */
function PJ_SetLEDs(integer $InstanceID, boolean $Green, boolean $Yellow, boolean $Red)
{
    
}

/**
 * setzt einen Farbwert
 * 
 * <p>Setzt einen <b>RGB</b>-Farbwert mit der Helligkeit <b>W</b> an dem Controller mit der ID <b>InstanzID</b>.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/ips-868/rgbw-868/pj-setrgbw/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param integer $R Helligkeitswert 0 (aus) bis 255 (an, maximale Helligkeit)
 * @param integer $G Helligkeitswert 0 (aus) bis 255 (an, maximale Helligkeit)
 * @param integer $B Helligkeitswert 0 (aus) bis 255 (an, maximale Helligkeit)
 * @param integer $W Gesamthelligkeitswert 0 (aus) bis 255 (an, maximale Helligkeit)
 */
function PJ_SetRGBW(integer $InstanceID, integer $R, integer $G, integer $B, integer $W)
{
    
}

/**
 * setzt einen Servo Kanal
 * 
 * <p>Setzt einen Servo-Kanal <b>Kanal</b> an dem Controller mit der ID <b>InstanzID</b> auf den <b>Wert</b>.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/ips-868/servo-868/pj-setservo/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param integer $Channel Servo-Kanal 1..4
 * @param integer $Value Wert von 0..255
 */
function PJ_SetServo(integer $InstanceID, integer $Channel, integer $Value)
{
    
}

/**
 * schaltet ein Relais
 * 
 * <p>Schaltet das Relais vom WDT mit der ID <b>InstanzID</b> auf Wert <b>Status</b> fr <b>Dauer</b> Sekunden</p><p>Das IP-Symcon 868 Funksystem ist bidirektional. Dadurch sendet der WDT den neuen Status des Relais nach Ablauf des Timer.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/ips-868/wdt-868/pj-switchduration/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param boolean $DeviceOn 
 * @param integer $Duration Ein- oder Ausschaltdauer in Sekunden
 */
function PJ_SwitchDuration(integer $InstanceID, boolean $DeviceOn, integer $Duration)
{
    
}

/**
 * schaltet einen LED vom Display
 * 
 * <p>Schaltet eine Leuchtdiode vom FD-868 mit der ID <b>InstanzID</b> ein oder aus.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/ips-868/fd-868/pj-switchled/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param integer $LED 1: Rot, 2: Gelb, 3 Grn
 * @param boolean $Status True = Ein / False = Aus
 */
function PJ_SwitchLED(integer $InstanceID, integer $LED, boolean $Status)
{
    
}

/**
 * sendet einen Schaltbefehl
 * 
 * <p>Schaltet das Gert mit der ID <b>InstanzID</b> auf Wert Status.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/ips-868/wdt-868/pj-switchmode/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param boolean $DeviceOn 
 */
function PJ_SwitchMode(integer $InstanceID, boolean $DeviceOn)
{
    
}

/**
 * gibt ein Array zu den gecachten E-Mails zurck
 * 
 * <p>Der Befehl gibt ein Array mit Informationen ber die gecacheten E-Mails einer POP3-Instanz mit der ID <b>InstanzID</b> zurck. Sollte die Instanz nicht existieren, wird eine Warnung generiert.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/pop3/pop3-getcachedmails/
 * @returns array <p>Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis ein Array mit Daten zu den gecacheten E-Mails, andernfalls ein Boolean mit dem Wert <b>FALSE</b>.</p>
 * @param integer $InstanceID ID der POP3-Instanz
 */
function POP3_GetCachedMails(integer $InstanceID)
{
    
}

/**
 * liefert ein Array mit Informationen zu einer bestimmten E-Mail(UID) wieder
 * 
 * <p>Der Befehl ldt eine E-Mail mit der UID <b>UID</b> ber die POP3-Instanz mit der ID <b>InstanzID</b> und gibt ein Array mit den Daten der E-Mail zurck. Sollte die Instanz oder eine E-Mail mit der bergebenen UID nicht existieren, wird eine Warnung generiert.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/pop3/pop3-getmailex/
 * @returns array <p>Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis ein Array mit den Daten der E-Mail, andernfalls ein Boolean mit <b>FALSE</b>.</p>
 * @param integer $InstanceID ID der POP3-Instanz
 * @param string $UID UID der zu ladenden E-Mail
 */
function POP3_GetMailEx(integer $InstanceID, string $UID)
{
    
}

/**
 * POP3_UpdateCache
 * 
 * @returns boolean
 * @param integer $InstanceID
 */
function POP3_UpdateCache(integer $InstanceID)
{
    
}

/**
 * liest den internen Puffer
 * 
 * <p>Liest den internen Puffer der Instanz mit ID <b>InstanzID</b>.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/registervariable/regvar-getbuffer/
 * @returns string <p>String des aktuellen Puffers</p>
 * @param integer $InstanceID ID des zu schaltenden Gerts
 */
function RegVar_GetBuffer(integer $InstanceID)
{
    
}

/**
 * sendet Daten an die bergeordnete Instanz
 * 
 * <p>Sendet einen String <b>Text</b> ber die Instanz mit der ID <b>InstanzID</b></p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/registervariable/regvar-sendtext/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param string $Text Zu sendender Puffer
 */
function RegVar_SendText(integer $InstanceID, string $Text)
{
    
}

/**
 * setzt den internen Puffer
 * 
 * <p>Setzt den internen Puffer der Instanz mit ID <b>InstanzID</b> auf Wert <b>Puffer</b></p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/registervariable/regvar-setbuffer/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param string $Text Daten, die in den Puffer geschrieben werden sollen
 */
function RegVar_SetBuffer(integer $InstanceID, string $Text)
{
    
}

/**
 * fhrt einen Lesevorgang auf einem Gert aus
 * 
 * <p>Fhrt einen erneuten Lesevorgang fr das Gert mit der ID <b>InstanzID</b> aus.</p><p>Sobald die Funktion ausgefhrt wurde, sind die neuen Werte in den Status Variablen abrufbar.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/sps-siemens-vipa-logo/s7-requestread/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 */
function S7_RequestRead(integer $InstanceID)
{
    
}

/**
 * S7_Write
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param float $Value
 */
function S7_Write(integer $InstanceID, float $Value)
{
    
}

/**
 * setzt eine Adresse auf An/Aus
 * 
 * <p>Setzt die Adresse mit der ID InstanzID auf Wert Status</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/sps-siemens-vipa-logo/s7-writebit/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param boolean $Value 
 */
function S7_WriteBit(integer $InstanceID, boolean $Value)
{
    
}

/**
 * setzt eine Adresse auf einen bestimmten Bytewert
 * 
 * <p>Setzt die Adresse mit der ID InstanzID auf Wert</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/sps-siemens-vipa-logo/s7-writebyte/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param integer $Value 0-255
 */
function S7_WriteByte(integer $InstanceID, integer $Value)
{
    
}

/**
 * setzt eine Adresse auf einen bestimmten unsigned Integerwert
 * 
 * <p>Setzt die Adresse mit der ID <b>InstanzID</b> auf <b>Wert</b></p><p>Aufgrund von einer Beschrnkung auf 32-Bit Integer innerhalb von PHP kann nur der Bereich bis 2147483647 genutzt werden.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/sps-siemens-vipa-logo/s7-writedword/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param integer $Value 0-4294967295
 */
function S7_WriteDWord(integer $InstanceID, integer $Value)
{
    
}

/**
 * setzt eine Adresse auf einen bestimmten Integerwert
 * 
 * <p>Setzt die Adresse mit der ID InstanzID auf Wert</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/sps-siemens-vipa-logo/s7-writeinteger/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param integer $Value -2147483648 bis 2147483647
 */
function S7_WriteInteger(integer $InstanceID, integer $Value)
{
    
}

/**
 * setzt eine Adresse auf einen bestimmten Floatwert
 * 
 * <p>Setzt die Adresse mit der ID InstanzID auf Wert</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/sps-siemens-vipa-logo/s7-writereal/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param float $Value 64Bit Gleitkommawert nach IEEE754
 */
function S7_WriteReal(integer $InstanceID, float $Value)
{
    
}

/**
 * setzt eine Adresse auf einen bestimmten Shortintegerwert
 * 
 * <p>Setzt die Adresse mit der ID InstanzID auf Wert</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/sps-siemens-vipa-logo/s7-writeshortint/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param integer $Value -128 bis 127
 */
function S7_WriteShortInt(integer $InstanceID, integer $Value)
{
    
}

/**
 * setzt eine Adresse auf einen bestimmten Smallintegerwert
 * 
 * <p>Setzt die Adresse mit der ID InstanzID auf Wert</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/sps-siemens-vipa-logo/s7-writesmallint/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param integer $Value -32768 bis 32767
 */
function S7_WriteSmallInt(integer $InstanceID, integer $Value)
{
    
}

/**
 * setzt eine Adresse auf einen bestimmten unsigned Smallintegerwert
 * 
 * <p>Setzt die Adresse mit der ID InstanzID auf Wert</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/sps-siemens-vipa-logo/s7-writeword/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param integer $Value 0-65535
 */
function S7_WriteWord(integer $InstanceID, integer $Value)
{
    
}

/**
 * SC_CreateSkin
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param string $SkinURL
 */
function SC_CreateSkin(integer $InstanceID, string $SkinURL)
{
    
}

/**
 * SC_DeleteSkin
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param string $Skin
 */
function SC_DeleteSkin(integer $InstanceID, string $Skin)
{
    
}

/**
 * SC_GetSkin
 * 
 * @returns array
 * @param integer $InstanceID
 * @param string $Skin
 */
function SC_GetSkin(integer $InstanceID, string $Skin)
{
    
}

/**
 * SC_GetSkinIconContent
 * 
 * @returns string
 * @param integer $InstanceID
 * @param string $Skin
 * @param string $Icon
 */
function SC_GetSkinIconContent(integer $InstanceID, string $Skin, string $Icon)
{
    
}

/**
 * SC_GetSkinList
 * 
 * @returns array
 * @param integer $InstanceID
 */
function SC_GetSkinList(integer $InstanceID)
{
    
}

/**
 * SC_GetSkinRepositoryInfo
 * 
 * @returns array
 * @param integer $InstanceID
 * @param string $Skin
 */
function SC_GetSkinRepositoryInfo(integer $InstanceID, string $Skin)
{
    
}

/**
 * bewegt den Rolladen an eine bestimmte Position
 * 
 * <p>Bewegt den Rolladen fr das Gert mit der ID <b>InstanzID</b> auf die <b>Position</b>.</p><p>Da einige Funk-Systeme unidirektonal sind, kann nicht festgestellt werden, ob ein Befehl erfolgreich war. Dadurch kann die genaue Positionierung nicht garantiert werden.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/shutter-control/sc-move/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID der Shutter Control Instanz
 * @param integer $Position 0%-100%, 99% = Auf Spalt fahren
 */
function SC_Move(integer $InstanceID, integer $Position)
{
    
}

/**
 * bewegt den Rolladen bis zu Endposition runter
 * 
 * <p>Bewegt den Rolladen fr das Gert mit der ID <b>InstanzID</b> fr <b>Dauer</b> Millisekunden nach unten.</p><p>Die Statusvariable wird unabhngig von der gefahrenen Zeit auf 100 zurckgesetzt.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/shutter-control/sc-movedown/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID der Shutter Control Instanz
 * @param integer $Duration 0 = Endlagenschalter, &gt;1 = Dauer in ms
 */
function SC_MoveDown(integer $InstanceID, integer $Duration)
{
    
}

/**
 * bewegt den Rolladen bis zu Endposition hoch
 * 
 * <p>Bewegt den Rolladen fr das Gert mit der ID <b>InstanzID</b> fr <b>Dauer</b> Millisekunden nach oben.</p><p>Die Statusvariable wird unabhngig von der gefahrenen Zeit auf 0 zurckgesetzt.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/shutter-control/sc-moveup/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID der Shutter Control Instanz
 * @param integer $Duration 0 = Endlagenschalter, &gt;1 = Dauer in ms
 */
function SC_MoveUp(integer $InstanceID, integer $Duration)
{
    
}

/**
 * stoppt einen Bewegungsvorgang
 * 
 * <p>Stoppt einen Bewegungsvorgang fr das Gert mit der ID <b>InstanzID</b>.</p><p>Die Statusvariable wird auf -1 zurckgesetzt.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/shutter-control/sc-stop/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID der Shutter Control Instanz
 */
function SC_Stop(integer $InstanceID)
{
    
}

/**
 * SC_UpdateSkin
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param string $Skin
 */
function SC_UpdateSkin(integer $InstanceID, string $Skin)
{
    
}

/**
 * SMS_RequestBalance
 * 
 * @returns float
 * @param integer $InstanceID
 */
function SMS_RequestBalance(integer $InstanceID)
{
    
}

/**
 * SMS_RequestStatus
 * 
 * @returns string
 * @param integer $InstanceID
 * @param string $MsgID
 */
function SMS_RequestStatus(integer $InstanceID, string $MsgID)
{
    
}

/**
 * versendet eine E-Mail an die Standardadresse
 * 
 * <p>Sendet ber die Instanz mit der ID <b>InstanzID</b> eine SMS mit dem Text an Nummer.</p><p>Es wird die Absendernummer genutzt, die in der Eigenschaftenseite angegeben wurde.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/sms/sms-send/
 * @returns string Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param string $Number Mobilfunknummer des Empfngers
 * @param string $Text Text der SMS (max. 160 Zeichen)
 */
function SMS_Send(integer $InstanceID, string $Number, string $Text)
{
    
}

/**
 * versendet eine E-Mail an die Standardadresse
 * 
 * <p>Sendet ber die Instanz mit der ID <b>InstanzID</b> eine E-Mail mit dem Betreff und Text.</p><p>Es wird der Empfnger genutzt, der in der Eigenschaftenseite angegeben wurde. Wenn unterschiedliche Empfnger addressiert werden sollen, nutzen Sie bitte die SMTP_SendMailEx Funktion.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/smtp/smtp-sendmail/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID der SMTP Instanz
 * @param string $Subject Betreff der E-Mail
 * @param string $Textg Text der E-Mail
 */
function SMTP_SendMail(integer $InstanceID, string $Subject, string $Textg)
{
    
}

/**
 * versendet eine E-Mail mit Anhang an die Standardadresse
 * 
 * <p>Sendet ber die Instanz mit der ID <b>InstanzID</b> eine E-Mail mit dem Betreff, Anhang und Text.</p><p>Es wird der Empfnger genutzt, der in der Eigenschaftenseite angegeben wurde. Wenn unterschiedliche Empfnger addressiert werden sollen, nutzen Sie bitte die SMTP_SendMailAttachmentEx Funktion.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/smtp/smtp-sendmailattachment/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID der SMTP Instanz
 * @param string $Subject Betreff der E-Mail
 * @param string $Text Text der E-Mail
 * @param string $Filename Pfad zur Datei
 */
function SMTP_SendMailAttachment(integer $InstanceID, string $Subject, string $Text, string $Filename)
{
    
}

/**
 * versendet eine E-Mail mit Anhang an eine beliebige Adresse
 * 
 * <p>Sendet ber die Instanz mit der ID <b>InstanzID</b> eine E-Mail mit dem Betreff, Anhang und Text an Empfnger. Im Gegensatz zur SMTP_SendMail Funktion kann hier der Empfnger explizit im Funktionsaufruf angegeben werden.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/smtp/smtp-sendmailattachmentex/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID der SMTP Instanz
 * @param string $Address E-Mail Adresse des Empfngers
 * @param string $Subject Betreff der E-Mail
 * @param string $Text Text der E-Mail
 * @param string $Filename Pfad zur Datei
 */
function SMTP_SendMailAttachmentEx(integer $InstanceID, string $Address, string $Subject, string $Text, string $Filename)
{
    
}

/**
 * versendet eine E-Mail an eine beliebige Adresse
 * 
 * <p>Sendet ber die Instanz mit der ID <b>InstanzID</b> eine E-Mail mit dem Betreff und Text an Empfnger. Im Gegensatz zur SMTP_SendMail Funktion kann hier der Empfnger explizit im Funktionsaufruf angegeben werden.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/smtp/smtp-sendmailex/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID der SMTP Instanz
 * @param string $Address E-Mail Adresse des Empfngers
 * @param string $Subject Betreff der E-Mail
 * @param string $Text Text der E-Mail
 */
function SMTP_SendMailEx(integer $InstanceID, string $Address, string $Subject, string $Text)
{
    
}

/**
 * versendet eine E-Mail mit Anhang eines Medienobjekts vom Typ "Bild/Ton" an die Standardadresse
 * 
 * <p>Sendet ber die Instanz mit der ID <b>InstanzID</b> eine E-Mail mit dem Betreff, Medienobjekt und Text.</p><p>Es wird der Empfnger genutzt, der in der Eigenschaftenseite angegeben wurde. Wenn unterschiedliche Empfnger addressiert werden sollen, nutzen Sie bitte die SMTP_SendMailMediaEx Funktion.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/smtp/smtp-sendmailmedia/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID der SMTP Instanz
 * @param string $Subject Betreff der E-Mail
 * @param string $Text Text der E-Mail
 * @param integer $MediaID ID des Medienobjekts (nur Bild/Ton)
 */
function SMTP_SendMailMedia(integer $InstanceID, string $Subject, string $Text, integer $MediaID)
{
    
}

/**
 * versendet eine E-Mail mit Anhang eines Medienobjekts vom Typ "Bild/Ton" an eine beliebige Adresse
 * 
 * <p>Sendet ber die Instanz mit der ID <b>InstanzID</b> eine E-Mail mit dem Betreff, Medienobjekt und Text an Empfnger. Im Gegensatz zur SMTP_SendMailMedia Funktion kann hier der Empfnger explizit im Funktionsaufruf angegeben werden.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/smtp/smtp-sendmailmediaex/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID der SMTP Instanz
 * @param string $Address E-Mail Adresse des Empfngers
 * @param string $Subject Betreff der E-Mail
 * @param string $Text Text der E-Mail
 * @param integer $MediaID ID des Medienobjekts (nur Bild/Ton)
 */
function SMTP_SendMailMediaEx(integer $InstanceID, string $Address, string $Subject, string $Text, integer $MediaID)
{
    
}

/**
 * sendet einen String auf den I/O
 * 
 * <p>Sendet den String <b>Text</b> auf dem Serial Port mit der ID <b>InstanzID</b>.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/io/serialport/sprt-sendtext/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu aktualisierenden WWW Readers
 * @param string $Text der zusendene String
 */
function SPRT_SendText(integer $InstanceID, string $Text)
{
    
}

/**
 * schaltet den Break eines Serial Ports
 * 
 * <p>Schaltet die Break auf <b>AnAus</b> auf dem Serial Port mit der ID <b>InstanzID</b>.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/io/serialport/sprt-setbreak/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu aktualisierenden Serial Ports
 * @param boolean $OnOff schaltet den Break An
 */
function SPRT_SetBreak(integer $InstanceID, boolean $OnOff)
{
    
}

/**
 * schaltet den Break eines Serial Ports
 * 
 * <p>Schaltet den DTR auf <b>AnAus</b> auf dem Serial Port mit der ID <b>InstanzID</b>.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/io/serialport/sprt-setdtr/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu aktualisierenden Serial Ports
 * @param boolean $OnOff schaltet den DTR An
 */
function SPRT_SetDTR(integer $InstanceID, boolean $OnOff)
{
    
}

/**
 * schaltet den Break eines Serial Ports
 * 
 * <p>Schaltet den RTS auf <b>AnAus</b> auf dem Serial Port mit der ID <b>InstanzID</b>.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/io/serialport/sprt-setrts/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu aktualisierenden Serial Ports
 * @param boolean $OnOff schaltet den RTS An
 */
function SPRT_SetRTS(integer $InstanceID, boolean $OnOff)
{
    
}

/**
 * sendet einen String auf den I/O
 * 
 * <p>Sendet den String <b>Text</b> auf dem Server Socket mit der ID <b>InstanzID</b>.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/io/serversocket/ssck-sendtext/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu aktualisierenden Server Sockets
 * @param string $Text der zusendene String
 */
function SSCK_SendText(integer $InstanceID, string $Text)
{
    
}

/**
 * setzt den Wert einer IP-Symcon Variable unabhngig des Typs
 * 
 * <p>Der Befehl schreibt den Inhalt einer internen Variablen mit dem Wert <b>Wert</b> in die Externe Variable mit der ID <b>VariablenID</b>. Es ist darauf zu achten, dass der Typ von VariablenWert zum Typ der Zielvariablen passt. Ist die Zielvariable vom Typ String, so sollte auch Wert vom Typ String sein.</p><p>Falls Quell- und Zieltyp nicht bereinstimmen, versucht PHP eine geeignete Konvertierung vorzunehmen. Das Ergebnis dieser Konvertierung kann aber vom erwarteten Ergebnis abweichen. Es ist daher besser von vornherein den richtigen Typ zu bergeben.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/variablenzugriff/SetValue/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $VariableID ID der Variable
 * @param mixed $Value Neuer Wert der Variable
 */
function SetValue(integer $VariableID, mixed $Value)
{
    
}

/**
 * setzt den Wert einer IP-Symcon Variable vom Typ Boolean
 * 
 * <p>Der Befehl setzt den Inhalt der externen Variablen mit der ID <b>VariablenID</b>. Die gewhlte Variable muss vom Typ Boolean sein. Wenn nicht, bricht die Funktion mit einem Fehler ab. Eine Konvertierung wird nicht vorgenommen.  Fr ein typunsicheres Setzen der Variable knnen Sie die SetValue Funktion nutzen.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/variablenzugriff/setvalueboolean/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $VariableID ID der Variable
 * @param boolean $Value TRUE/FALSE
 */
function SetValueBoolean(integer $VariableID, boolean $Value)
{
    
}

/**
 * setzt den Wert einer IP-Symcon Variable vom Typ Float
 * 
 * <p>Der Befehl setzt den Inhalt der externen Variablen mit der ID <b>VariablenID</b>. Die gewhlte Variable muss vom Typ Float sein. Wenn nicht, bricht die Funktion mit einem Fehler ab. Eine Konvertierung von Integer/Boolean (0/1) wird vorgenommen. Fr ein typunsicheres Setzten der Variable knnen Sie die SetValue Funktion nutzen.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/variablenzugriff/setvaluefloat/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $VariableID ID der Variable
 * @param float $Value 64Bit Gleitkommazahl
 */
function SetValueFloat(integer $VariableID, float $Value)
{
    
}

/**
 * setzt den Wert einer IP-Symcon Variable vom Typ Integer
 * 
 * <p>Der Befehl setzt den Inhalt der Externen Variablen mit der ID <b>VariablenID</b>. Die gewhlte Variable muss vom Typ Integer sein. Wenn nicht, bricht die Funktion mit einem Fehler ab. Eine Konvertierung von Float (Trunc)/Boolean (0/1) wird vorgenommen. Fr ein typunsicheres Setzten der Variable knnen Sie die SetValue Funktion nutzen.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/variablenzugriff/setvalueinteger/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $VariableID ID der Variable
 * @param integer $Value -2,147,483,648 .. 2,147,483,647
 */
function SetValueInteger(integer $VariableID, integer $Value)
{
    
}

/**
 * setzt den Wert einer IP-Symcon Variable vom Typ String
 * 
 * <p>Der Befehl setzt den Inhalt der externen Variablen mit der ID <b>VariablenID</b>. Die gewhlte Variable muss vom Typ String sein. Wenn nicht, bricht die Funktion mit einem Fehler ab. Eine Konvertierung von Float/Integer/Boolean (False/True) wird vorgenommen. Fr ein typunsicheres Setzten der Variable knnen Sie die SetValue Funktion nutzen.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/befehlsreferenz/variablenzugriff/setvaluestring/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $VariableID ID der Variable
 * @param string $Value Text
 */
function SetValueString(integer $VariableID, string $Value)
{
    
}

/**
 * StrRecv_SendText
 * 
 * @returns mixed
 * @param integer $InstanceID
 * @param string $String
 */
function StrRecv_SendText(integer $InstanceID, string $String)
{
    
}

/**
 * zeigt Informationen zur Batterie an
 * 
 * <p>Gibt Informationen ber das Vorhandensein einer Batterie, ob sie in Gebrauch ist und wieviel Prozent der Batterie noch vorhanden sind. Die Angaben der Restlaufzeit und maximalen Batterielaufzeit werden in Sekunden angegeben.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/system-informationen/sys-getbattery/
 * @returns array <p>Array mit Informationen zur Batterie</p>
 */
function Sys_GetBattery()
{
    
}

/**
 * zeigt die CPU Auslastung an
 * 
 * <p><b>Ab Version 4.0</b><br>Liefert fr jede CPU die aktuelle Last (CPU_*) und die momentane Durchschnittlast fr alle CPU Kerne (CPU_AVG).</p><p><b>Bis Version 3.4</b><br>Liefert fr jede CPU die aktuelle Last (CPU_*) und die Durchschnittlast der letzten 60 Sekunden fr alle CPU Kerne (CPU_AVG). Die durchschnittliche Last wird berechnet, indem jeder Sekunde ein Messwert der aktuellen Last genommen und abgespeichert wird. Die durchschnittliche Last wird berechnet, indem die letzten 60 Messwerte addiert und durch 60 geteilt werden.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/system-informationen/sys-getcpuinfo/
 * @returns array <p>Array mit Informationen zur CPU-Auslastung</p>
 */
function Sys_GetCPUInfo()
{
    
}

/**
 * zeigt den Festplattenspeicherplatz/-verbrauch an
 * 
 * <p>Liefert Informationen zu den vorhandenen Festplatten im System inklusive der Gre und dem bereits verbrauchten Speicher.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/system-informationen/sys-getharddiskinfo/
 * @returns array <p>Array mit Informationen zu allen Festplatten</p>
 */
function Sys_GetHardDiskInfo()
{
    
}

/**
 * zeigt den Speicherverbrauch an
 * 
 * <p>Gibt Informationen zum Speicherverbrauch des Betriebssystems.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/system-informationen/sys-getmemoryinfo/
 * @returns array <p>Array mit Informationen zum Gesamtspeicherverbrauch und virtuellen Speicherverbrauch</p>
 */
function Sys_GetMemoryInfo()
{
    
}

/**
 * zeigt Informationen zu den Netzwerkadaptern
 * 
 * <p>Liefert Informationen ber alle Netzwerkadapter</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/system-informationen/sys-getnetworkinfo/
 * @returns array <p>Array mit Informationen zu allen Netzwerkadaptern</p>
 */
function Sys_GetNetworkInfo()
{
    
}

/**
 * listet alle Prozesse auf
 * 
 * <p>Gibt Informationen zum Prozess von IP-Symcon.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/system-informationen/sys-getprocessinfo/
 * @returns array <p>Array mit Informationen, wie z.B. Speicherverbrauch und Anzahl der Threads</p>
 */
function Sys_GetProcessInfo()
{
    
}

/**
 * zeigt Informationen zu den Druckerwarteschlangen an
 * 
 * <p>Gibt Informationen ber alle Druckerwarteschlangen aus</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/system-informationen/sys-getspooler/
 * @returns array <p>Array mit Informationen zu allen Druckerwarteschlagen und den im Druck befindlichen Dokumenten</p>
 */
function Sys_GetSpooler()
{
    
}

/**
 * liest den Inhalt einer URL als String aus
 * 
 * <p>Liest den Inhalt der <b>URL</b> aus und gibt ihn als Rckgabewert zurck.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/system-informationen/sys-geturlcontent/
 * @returns string <p>Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis den Inhalt der Webseite (auch Binrcode), andernfalls <b>FALSE</b>.</p>
 * @param string $URL Vollstndige URL
 */
function Sys_GetURLContent(string $URL)
{
    
}

/**
 * liest den Inhalt einer URL als String aus und bietet die Mglichkeit einen Proxy zu spezifizieren
 * 
 * <p>Liest den Inhalt der <b>URL</b> aus und gibt ihn als Rckgabewert zurck. Dabei knnen einige <b>Parameter</b> fr Timeouts, Authentifizierung und Proxy vorgenommen werden.</p><p>Die Proxy Parameter knnen nur bis Version 3.4 verwendet werden</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/system-informationen/sys-geturlcontentex/
 * @returns string <p>Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis den Inhalt der Webseite (auch Binrcode), andernfalls <b>FALSE</b>.</p>
 * @param string $URL Vollstndige URL
 * @param array $Options 
 */
function Sys_GetURLContentEx(string $URL, array $Options)
{
    
}

/**
 * sendet einen Ping an ein Netzwerkgert
 * 
 * <p>Sendet einen Ping an <b>Host</b> und wartet <b>Timeout</b> Millisekunden.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/system-informationen/sys-ping/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param string $Host Rechnername oder IP-Adresse
 * @param integer $Timeout Zeit in Millisekunden
 */
function Sys_Ping(string $Host, integer $Timeout)
{
    
}

/**
 * generiert eine WAV Datei mit dem gewnschten Text
 * 
 * <p>Generiert ber das Text-To-Speech Modul mit der ID <b>InstanzID</b> eine Sounddatei im Wav-Format in die Datei <b>Dateiname</b>. Der Format Parameter bestimmt die Qualitt der Wav Datei.</p><p><em>Warning: % wurde nicht gefunden in [...] on line </em><br>Sollte o.g. Fehlermeldung erscheinen, deutet es auf ein Zugriffsproblem hin. Wahrscheinlich wird die zu beschreibende Datei von einem anderen Prozess blockiert.<br>Desweiteren ist es nicht mglich auf <b>Netzwerkpfade</b> zu schreiben.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/text-to-speech/tts-generatefile/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des Text-To-Speech Moduls
 * @param string $Text Zu sagender Text
 * @param string $Filename Dateiname/-pfad im System
 * @param integer $Format 
 */
function TTS_GenerateFile(integer $InstanceID, string $Text, string $Filename, integer $Format)
{
    
}

/**
 * spricht einen beliebigen Text auf der gewhlten Soundkarte
 * 
 * <p>Spricht ber das Text-To-Speech Modul mit der ID <b>InstanzID</b> den in <b>Text</b> angegeben Text. Der <b>Warten</b> Parameter gibt an, ob gewartet werden soll, bis die Sprachausgabe beendet wurde.</p><p>Diese Funktion funktioniert nicht unter Windows <b>Vista/2003</b> oder neuer. Das Problem macht sich mit der Fehlermeldung: <b>OLE error 80045063</b><br>Auszug MSDN: SPERR_NOT_ACTIVE_SESSION bemerkbar.</p><p>Als <em>Ersatz</em> sollte die Funktion TTS_GenerateFile im Zusammenhang mit dem Media Player genutzt werden.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/text-to-speech/tts-speak/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des Text-To-Speech Moduls
 * @param string $Text Zu sagender Text
 * @param boolean $Wait 
 */
function TTS_Speak(integer $InstanceID, string $Text, boolean $Wait)
{
    
}

/**
 * UC_FindInFiles
 * 
 * @returns array
 * @param integer $InstanceID
 * @param array $Files
 * @param string $SearchStr
 */
function UC_FindInFiles(integer $InstanceID, array $Files, string $SearchStr)
{
    
}

/**
 * UC_RenameScript
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param integer $ScriptID
 * @param string $Filename
 */
function UC_RenameScript(integer $InstanceID, integer $ScriptID, string $Filename)
{
    
}

/**
 * UC_ReplaceInFiles
 * 
 * @returns array
 * @param integer $InstanceID
 * @param array $Files
 * @param string $SearchStr
 * @param string $ReplaceStr
 */
function UC_ReplaceInFiles(integer $InstanceID, array $Files, string $SearchStr, string $ReplaceStr)
{
    
}

/**
 * sendet einen String auf den I/O
 * 
 * <p>Sendet den String <b>Text</b> auf dem UDP Socket mit der ID <b>InstanzID</b>.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/io/udpsocket/usck-sendtext/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu aktualisierenden UDP Sockets
 * @param string $Text der zusendene String
 */
function USCK_SendText(integer $InstanceID, string $Text)
{
    
}

/**
 * UVR_UpdateValues
 * 
 * @returns boolean
 * @param integer $InstanceID
 */
function UVR_UpdateValues(integer $InstanceID)
{
    
}

/**
 * VELLEUSB_ReadAnalogChannel
 * 
 * @returns integer
 * @param integer $InstanceID
 * @param integer $Channel
 */
function VELLEUSB_ReadAnalogChannel(integer $InstanceID, integer $Channel)
{
    
}

/**
 * VELLEUSB_ReadCounter
 * 
 * @returns integer
 * @param integer $InstanceID
 * @param integer $Counter
 */
function VELLEUSB_ReadCounter(integer $InstanceID, integer $Counter)
{
    
}

/**
 * VELLEUSB_ReadDigital
 * 
 * @returns integer
 * @param integer $InstanceID
 */
function VELLEUSB_ReadDigital(integer $InstanceID)
{
    
}

/**
 * VELLEUSB_ReadDigitalChannel
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param integer $Channel
 */
function VELLEUSB_ReadDigitalChannel(integer $InstanceID, integer $Channel)
{
    
}

/**
 * VELLEUSB_ResetCounter
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param integer $Counter
 */
function VELLEUSB_ResetCounter(integer $InstanceID, integer $Counter)
{
    
}

/**
 * VELLEUSB_SetCounterDebounceTime
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param integer $Counter
 * @param integer $Time
 */
function VELLEUSB_SetCounterDebounceTime(integer $InstanceID, integer $Counter, integer $Time)
{
    
}

/**
 * VELLEUSB_WriteAnalogChannel
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param integer $Channel
 * @param integer $Value
 */
function VELLEUSB_WriteAnalogChannel(integer $InstanceID, integer $Channel, integer $Value)
{
    
}

/**
 * VELLEUSB_WriteDigital
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param integer $Value
 */
function VELLEUSB_WriteDigital(integer $InstanceID, integer $Value)
{
    
}

/**
 * VELLEUSB_WriteDigitalChannel
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param integer $Channel
 * @param boolean $Value
 */
function VELLEUSB_WriteDigitalChannel(integer $InstanceID, integer $Channel, boolean $Value)
{
    
}

/**
 * VIO_PushText
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param string $Text
 */
function VIO_PushText(integer $InstanceID, string $Text)
{
    
}

/**
 * VIO_PushTextHEX
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param string $Text
 */
function VIO_PushTextHEX(integer $InstanceID, string $Text)
{
    
}

/**
 * VIO_SendText
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param string $Text
 */
function VIO_SendText(integer $InstanceID, string $Text)
{
    
}

/**
 * fgt Musikdatei zur Playlist hinzu
 * 
 * <p>Fgt eine Datei der internen Playlist vom Media Player mit der ID <b>InstanzID</b> zu.</p><p>Es wird nicht geprft, ob die Datei schon vorhanden ist. Dieselbe Datei kann also mehrfach in der Playlist vorhanden sein.</p><p>Um die Wiedergabe zu starten, mssen Sie WAC_Play aufrufen.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/mediaplayer/wac-addfile/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu steuernden Media Players
 * @param string $Filename Pfad zur abzuspielenden Datei
 */
function WAC_AddFile(integer $InstanceID, string $Filename)
{
    
}

/**
 * lscht die Playlist
 * 
 * <p>Lscht die interne Playlist vom Media Player mit der ID <b>InstanzID</b>.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/mediaplayer/wac-clearplaylist/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu steuernden Media Players
 */
function WAC_ClearPlaylist(integer $InstanceID)
{
    
}

/**
 * WAC_GetPlaylistFile
 * 
 * @returns string
 * @param integer $InstanceID
 * @param integer $Position
 */
function WAC_GetPlaylistFile(integer $InstanceID, integer $Position)
{
    
}

/**
 * lscht die Playlist
 * 
 * <p>Gibt die Lnge der internen Playlist vom Media Player mit der ID <b>InstanzID</b> zurck.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/mediaplayer/wac-getplaylistlength/
 * @returns integer <p>Anzahl der Tracks, die in der Playlist eingetragen sind.</p>
 * @param integer $InstanceID ID des zu steuernden Media Players
 */
function WAC_GetPlaylistLength(integer $InstanceID)
{
    
}

/**
 * lscht die Playlist
 * 
 * <p>Gibt die aktuelle Position der internen Playlist vom Media Player mit der ID <b>InstanzID</b> zurck.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/mediaplayer/wac-getplaylistposition/
 * @returns integer <p>Wert zwischen 1 und WAC_GetPlayListLength; Falls die Playlist leer sein sollte, wird -1 zurckgegeben.</p>
 * @param integer $InstanceID ID des zu schaltenden Gerts
 */
function WAC_GetPlaylistPosition(integer $InstanceID)
{
    
}

/**
 * WAC_GetPlaylistTitle
 * 
 * @returns string
 * @param integer $InstanceID
 * @param integer $Position
 */
function WAC_GetPlaylistTitle(integer $InstanceID, integer $Position)
{
    
}

/**
 * spielt den nchsten Titel der Playlist ab
 * 
 * <p>Geht in der internen Playlist vom Media Player mit der ID <b>InstanzID</b> einen Titel vorwrts oder whlt zufllig einen Titel aus, wenn Shuffle aktiviert ist. Sollte die Wiedergabe gestartet sein, wird nach dem Zurckgehen der dann neue, aktuelle Titel von Anfang an abgespielt.</p><p>Sollte die Playliste leer sein, wird eine Fehlermeldung generiert.</p><p>Sollte die Playlist am Ende angelangt sein, wird wieder entweder eine Fehlermeldung generiert oder, falls Repeat aktiviert ist, am Anfang der Playlist neu gestartet.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/mediaplayer/wac-next/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu steuernden Media Players
 */
function WAC_Next(integer $InstanceID)
{
    
}

/**
 * pausiert die Wiedergabe
 * 
 * <p>Pausiert die Wiedergabe der internen Playlist vom Media Player mit der ID <b>InstanzID</b>. Durch ein erneutes aufrufen von WAC_Pause oder einem Aufruf von WAC_Play kann die Wiedergabe fortgesetzt werden.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/mediaplayer/wac-pause/
 * @returns boolean <p>Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>. Es wird auch <b>TRUE</b> zurckgegeben, falls keine aktive Wiedergabe vorhanden ist.</p>
 * @param integer $InstanceID ID des zu steuernden Media Players
 */
function WAC_Pause(integer $InstanceID)
{
    
}

/**
 * spielt die Playlist ab
 * 
 * <p>Startet die Wiedergabe der internen Playlist vom Media Player mit der ID <b>InstanzID</b>. Falls Sie noch keine Dateien hinzugefgt haben, knnen Sie dies ber WAC_AddFile tun. Eine direkte Funktion zum Abspielen einer einzelnen Datei ist WAC_PlayFile. Bitte beachten Sie auch die untersttzten Dateiformate, die sich auf WAC_PlayFile finden knnen.</p><p>Sollte eine Wiedergabe bereits gestartet worden sein, wird durch Aufrufen dieses Befehls die Wiedergabe vom Anfang der Datei gestartet.</p><p>Sollte die Playliste leer sein, wird eine Fehlermeldung generiert.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/mediaplayer/wac-play/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu steuernden Media Players
 */
function WAC_Play(integer $InstanceID)
{
    
}

/**
 * spielt eine Musikdatei direkt ab
 * 
 * <p>Spielt eine Datei mit Dateiname direkt ber den Media Player mit der ID <b>InstanzID</b> ab. Der Befehl ist nur zur Vereinfachung vorhanden. Sie knnen ihn auch durch eine Abfolge von WAC_ClearPlaylist, WAC_AddFile, WAC_Play ersetzen.</p><p>Bitte beachten Sie die untersttzten Dateiformate.Zur Zeit untersttzte Formate: <b>*.wav, *.mp3, *.wma</b> (jeweils ohne DRM)</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/mediaplayer/wac-playfile/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu steuernden Media Players
 * @param string $Filename Pfad zur abzuspielenden Datei
 */
function WAC_PlayFile(integer $InstanceID, string $Filename)
{
    
}

/**
 * spielt den vorherigen Titel der Playlist ab
 * 
 * <p>Geht in der internen Playlist vom Media Player mit der ID <b>InstanzID</b> einen Titel zurck. Sollte die Wiedergabe gestartet sein, wird nach dem Zurckgehen der dann neue aktuelle Titel von Anfang an abgespielt.</p><p>Sollte die Playliste leer sein, wird eine Fehlermeldung generiert.</p><p>Sollte die Playlist am Anfang angelangt sein, wird der aktuelle Titel von Vorne abgespielt.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/mediaplayer/wac-prev/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu steuernden Media Players
 */
function WAC_Prev(integer $InstanceID)
{
    
}

/**
 * lscht die Playlist
 * 
 * <p>Setzt die aktuelle Position der internen Playlist vom Media Player mit der ID <b>InstanzID</b> auf die neue <b>Position</b>. Nach dem Ausfhren muss WAC_Play ausgefhrt werden, wenn die Wiedergabe an der neuen Position starten soll. Andernfalls wird der nchste Titel, nach dem Ende des aktuellen Titels abgespielt.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/mediaplayer/wac-setplaylistposition/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param integer $Position
 */
function WAC_SetPlaylistPosition(integer $InstanceID, integer $Position)
{
    
}

/**
 * setzt den Positionsmarker auf eine bestimmte Sekunde
 * 
 * <p>Setzt den Positionsmarker vom Media Player mit der ID <b>InstanzID</b> auf die angegeben <b>Sekunden</b>. Der Titel muss zum Ausfhrungszeitpunkt bereits abgespielt werden.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/mediaplayer/wac-setposition/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu steuernden Media Players
 * @param integer $Seconds Sprungmarke in Sekunden
 */
function WAC_SetPosition(integer $InstanceID, integer $Seconds)
{
    
}

/**
 * schaltet die Wiederholung der Playlist ein/aus
 * 
 * <p>Aktiviert/ deaktiviert die Wiederholung der Playlist vom Media Player mit der ID InstanzID.</p><p>Der Befehl wird sofort bernommen, macht sich aber erst beim nchsten Track der aktuellen Playlist bemerkbar. Die aktuelle Wiedergabe wird nicht beeinflusst.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/mediaplayer/wac-setrepeat/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu steuernden Media Players
 * @param boolean $DoRepeat 
 */
function WAC_SetRepeat(integer $InstanceID, boolean $DoRepeat)
{
    
}

/**
 * schaltet die Zufallswiedergabe ein/aus
 * 
 * <p>Aktiviert/ deaktiviert die Zufallswiedergabe vom Media Player mit der ID <b>InstanzID</b>.</p><p>Der Befehl wird sofort bernommen, macht sich aber erst beim nchsten Track der aktuellen Playlist bemerkbar. Die aktuelle Wiedergabe wird nicht beeinflusst.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/mediaplayer/wac-setshuffle/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu steuernden Media Players
 * @param boolean $DoShuffle 
 */
function WAC_SetShuffle(integer $InstanceID, boolean $DoShuffle)
{
    
}

/**
 * setzt die Lautstrke
 * 
 * <p>Fadet die Lautstrke vom Media Player mit der ID <b>InstanzID</b> innerhalb von 500ms auf die gewnschte Lautstrke.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/mediaplayer/wac-setvolume/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu steuernden Media Players
 * @param integer $Volume 0-100 (%)
 */
function WAC_SetVolume(integer $InstanceID, integer $Volume)
{
    
}

/**
 * stoppt die Wiedergabe
 * 
 * <p>Stoppt die Wiedergabe der internen Playlist vom Media Player mit der ID InstanzID.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/mediaplayer/wac-stop/
 * @returns boolean <p>Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>. Es wird auch <b>TRUE</b> zurckgegeben, falls keine aktive Wiedergabe vorhanden ist.</p>
 * @param integer $InstanceID ID des zu steuernden Media Players
 */
function WAC_Stop(integer $InstanceID)
{
    
}

/**
 * WFC_AddItem
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param string $ID
 * @param string $ClassName
 * @param string $Configuration
 * @param string $ParentID
 */
function WFC_AddItem(integer $InstanceID, string $ID, string $ClassName, string $Configuration, string $ParentID)
{
    
}

/**
 * sendet eine Audio-Meldung auf das WebFront
 * 
 * <p>Sendet eine Audio-Nachricht mit <b>Titel</b> an das WebFront, das dem Konfigurator mit der ID <b>InstanzID</b> zugeordnet ist. Die Audio-Nachricht erscheint als kleiner Kasten in der oberen rechten Ecke des WebFronts und wird fr die Abspieldauer angezeigt.</p><p>Bitte beachten, dass nicht alle Browser alle Formate untersttzen: http://www.w3schools.com/tags/tag_audio.asp</p><p>Unter iOS hat diese Funktion keierlei Auswirkung, da Apple das Abspielen von Sounddateien im WebBrowser unterbindet!</p><p>Unter Android Browser und Android Chrome hat diese Funktion keierlei Auswirkung, da Google das Abspielen von Sounddateien im WebBrowser unterbindet!<br>Unter Android Chrome kann das automatische Abspielen von Sounddateien aktiviert werden. Dazu muss unter about:flags "Bewegungsanforderung fr Medienwiedergabe deaktivieren" aktiviert und der Browser neugestartet werden.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/webfront-konfigurator/wfc-audionotification/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des WebFront Konfigurators
 * @param string $Title Titel der Audio-Meldung
 * @param integer $MediaID ID des Media-Objekts, welches vom Typ "Ton" ist
 */
function WFC_AudioNotification(integer $InstanceID, string $Title, integer $MediaID)
{
    
}

/**
 * WFC_DeleteItem
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param string $ID
 */
function WFC_DeleteItem(integer $InstanceID, string $ID)
{
    
}

/**
 * WFC_Execute
 * 
 * @returns string
 * @param integer $InstanceID
 * @param integer $ActionID
 * @param integer $TargetID
 * @param mixed $Value
 */
function WFC_Execute(integer $InstanceID, integer $ActionID, integer $TargetID, mixed $Value)
{
    
}

/**
 * WFC_GetAggregatedValues
 * 
 * @returns array
 * @param integer $InstanceID
 * @param integer $VariableID
 * @param integer $AggregationSpan
 *   enum[0=agHour, 1=agDay, 2=agWeek, 3=agMonth, 4=agYear, 5=ag5Minutes, 6=ag1Minute, 7=agChanges]
 * @param integer $StartTime
 * @param integer $EndTime
 * @param integer $Limit
 */
function WFC_GetAggregatedValues(integer $InstanceID, integer $VariableID, integer $AggregationSpan, integer $StartTime, integer $EndTime, integer $Limit)
{
    
}

/**
 * WFC_GetItems
 * 
 * @returns array
 * @param integer $InstanceID
 */
function WFC_GetItems(integer $InstanceID)
{
    
}

/**
 * WFC_GetLoggedValues
 * 
 * @returns array
 * @param integer $InstanceID
 * @param integer $VariableID
 * @param integer $StartTime
 * @param integer $EndTime
 * @param integer $Limit
 */
function WFC_GetLoggedValues(integer $InstanceID, integer $VariableID, integer $StartTime, integer $EndTime, integer $Limit)
{
    
}

/**
 * WFC_GetSnapshot
 * 
 * @returns string
 * @param integer $InstanceID
 */
function WFC_GetSnapshot(integer $InstanceID)
{
    
}

/**
 * WFC_GetSnapshotChanges
 * 
 * @returns string
 * @param integer $InstanceID
 * @param integer $LastTimeStamp
 */
function WFC_GetSnapshotChanges(integer $InstanceID, integer $LastTimeStamp)
{
    
}

/**
 * WFC_GetSnapshotChangesEx
 * 
 * @returns string
 * @param integer $InstanceID
 * @param integer $CategoryID
 * @param integer $LastTimeStamp
 */
function WFC_GetSnapshotChangesEx(integer $InstanceID, integer $CategoryID, integer $LastTimeStamp)
{
    
}

/**
 * WFC_GetSnapshotEx
 * 
 * @returns string
 * @param integer $InstanceID
 * @param integer $CategoryID
 */
function WFC_GetSnapshotEx(integer $InstanceID, integer $CategoryID)
{
    
}

/**
 * sendet eine Push-Nachricht an die mobilen Apps
 * 
 * <p>Sendet eine Push-Nachricht mit <b>Titel</b>, <b>Text</b> an alle mobilen Gerte, die dem Konfigurator mit der ID <b>InstanzID</b> zugeordnet sind. Alternativ kann auch einer der folgenden Sounds abgespielt werden:</p><ul><li>alarm</li><li>bell</li><li>boom</li><li>buzzer</li><li>connected</li><li>dark</li><li>digital</li><li>drums</li><li>duck</li><li>full</li><li>happy</li><li>horn</li><li>inception</li><li>kazoo</li><li>roll</li><li>siren</li><li>space</li><li>trickling</li><li>turn</li></ul><p>Bitte beachten Sie, dass Push-Benachrichtigungen verschlsselt ber den IP-Symcon Server an Apple/Google weitergeleitet werden, und dies eine gewisse Verzgerungszeit impliziert. Bei zu vielen Nachrichten hintereinander verzgern die Dienste von Apple/Google die Zustellungen automatisch, worauf IP-Symcon keinerlei Einfluss nehmen kann.</p><p>Die Nutzung dieser Funktion erfordert, wie schon in der Beschreibung der Mobile-Apps beschrieben, eine gltige Subskription. Diese knnen Sie jederzeit ber unseren Shop verlngern. Zustzlich muss das Gert in IP-Symcon registriert werden. Nhere Informationen dazu finden Sie unter dem Punkt Notification Control</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/webfront-konfigurator/wfc-pushnotification/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des WebFront Konfigurators
 * @param string $Title Titel der Meldung. Kann auch leer sein.
 * @param string $Text Text der Meldung.
 * @param string $Sound Wird in den Apps ab Version 3.0.6 ausgewertet
 * @param integer $TargetID 
 */
function WFC_PushNotification(integer $InstanceID, string $Title, string $Text, string $Sound, integer $TargetID)
{
    
}

/**
 * WFC_RegisterPNS
 * 
 * @returns string
 * @param integer $InstanceID
 * @param string $Token
 * @param string $Provider
 * @param string $DeviceID
 * @param string $DeviceName
 */
function WFC_RegisterPNS(integer $InstanceID, string $Token, string $Provider, string $DeviceID, string $DeviceName)
{
    
}

/**
 * ldt das WebFront auf dem Client-Rechner neu
 * 
 * <p>Ldt das WebFront, das dem Konfigurator mit der ID <b>InstanzID</b> zugeordnet ist neu.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/webfront-konfigurator/wfc-reload/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des WebFront Konfigurators
 */
function WFC_Reload(integer $InstanceID)
{
    
}

/**
 * WFC_RenderChart
 * 
 * @returns string
 * @param integer $InstanceID
 * @param integer $ObjectID
 * @param integer $StartTime
 * @param integer $TimeSpan
 *   enum[0=tsHour, 1=tsDay, 2=tsWeek, 3=tsMonth, 4=tsYear, 5=tsDecade]
 * @param boolean $IsHD
 * @param boolean $IsExtrema
 * @param boolean $IsDyn
 * @param integer $Width
 * @param integer $Height
 */
function WFC_RenderChart(integer $InstanceID, integer $ObjectID, integer $StartTime, integer $TimeSpan, boolean $IsHD, boolean $IsExtrema, boolean $IsDyn, integer $Width, integer $Height)
{
    
}

/**
 * sendet eine kleine Meldung auf das WebFront
 * 
 * <p>Sendet eine kleine Nachricht mit <b>Titel</b>, <b>Text</b> und <b>Icon</b> an das WebFront, das dem Konfigurator mit der ID <b>InstanzID</b> zugeordnet ist. Die Nachricht erscheint als kleiner Kasten in der oberen rechten Ecke des WebFronts und wird fr <b>Timeout</b> Sekunden angezeigt.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/webfront-konfigurator/wfc-sendnotification/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des WebFront Konfigurators
 * @param string $Title Titel der Meldung
 * @param string $Text Text der Meldung. Kann auch leer sein.
 * @param string $Icon Wenn nicht leer, dann wird das Icon angezeigt. Siehe
 * @param integer $Timeout Anzuzeigende Zeit in Sekunden. 0 = Nur ausblenden, wenn der Nutzer auf die Meldung klickt.
 */
function WFC_SendNotification(integer $InstanceID, string $Title, string $Text, string $Icon, integer $Timeout)
{
    
}

/**
 * sendet eine groe Meldung an das WebFront
 * 
 * <p>Sendet eine groe Meldung an das WebFront, das dem Konfigurator mit der ID <b>InstanzID</b> zugeordnet ist. Es werden der Inhalt <b>Text</b> und der <b>Titel</b> angezeigt.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/webfront-konfigurator/wfc-sendpopup/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des WebFront Konfigurators
 * @param string $Title Angezeigter Titel
 * @param string $Text Angezeigter Text (HTML wird gefiltert!)
 */
function WFC_SendPopup(integer $InstanceID, string $Title, string $Text)
{
    
}

/**
 * WFC_SetItems
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param string $Items
 */
function WFC_SetItems(integer $InstanceID, string $Items)
{
    
}

/**
 * wechselt den Reiter im WebFront
 * 
 * <p>Wechselt im WebFront, das dem Konfigurator mit der ID <b>InstanzID</b> zugeordnet ist, auf den Reiter mit der ID <b>PageName</b>.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/webfront-konfigurator/wfc-switchpage/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des WebFront Konfigurators
 * @param string $PageName Name des Reiters (z.B. item1234)
 */
function WFC_SwitchPage(integer $InstanceID, string $PageName)
{
    
}

/**
 * WFC_UpdateConfiguration
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param string $ID
 * @param string $Configuration
 */
function WFC_UpdateConfiguration(integer $InstanceID, string $ID, string $Configuration)
{
    
}

/**
 * WFC_UpdateParentID
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param string $ID
 * @param string $ParentID
 */
function WFC_UpdateParentID(integer $InstanceID, string $ID, string $ParentID)
{
    
}

/**
 * WFC_UpdatePosition
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param string $ID
 * @param integer $Position
 */
function WFC_UpdatePosition(integer $InstanceID, string $ID, integer $Position)
{
    
}

/**
 * WFC_UpdateVisibility
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param string $ID
 * @param boolean $Visible
 */
function WFC_UpdateVisibility(integer $InstanceID, string $ID, boolean $Visible)
{
    
}

/**
 * lsst die konfigurierte URL abfragen
 * 
 * <p>Lsst die URL des WWW Readers mit der ID ID <b>InstanzID</b> abfragen.</p><p>Dieser Befehl hat nur eine Funktion sofern die URL-Maske auf der Konfigurationsseite genutzt wird.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/io/wwwreader/www-updatepage/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu aktualisierenden WWW Readers
 */
function WWW_UpdatePage(integer $InstanceID)
{
    
}

/**
 * sendet einmalig einen Fernbedienungsbefehl
 * 
 * <p>Sendet einen Fernbedienungsbefehl ber die Instanz mit der ID <b>InstanzID</b> ab. Die Werte Fernbedienung und Knopf geben an, welcher Befehl gesendet werden soll. Diese mssen in der Client Software (WinLIRC/IRTrans Tray) entsprechend eingerichtet worden sein.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/winlirc/winlirc-sendonce/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param string $Remote Name der Fernbedienung, der in der Fernbedienungsdatenbank eingetragen ist/wurde.
 * @param string $Button Name der Fernbedienungsfunktion, die in der Fernbedienungsdatenbank eingetragen ist/wurde.
 */
function WinLIRC_SendOnce(integer $InstanceID, string $Remote, string $Button)
{
    
}

/**
 * WuT_SwitchMode
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param boolean $DeviceOn
 */
function WuT_SwitchMode(integer $InstanceID, boolean $DeviceOn)
{
    
}

/**
 * WuT_UpdateValue
 * 
 * @returns boolean
 * @param integer $InstanceID
 */
function WuT_UpdateValue(integer $InstanceID)
{
    
}

/**
 * WuT_UpdateValues
 * 
 * @returns boolean
 * @param integer $InstanceID
 */
function WuT_UpdateValues(integer $InstanceID)
{
    
}

/**
 * sendet einen Datenstring an ein bestimmtes Gert
 * 
 * <p>Sendet den DatenString <b>Buffer</b> an das Zielgert <b>ZielGert</b> und das XBee-Gateway mit der ID <b>InstanzID</b>.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/xbee/xbee-sendbuffer/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des abzufragenden Gerts
 * @param integer $DestinationDevice ID des ZielGerts
 * @param string $Buffer Datenbuffer der versendet werden soll
 */
function XBee_SendBuffer(integer $InstanceID, integer $DestinationDevice, string $Buffer)
{
    
}

/**
 * sendet einen Befehl an einen bestimmten XBee-Splitter
 * 
 * <p>Sendet den Befehl <b>Befehl</b> an den XBee-Splitter mit der ID <b>InstanzID</b>.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/xbee/xbee-sendcommand/
 * @returns string Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu verndernden Gerts
 * @param string $Command Befehl der gesendet werden soll
 */
function XBee_SendCommand(integer $InstanceID, string $Command)
{
    
}

function ZW_AssociationAddToGroup(integer $InstanceID, integer $Group, integer $Node)
{
    
}

/**
 * ZW_AssociationRemoveFromGroup
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param integer $Group
 * @param integer $Node
 */
function ZW_AssociationRemoveFromGroup(integer $InstanceID, integer $Group, integer $Node)
{
    
}

/**
 * bient ein Gert ber die Basisfunktion
 * 
 * <p>Schaltet die Basisfunktion vom angegeben Gert mit der InstanzID <b>InstanzID</b></p><p>Die Basisfunktion kann in den meisten Gerten ber Parameter bestimmt werden. Bitte entnehmen Sie weitere Informationen der Anleitung ihres spezifischen Gertes.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/z-wave/zw-basic/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des Gerts
 * @param integer $Value 0..255
 */
function ZW_Basic(integer $InstanceID, integer $Value)
{
    
}

/**
 * ZW_CheckCapability
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param integer $Cap
 *   enum[0=zcPrimaryController, 1=zcSecondaryController, 2=zcIsSUC, 3=zcHasSIS]
 */
function ZW_CheckCapability(integer $InstanceID, integer $Cap)
{
    
}

/**
 * ZW_ConfigurationGetValue
 * 
 * @returns integer
 * @param integer $InstanceID
 * @param integer $Parameter
 */
function ZW_ConfigurationGetValue(integer $InstanceID, integer $Parameter)
{
    
}

/**
 * ZW_ConfigurationResetValue
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param integer $Parameter
 */
function ZW_ConfigurationResetValue(integer $InstanceID, integer $Parameter)
{
    
}

/**
 * ZW_ConfigurationSetValue
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param integer $Parameter
 * @param integer $Value
 */
function ZW_ConfigurationSetValue(integer $InstanceID, integer $Parameter, integer $Value)
{
    
}

/**
 * ZW_ConfigurationSetValueEx
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param integer $Parameter
 * @param integer $Size
 * @param integer $Value
 */
function ZW_ConfigurationSetValueEx(integer $InstanceID, integer $Parameter, integer $Size, integer $Value)
{
    
}

/**
 * ZW_DeleteFailedDevice
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param integer $NodeID
 */
function ZW_DeleteFailedDevice(integer $InstanceID, integer $NodeID)
{
    
}

/**
 * dimmt ein Z-Wave Gert auf eine bestimmte Stufe
 * 
 * <p>Dimmt das Gert mit der ID <b>InstanzID</b> auf Wert <b>Intensitt</b></p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/z-wave/zw-dimset/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 * @param integer $Intensity Wert von 0-100 (in %)
 */
function ZW_DimSet(integer $InstanceID, integer $Intensity)
{
    
}

/**
 * stoppt die Dimmung eines Z-Wave Gerts
 * 
 * <p>Unterbricht das Dimmen des Gerts mit der ID <b>InstanzID</b></p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/z-wave/zw-dimstop/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des Gerts
 */
function ZW_DimStop(integer $InstanceID)
{
    
}

/**
 * ZW_GetCapabilities
 * 
 * @returns array
 * @param integer $InstanceID
 */
function ZW_GetCapabilities(integer $InstanceID)
{
    
}

/**
 * ZW_GetDevices
 * 
 * @returns array
 * @param integer $InstanceID
 */
function ZW_GetDevices(integer $InstanceID)
{
    
}

/**
 * ZW_GetHomeID
 * 
 * @returns string
 * @param integer $InstanceID
 */
function ZW_GetHomeID(integer $InstanceID)
{
    
}

/**
 * ZW_GetKnownDevices
 * 
 * @returns array
 * @param integer $InstanceID
 */
function ZW_GetKnownDevices(integer $InstanceID)
{
    
}

/**
 * ZW_GetNodeID
 * 
 * @returns integer
 * @param integer $InstanceID
 */
function ZW_GetNodeID(integer $InstanceID)
{
    
}

/**
 * ZW_GetSUCID
 * 
 * @returns integer
 * @param integer $InstanceID
 */
function ZW_GetSUCID(integer $InstanceID)
{
    
}

/**
 * ZW_GetType
 * 
 * @returns integer
 * @param integer $InstanceID
 */
function ZW_GetType(integer $InstanceID)
{
    
}

/**
 * ZW_GetVersion
 * 
 * @returns string
 * @param integer $InstanceID
 */
function ZW_GetVersion(integer $InstanceID)
{
    
}

/**
 * setzt den LockMode
 * 
 * <p>Setzt den LockMode bei dem Gert mit der InstanzID <b>InstanzID</b></p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/z-wave/zw-lockmode/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des Gerts
 * @param boolean $Locked 0..255
 */
function ZW_LockMode(integer $InstanceID, boolean $Locked)
{
    
}

/**
 * resetet das Meter
 * 
 * <p>Setzt das Meter vom Gert mit der InstanzID <b>InstanzID</b> zurck</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/z-wave/zw-meterreset/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des Gerts
 */
function ZW_MeterReset(integer $InstanceID)
{
    
}

/**
 * setzt die Protection und dessen Mode
 * 
 * <p>Setzt die Protection und dessen Mode <b>Mode</b> vom angegeben Gert mit der InstanzID <b>InstanzID</b></p><li>Off  0</li><li>Limited  1</li><li>On  2</li>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/z-wave/zw-protectionset/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des Gerts
 * @param integer $Mode 0..255
 *   enum[0=pOff, 1=pLimited, 2=pOn]
 */
function ZW_ProtectionSet(integer $InstanceID, integer $Mode)
{
    
}

/**
 * setzt den Fan Mode
 * 
 * <p>Setzt den FanMode <b>FanMode</b> vom angegeben Gert mit der InstanzID <b>InstanzID</b></p><li>Auto  0</li><li>Low  1</li><li>Medium  4</li><li>High  3</li><li>Off  5</li>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/z-wave/zw-pulsethermostatfanmodeset/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des Gerts
 * @param integer $FanMode 0..255
 *   enum[0=ptfmAuto, 1=ptfmLow, 2=ptfmMedium, 3=ptfmHigh, 4=ptfmOff]
 */
function ZW_PulseThermostatFanModeSet(integer $InstanceID, integer $FanMode)
{
    
}

/**
 * setzt den ThermostatMode
 * 
 * <p>Setzt den ThermostatMode <b>Mode</b> vom angegeben Gert mit der InstanzID <b>InstanzID</b></p><li>Heat  0</li><li>Cool  1</li><li>AutoChangeover  2</li>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/z-wave/zw-pulsethermostatmodeset/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des Gerts
 * @param integer $Mode 0..255
 *   enum[0=ptmHeat, 1=ptmCool, 2=ptmAutoChangeover]
 */
function ZW_PulseThermostatModeSet(integer $InstanceID, integer $Mode)
{
    
}

/**
 * setzt den Power Mode
 * 
 * <p>Setzt den PowerMode <b>PowerMode</b> vom angegeben Gert mit der InstanzID <b>InstanzID</b></p><li>off  0</li><li>Normal  1</li><li>Economy  2</li>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/z-wave/zw-pulsethermostatpowermodeset/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des Gerts
 * @param integer $PowerMode 0..255
 *   enum[0=ptpmOff, 1=ptpmNormal, 2=ptpmEconomy]
 */
function ZW_PulseThermostatPowerModeSet(integer $InstanceID, integer $PowerMode)
{
    
}

/**
 * setzt den PointSet
 * 
 * <p>Setzt den PointSet <b>PointSet</b> vom angegeben Gert mit der InstanzID <b>InstanzID</b></p><li>NormalHeat  0</li><li>NormalCool  1</li><li>NormalAuto  2</li><li>EconomyHeat  3</li><li>EconomyCool  4</li><li>EconomyAutoHeat  5</li><li>EconomyAutoCool  6</li>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/z-wave/zw-pulsethermostatsetpointset/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des Gerts
 * @param integer $SetPoint 0..255
 *   enum[0=ptspNormalHeat, 1=ptspNormalCool, 2=ptspNormalAuto, 3=ptspEconomyHeat, 4=ptspEconomyCool, 5=ptspEconomyAutoHeat, 6=ptspEconomyAutoCool]
 * @param float $Value 0..
 */
function ZW_PulseThermostatSetPointSet(integer $InstanceID, integer $SetPoint, float $Value)
{
    
}

/**
 * ZW_RequestAssociations
 * 
 * @returns array
 * @param integer $InstanceID
 */
function ZW_RequestAssociations(integer $InstanceID)
{
    
}

/**
 * ZW_RequestInfo
 * 
 * @returns boolean
 * @param integer $InstanceID
 */
function ZW_RequestInfo(integer $InstanceID)
{
    
}

/**
 * sende eine Statusmeldungsanfrage an ein Gert
 * 
 * <p>Fragt den Status fr das Gert mit der ID <b>InstanzID</b> ab. Nur netzbetriebene Gerte knnen per Befehl direkt abgefragt werden, da batteriebetriebene Gerte nicht dauerhaft dem Abfragen lauschen.</p><p><b>Diese Funktion belastet den Funkverkehr erheblich.</b>Sie sollte ausschlielich verwendet werden, um kritische Gert zum IP-Symcon-Start zu aktualisieren. Ein erneutes Abfragen zur Laufzeit wird nicht bentigt, da Z-Wave im Normalfall alle Statusnderungen direkt an IP-Symcon weiterleitet. ltere Gerte die dies nicht tun, sollten durch neuere Gerte ersetzt werden.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/z-wave/zw-requeststatus/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des Gerts
 */
function ZW_RequestStatus(integer $InstanceID)
{
    
}

/**
 * ZW_RequestVersion
 * 
 * @returns array
 * @param integer $InstanceID
 */
function ZW_RequestVersion(integer $InstanceID)
{
    
}

/**
 * ZW_RequestWakeUpInterval
 * 
 * @returns array
 * @param integer $InstanceID
 */
function ZW_RequestWakeUpInterval(integer $InstanceID)
{
    
}

/**
 * ZW_ResetToDefault
 * 
 * @returns boolean
 * @param integer $InstanceID
 */
function ZW_ResetToDefault(integer $InstanceID)
{
    
}

/**
 * ZW_RoutingAssignReturnRoute
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param integer $NodeID
 */
function ZW_RoutingAssignReturnRoute(integer $InstanceID, integer $NodeID)
{
    
}

/**
 * ZW_RoutingGetNodes
 * 
 * @returns array
 * @param integer $InstanceID
 * @param integer $NodeID
 */
function ZW_RoutingGetNodes(integer $InstanceID, integer $NodeID)
{
    
}

/**
 * ZW_RoutingOptimize
 * 
 * @returns boolean
 * @param integer $InstanceID
 */
function ZW_RoutingOptimize(integer $InstanceID)
{
    
}

/**
 * ZW_RoutingOptimizeNode
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param integer $NodeID
 */
function ZW_RoutingOptimizeNode(integer $InstanceID, integer $NodeID)
{
    
}

/**
 * ZW_RoutingTestNode
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param integer $NodeID
 */
function ZW_RoutingTestNode(integer $InstanceID, integer $NodeID)
{
    
}

/**
 * ZW_SearchDevices
 * 
 * @returns boolean
 * @param integer $InstanceID
 */
function ZW_SearchDevices(integer $InstanceID)
{
    
}

/**
 * ZW_SearchMainDevice
 * 
 * @returns integer
 * @param integer $InstanceID
 */
function ZW_SearchMainDevice(integer $InstanceID)
{
    
}

/**
 * ZW_SearchSubDevices
 * 
 * @returns array
 * @param integer $InstanceID
 */
function ZW_SearchSubDevices(integer $InstanceID)
{
    
}

/**
 * bewegt den Rolladen nach unten bis zur Endposition/Stop
 * 
 * <p>Bewegt den Rolladen mit der ID <b>InstanzID</b> nach unten, bis ZW_ShutterStop ausgefhrt oder die Endposition erreicht wird.</p><p>Beachten Sie, dass einige Rollladensteuerungen bei Z-Wave ber ZW_DimSet wie Dimmer angesprochen werden mssen.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/z-wave/zw-shuttermovedown/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 */
function ZW_ShutterMoveDown(integer $InstanceID)
{
    
}

/**
 * bewegt den Rolladen nach oben bis zur Endposition/Stop
 * 
 * <p>Bewegt den Rolladen mit der ID <b>InstanzID</b> nach oben, bis ZW_ShutterStop ausgefhrt oder die Endposition erreicht wird.</p><p>Beachten Sie, dass einige Rollladensteuerungen bei Z-Wave ber ZW_DimSet wie Dimmer angesprochen werden mssen.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/z-wave/zw-shuttermoveup/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 */
function ZW_ShutterMoveUp(integer $InstanceID)
{
    
}

/**
 * stoppt einen Bewegungsvorgang
 * 
 * <p>Stoppt eine aktuelle Bewegung des Rolladens.</p><p>Beachten Sie, dass einige Rollladensteuerungen bei Z-Wave ber ZW_DimSet wie Dimmer angesprochen werden mssen.</p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/z-wave/zw-shutterstop/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des zu schaltenden Gerts
 */
function ZW_ShutterStop(integer $InstanceID)
{
    
}

/**
 * ZW_StartAddDevice
 * 
 * @returns boolean
 * @param integer $InstanceID
 */
function ZW_StartAddDevice(integer $InstanceID)
{
    
}

/**
 * ZW_StartAddNewPrimaryController
 * 
 * @returns boolean
 * @param integer $InstanceID
 */
function ZW_StartAddNewPrimaryController(integer $InstanceID)
{
    
}

/**
 * ZW_StartRemoveDevice
 * 
 * @returns boolean
 * @param integer $InstanceID
 */
function ZW_StartRemoveDevice(integer $InstanceID)
{
    
}

/**
 * ZW_StopAddDevice
 * 
 * @returns boolean
 * @param integer $InstanceID
 */
function ZW_StopAddDevice(integer $InstanceID)
{
    
}

/**
 * ZW_StopAddNewPrimaryController
 * 
 * @returns boolean
 * @param integer $InstanceID
 */
function ZW_StopAddNewPrimaryController(integer $InstanceID)
{
    
}

/**
 * ZW_StopRemoveDevice
 * 
 * @returns boolean
 * @param integer $InstanceID
 */
function ZW_StopRemoveDevice(integer $InstanceID)
{
    
}

/**
 * schaltet ein Z-Wave Gert an/aus
 * 
 * <p>Schaltet das Gert mit der ID <b>InstanzID</b> auf Wert <b>Status</b></p>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/z-wave/zw-switchmode/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des Gerts
 * @param boolean $DeviceOn 
 */
function ZW_SwitchMode(integer $InstanceID, boolean $DeviceOn)
{
    
}

/**
 * Setzt den FanMode fr Thermostat
 * 
 * <p>Setzt den FanMode <b>FanMode</b> vom angegeben Gert mit der InstanzID <b>InstanzID</b></p><li>AutoLow  0</li><li>OnLow  1</li><li>AutoHigh  2</li><li>OnHigh  3</li>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/z-wave/zw-thermostatfanmodeset/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des Gerts
 * @param integer $FanMode 0..255
 *   enum[0=tfmAutoLow, 1=tfmOnLow, 2=tfmAutoHigh, 3=tfmOnHigh]
 */
function ZW_ThermostatFanModeSet(integer $InstanceID, integer $FanMode)
{
    
}

/**
 * Setzt den Thermostat Mode
 * 
 * <p>Setzt den Mode <b>Mode</b> vom angegeben Gert mit der InstanzID <b>InstanzID</b></p><li>Off  0</li><li>Heat  1</li><li>Cool  2</li><li>Auto  3</li><li>Auxiliary  4</li><li>Resume  5</li><li>FanOnly  6</li><li>Furnace  7</li><li>DryAir  8</li><li>MoistAir  9</li><li>AutoChangeover  10</li>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/z-wave/zw-thermostatmodeset/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des Gerts
 * @param integer $Mode 0..255
 *   enum[0=tmOff, 1=tmHeat, 2=tmCool, 3=tmAuto, 4=tmAuxiliary, 5=tmResume, 6=tmFanOnly, 7=tmFurnace, 8=tmDryAir, 9=tmMoistAir, 10=tmAutoChangeover]
 */
function ZW_ThermostatModeSet(integer $InstanceID, integer $Mode)
{
    
}

/**
 * Setzt den PointSet Value
 * 
 * <p>Setzt den PointSet <b>PointSet</b> vom angegeben Gert mit der InstanzID <b>InstanzID</b></p><li>Invalid  0</li><li>Heating  1</li><li>Cooling  2</li><li>Furnace  3</li><li>DryAir  4</li><li>MoistAir  5</li><li>AutoChangeover  6</li>
 * 
 * @link https://www.symcon.de/service/dokumentation/modulreferenz/z-wave/zw-thermostatsetpointset/
 * @returns boolean Konnte der Befehl erfolgreich ausgefhrt werden, liefert er als Ergebnis <b>TRUE</b>, andernfalls <b>FALSE</b>.
 * @param integer $InstanceID ID des Gerts
 * @param integer $SetPoint 0..255
 *   enum[0=tspInvalid, 1=tspHeating, 2=tspCooling, 3=tspFurnace, 4=tspDryAir, 5=tspMoistAir, 6=tspAutoChangeover]
 * @param float $Value 0..255
 */
function ZW_ThermostatSetPointSet(integer $InstanceID, integer $SetPoint, float $Value)
{
    
}

/**
 * ZW_WakeUpComplete
 * 
 * @returns boolean
 * @param integer $InstanceID
 */
function ZW_WakeUpComplete(integer $InstanceID)
{
    
}

/**
 * ZW_WakeUpKeepAlive
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param boolean $KeepAlive
 */
function ZW_WakeUpKeepAlive(integer $InstanceID, boolean $KeepAlive)
{
    
}

/**
 * ZW_WakeUpSetInterval
 * 
 * @returns boolean
 * @param integer $InstanceID
 * @param integer $Seconds
 */
function ZW_WakeUpSetInterval(integer $InstanceID, integer $Seconds)
{
    
}
